@@ -44,13 +44,12 @@ class OffscreenCanvasViewRasterizer extends ViewRasterizer {
     createCanvas: () => RenderCanvas(),
   );
 
-  /// Render the given [pictures] so it is displayed by the given [canvas].
-  @override
-  Future<void> rasterizeToCanvas(DisplayCanvas canvas, List<CkPicture> pictures) async {
+  /// Render the given [picture] so it is displayed by the given [canvas].
+  Future<void> rasterizeToCanvas(DisplayCanvas canvas, ui.Picture picture) async {
     await rasterizer.offscreenSurface.rasterizeToCanvas(
       currentFrameSize,
       canvas as RenderCanvas,
-      pictures,
+      picture,
     );
   }
 
@@ -58,4 +57,22 @@ class OffscreenCanvasViewRasterizer extends ViewRasterizer {
   void prepareToDraw() {
     rasterizer.offscreenSurface.createOrUpdateSurface(currentFrameSize);
   }
+
+  @override
+  Future<void> rasterize(
+    List<DisplayCanvas> displayCanvases,
+    List<ui.Picture> pictures,
+    FrameTimingRecorder? recorder,
+  ) async {
+    if (displayCanvases.length != pictures.length) {
+      throw ArgumentError('Called rasterize() with a different number of canvases and pictures.');
+    }
+    final List<Future<void>> rasterizeFutures = <Future<void>>[];
+    for (int i = 0; i < displayCanvases.length; i++) {
+      rasterizeFutures.add(rasterizeToCanvas(displayCanvases[i], pictures[i]));
+    }
+    recorder?.recordRasterStart();
+    await Future.wait<void>(rasterizeFutures);
+    recorder?.recordRasterFinish();
+  }
 }
