@@ -21,3 +21,9 @@ external WasmI32 addFunction(WasmFuncRef function);
 
 @Native<Bool Function()>(symbol: 'skwasm_isMultiThreaded', isLeaf: true)
 external bool skwasmIsMultiThreaded();
+
+@Native<Bool Function()>(symbol: 'skwasm_isHeavy', isLeaf: true)
+external bool skwasmIsHeavy();
+
+@Native<Void Function(Pointer<Uint32>)>(symbol: 'skwasm_getLiveObjectCounts', isLeaf: true)
+external void skwasmGetLiveObjectCounts(Pointer<Uint32> objectCounts);
