@@ -11,7 +11,6 @@ import 'dart:async';
 import 'dart:collection';
 import 'dart:convert' hide Codec;
 import 'dart:developer' as developer;
-import 'dart:js_util' as js_util;
 import 'dart:js_interop';
 import 'dart:js_interop_unsafe';
 import 'dart:math' as math;
@@ -19,7 +18,6 @@ import 'dart:typed_data';
 import 'dart:ui' as ui;
 import 'dart:ui_web' as ui_web;
 import 'dart:_engine';
-import 'dart:_web_unicode';
 import 'dart:_web_test_fonts';
 import 'dart:_web_locale_keymap' as locale_keymap;
 
