@@ -174,6 +174,15 @@ class ClipRRectEngineLayer extends _EngineLayerWrapper {
   ClipRRectEngineLayer._(super.nativeLayer) : super._();
 }
 
+/// An opaque handle to a clip rounded superellipse engine layer.
+///
+/// Instances of this class are created by [SceneBuilder.pushClipRSuperellipse].
+///
+/// {@macro dart.ui.sceneBuilder.oldLayerCompatibility}
+class ClipRSuperellipseEngineLayer extends _EngineLayerWrapper {
+  ClipRSuperellipseEngineLayer._(super.nativeLayer) : super._();
+}
+
 /// An opaque handle to a clip path engine layer.
 ///
 /// Instances of this class are created by [SceneBuilder.pushClipPath].
@@ -325,6 +334,22 @@ abstract class SceneBuilder {
     ClipRRectEngineLayer? oldLayer,
   });
 
+  /// Pushes a rounded-superellipse clip operation onto the operation stack.
+  ///
+  /// Rasterization outside the given rounded superellipse is discarded.
+  ///
+  /// {@macro dart.ui.sceneBuilder.oldLayer}
+  ///
+  /// {@macro dart.ui.sceneBuilder.oldLayerVsRetained}
+  ///
+  /// See [pop] for details about the operation stack, and [Clip] for different clip modes.
+  /// By default, the clip will be anti-aliased (clip = [Clip.antiAlias]).
+  ClipRSuperellipseEngineLayer pushClipRSuperellipse(
+    RSuperellipse rsuperellipse, {
+    Clip clipBehavior = Clip.antiAlias,
+    ClipRSuperellipseEngineLayer? oldLayer,
+  });
+
   /// Pushes a path clip operation onto the operation stack.
   ///
   /// Rasterization outside the given path is discarded.
@@ -720,6 +745,36 @@ base class _NativeSceneBuilder extends NativeFieldWrapperClass1 implements Scene
     EngineLayer? oldLayer,
   );
 
+  @override
+  ClipRSuperellipseEngineLayer pushClipRSuperellipse(
+    RSuperellipse rsuperellipse, {
+    Clip clipBehavior = Clip.antiAlias,
+    ClipRSuperellipseEngineLayer? oldLayer,
+  }) {
+    assert(clipBehavior != Clip.none);
+    assert(_debugCheckCanBeUsedAsOldLayer(oldLayer, 'pushClipRSuperellipse'));
+    final EngineLayer engineLayer = _NativeEngineLayer._();
+    _pushClipRSuperellipse(
+      engineLayer,
+      rsuperellipse._native(),
+      clipBehavior.index,
+      oldLayer?._nativeLayer,
+    );
+    final ClipRSuperellipseEngineLayer layer = ClipRSuperellipseEngineLayer._(engineLayer);
+    assert(_debugPushLayer(layer));
+    return layer;
+  }
+
+  @Native<Void Function(Pointer<Void>, Handle, Pointer<Void>, Int32, Handle)>(
+    symbol: 'SceneBuilder::pushClipRSuperellipse',
+  )
+  external void _pushClipRSuperellipse(
+    EngineLayer layer,
+    _NativeRSuperellipse rsuperellipseParam,
+    int clipBehavior,
+    EngineLayer? oldLayer,
+  );
+
   @override
   ClipPathEngineLayer pushClipPath(
     Path path, {
