@@ -11,7 +11,10 @@ void main() {
     'opacity_peephole_grid_of_alpha_savelayers',
     <ScrollableButtonRoute>[
       ScrollableButtonRoute(kScrollableName, kOpacityPeepholeRouteName),
-      ScrollableButtonRoute(kOpacityScrollableName, kOpacityPeepholeGridOfAlphaSaveLayerRectsRouteName),
+      ScrollableButtonRoute(
+        kOpacityScrollableName,
+        kOpacityPeepholeGridOfAlphaSaveLayerRectsRouteName,
+      ),
     ],
     pageDelay: const Duration(seconds: 1),
     duration: const Duration(seconds: 10),
