@@ -6,17 +6,17 @@ import 'package:flutter_driver/flutter_driver.dart';
 import 'package:test/test.dart' hide TypeMatcher, isInstanceOf;
 
 void main() {
-  late FlutterDriver driver;
+  FlutterDriver? driver;
 
   setUpAll(() async {
     driver = await FlutterDriver.connect();
   });
 
   tearDownAll(() async {
-    await driver.close();
+    await driver?.close();
   });
 
   test('Can run with --dart-define', () async {
-    await driver.waitFor(find.text('Example,AValue'));
+    await driver?.waitFor(find.text('Example,AValue'));
   }, timeout: Timeout.none);
 }
