@@ -29,7 +29,7 @@ void MockViewEmbedder::BeginFrame(
     const fml::RefPtr<fml::RasterThreadMerger>& raster_thread_merger) {}
 
 // |ExternalViewEmbedder|
-void MockViewEmbedder::PrepareFlutterView(SkISize frame_size,
+void MockViewEmbedder::PrepareFlutterView(DlISize frame_size,
                                           double device_pixel_ratio) {}
 
 // |ExternalViewEmbedder|
