@@ -4,8 +4,4 @@
 
 #include "impeller/renderer/command.h"
 
-namespace impeller {
-
-//
-
-}  // namespace impeller
+namespace impeller {}  // namespace impeller
