@@ -4,13 +4,10 @@
 
 import 'dart:typed_data';
 
+import 'package:ui/src/engine.dart';
 import 'package:ui/ui.dart' as ui;
 
-import 'canvas.dart';
-import 'canvaskit_api.dart';
-import 'picture.dart';
-
-class CkPictureRecorder implements ui.PictureRecorder {
+class CkPictureRecorder implements LayerPictureRecorder {
   SkPictureRecorder? _skRecorder;
   CkCanvas? _recordingCanvas;
 
@@ -18,7 +15,7 @@ class CkPictureRecorder implements ui.PictureRecorder {
     final SkPictureRecorder recorder = _skRecorder = SkPictureRecorder();
     final Float32List skRect = toSkRect(bounds);
     final SkCanvas skCanvas = recorder.beginRecording(skRect);
-    return _recordingCanvas = CkCanvas(skCanvas);
+    return _recordingCanvas = CkCanvas.fromSkCanvas(skCanvas);
   }
 
   CkCanvas? get recordingCanvas => _recordingCanvas;
@@ -43,4 +40,7 @@ class CkPictureRecorder implements ui.PictureRecorder {
 
   @override
   bool get isRecording => _skRecorder != null;
+
+  @override
+  bool get debugDisposed => _skRecorder == null;
 }
