@@ -63,6 +63,13 @@ class PlatformViewAndroidJNI {
       std::vector<std::string> strings,
       std::vector<std::vector<uint8_t>> string_attribute_args) = 0;
 
+  //----------------------------------------------------------------------------
+  /// @brief      Set application locale to a given language.
+  ///
+  /// @note       Must be called from the platform thread.
+  ///
+  virtual void FlutterViewSetApplicationLocale(std::string locale) = 0;
+
   //----------------------------------------------------------------------------
   /// @brief      Sends new custom accessibility events.
   ///
@@ -186,7 +193,7 @@ class PlatformViewAndroidJNI {
   ///
   struct OverlayMetadata {
     OverlayMetadata(int id, fml::RefPtr<AndroidNativeWindow> window)
-        : id(id), window(std::move(window)){};
+        : id(id), window(std::move(window)) {};
 
     ~OverlayMetadata() = default;
 
