@@ -16,10 +16,18 @@ namespace testing {
 class MockEpoxy {
  public:
   MockEpoxy();
+  ~MockEpoxy();
 
   MOCK_METHOD(bool, epoxy_has_gl_extension, (const char* extension));
   MOCK_METHOD(bool, epoxy_is_desktop_gl, ());
   MOCK_METHOD(int, epoxy_gl_version, ());
+  MOCK_METHOD(void,
+              eglCreateImage,
+              (EGLDisplay dpy,
+               EGLContext ctx,
+               EGLenum target,
+               EGLClientBuffer buffer,
+               const EGLAttrib* attrib_list));
   MOCK_METHOD(void, glClearColor, (GLfloat r, GLfloat g, GLfloat b, GLfloat a));
   MOCK_METHOD(void,
               glBlitFramebuffer,
@@ -33,6 +41,16 @@ class MockEpoxy {
                GLint dstY1,
                GLbitfield mask,
                GLenum filter));
+  MOCK_METHOD(void,
+              glDeleteFramebuffers,
+              (GLsizei n, const GLuint* framebuffers));
+  MOCK_METHOD(void,
+              glDeleteRenderbuffers,
+              (GLsizei n, const GLuint* renderbuffers));
+  MOCK_METHOD(void, glDeleteTextures, (GLsizei n, const GLuint* textures));
+  MOCK_METHOD(void, glGenFramebuffers, (GLsizei n, GLuint* framebuffers));
+  MOCK_METHOD(void, glGenRenderbuffers, (GLsizei n, GLuint* renderbuffers));
+  MOCK_METHOD(void, glGenTextures, (GLsizei n, GLuint* textures));
   MOCK_METHOD(const GLubyte*, glGetString, (GLenum pname));
 };
 
