@@ -4,14 +4,14 @@
 
 #include "flutter/shell/platform/windows/task_runner_window.h"
 
+#include <timeapi.h>
 #include <algorithm>
+#include <chrono>
 
 #include "flutter/fml/logging.h"
 
 namespace flutter {
 
-static const uintptr_t kTimerId = 0;
-
 // Timer used for PollOnce timeout.
 static const uintptr_t kPollTimeoutTimerId = 1;
 
@@ -21,6 +21,13 @@ TaskRunnerWindow::TaskRunnerWindow() {
       CreateWindowEx(0, window_class.lpszClassName, L"", 0, 0, 0, 0, 0,
                      HWND_MESSAGE, nullptr, window_class.hInstance, nullptr);
 
+  timer_ = CreateThreadpoolTimer(TimerProc, this, nullptr);
+  if (!timer_) {
+    FML_LOG(ERROR) << "Failed to create threadpool timer, error: "
+                   << GetLastError();
+    FML_CHECK(timer_);
+  }
+
   if (window_handle_) {
     SetWindowLongPtr(window_handle_, GWLP_USERDATA,
                      reinterpret_cast<LONG_PTR>(this));
@@ -35,14 +42,40 @@ TaskRunnerWindow::TaskRunnerWindow() {
     OutputDebugString(message);
     LocalFree(message);
   }
+
+  thread_id_ = GetCurrentThreadId();
+
+  // Increase timer precision for this process (the call only affects
+  // current process since Windows 10, version 2004).
+  timeBeginPeriod(1);
 }
 
 TaskRunnerWindow::~TaskRunnerWindow() {
+  SetThreadpoolTimer(timer_, nullptr, 0, 0);
+  // Ensures that no callbacks will run after CloseThreadpoolTimer.
+  // https://learn.microsoft.com/en-us/windows/win32/api/threadpoolapiset/nf-threadpoolapiset-closethreadpooltimer#remarks
+  WaitForThreadpoolTimerCallbacks(timer_, TRUE);
+  CloseThreadpoolTimer(timer_);
+
   if (window_handle_) {
     DestroyWindow(window_handle_);
     window_handle_ = nullptr;
   }
   UnregisterClass(window_class_name_.c_str(), nullptr);
+
+  timeEndPeriod(1);
+}
+
+void TaskRunnerWindow::OnTimer() {
+  if (!PostMessage(window_handle_, WM_NULL, 0, 0)) {
+    FML_LOG(ERROR) << "Failed to post message to main thread.";
+  }
+}
+
+void TaskRunnerWindow::TimerProc(PTP_CALLBACK_INSTANCE instance,
+                                 PVOID context,
+                                 PTP_TIMER timer) {
+  reinterpret_cast<TaskRunnerWindow*>(context)->OnTimer();
 }
 
 std::shared_ptr<TaskRunnerWindow> TaskRunnerWindow::GetSharedInstance() {
@@ -57,6 +90,18 @@ std::shared_ptr<TaskRunnerWindow> TaskRunnerWindow::GetSharedInstance() {
 }
 
 void TaskRunnerWindow::WakeUp() {
+  // When waking up from main thread while there are messages in the message
+  // queue use timer to post the WM_NULL message from background thread. This
+  // gives message loop chance to process input events before WM_NULL is
+  // processed - which is necessary because messages scheduled through
+  // PostMessage take precedence over input event messages. Otherwise await
+  // Future.delayed(Duration.zero) deadlocks the main thread. (See
+  // https://github.com/flutter/flutter/issues/173843)
+  if (thread_id_ == GetCurrentThreadId() && GetQueueStatus(QS_ALLEVENTS) != 0) {
+    SetTimer(std::chrono::nanoseconds::zero());
+    return;
+  }
+
   if (!PostMessage(window_handle_, WM_NULL, 0, 0)) {
     FML_LOG(ERROR) << "Failed to post message to main thread.";
   }
@@ -99,10 +144,16 @@ void TaskRunnerWindow::ProcessTasks() {
 
 void TaskRunnerWindow::SetTimer(std::chrono::nanoseconds when) {
   if (when == std::chrono::nanoseconds::max()) {
-    KillTimer(window_handle_, kTimerId);
+    SetThreadpoolTimer(timer_, nullptr, 0, 0);
   } else {
-    auto millis = std::chrono::duration_cast<std::chrono::milliseconds>(when);
-    ::SetTimer(window_handle_, kTimerId, millis.count() + 1, nullptr);
+    auto microseconds =
+        std::chrono::duration_cast<std::chrono::microseconds>(when).count();
+    ULARGE_INTEGER ticks;
+    ticks.QuadPart = -static_cast<LONGLONG>(microseconds * 10);
+    FILETIME ft;
+    ft.dwLowDateTime = ticks.LowPart;
+    ft.dwHighDateTime = ticks.HighPart;
+    SetThreadpoolTimer(timer_, &ft, 0, 0);
   }
 }
 
@@ -129,14 +180,6 @@ TaskRunnerWindow::HandleMessage(UINT const message,
                                 WPARAM const wparam,
                                 LPARAM const lparam) noexcept {
   switch (message) {
-    case WM_TIMER:
-      if (wparam == kPollTimeoutTimerId) {
-        // Ignore PollOnce timeout timer.
-        return 0;
-      }
-      FML_DCHECK(wparam == kTimerId);
-      ProcessTasks();
-      return 0;
     case WM_NULL:
       ProcessTasks();
       return 0;
