@@ -2,49 +2,36 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-// Flutter code sample for MaterialBanner
-
 import 'package:flutter/material.dart';
 
-void main() => runApp(const MyApp());
+/// Flutter code sample for [MaterialBanner].
 
-class MyApp extends StatelessWidget {
-  const MyApp({super.key});
+void main() => runApp(const MaterialBannerExampleApp());
 
-  static const String _title = 'Flutter Code Sample';
+class MaterialBannerExampleApp extends StatelessWidget {
+  const MaterialBannerExampleApp({super.key});
 
   @override
   Widget build(BuildContext context) {
-    return const MaterialApp(
-      title: _title,
-      home: MyStatelessWidget(),
-    );
+    return const MaterialApp(home: MaterialBannerExample());
   }
 }
 
-class MyStatelessWidget extends StatelessWidget {
-  const MyStatelessWidget({super.key});
+class MaterialBannerExample extends StatelessWidget {
+  const MaterialBannerExample({super.key});
 
   @override
   Widget build(BuildContext context) {
     return Scaffold(
-      appBar: AppBar(
-        title: const Text('The MaterialBanner is below'),
-      ),
+      appBar: AppBar(title: const Text('The MaterialBanner is below')),
       body: const MaterialBanner(
         padding: EdgeInsets.all(20),
         content: Text('Hello, I am a Material Banner'),
         leading: Icon(Icons.agriculture_outlined),
         backgroundColor: Color(0xFFE0E0E0),
         actions: <Widget>[
-          TextButton(
-            onPressed: null,
-            child: Text('OPEN'),
-          ),
-          TextButton(
-            onPressed: null,
-            child: Text('DISMISS'),
-          ),
+          TextButton(onPressed: null, child: Text('OPEN')),
+          TextButton(onPressed: null, child: Text('DISMISS')),
         ],
       ),
     );
