@@ -2,35 +2,28 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-// Flutter code sample for MaterialBanner
-
 import 'package:flutter/material.dart';
 
-void main() => runApp(const MyApp());
+/// Flutter code sample for [MaterialBanner].
 
-class MyApp extends StatelessWidget {
-  const MyApp({Key? key}) : super(key: key);
+void main() => runApp(const MaterialBannerExampleApp());
 
-  static const String _title = 'Flutter Code Sample';
+class MaterialBannerExampleApp extends StatelessWidget {
+  const MaterialBannerExampleApp({super.key});
 
   @override
   Widget build(BuildContext context) {
-    return const MaterialApp(
-      title: _title,
-      home: MyStatelessWidget(),
-    );
+    return const MaterialApp(home: MaterialBannerExample());
   }
 }
 
-class MyStatelessWidget extends StatelessWidget {
-  const MyStatelessWidget({Key? key}) : super(key: key);
+class MaterialBannerExample extends StatelessWidget {
+  const MaterialBannerExample({super.key});
 
   @override
   Widget build(BuildContext context) {
     return Scaffold(
-      appBar: AppBar(
-        title: const Text('The MaterialBanner is below'),
-      ),
+      appBar: AppBar(title: const Text('The MaterialBanner is below')),
       body: Center(
         child: ElevatedButton(
           child: const Text('Show MaterialBanner'),
@@ -40,12 +33,7 @@ class MyStatelessWidget extends StatelessWidget {
               content: Text('Hello, I am a Material Banner'),
               leading: Icon(Icons.agriculture_outlined),
               backgroundColor: Colors.green,
-              actions: <Widget>[
-                TextButton(
-                  onPressed: null,
-                  child: Text('DISMISS'),
-                ),
-              ],
+              actions: <Widget>[TextButton(onPressed: null, child: Text('DISMISS'))],
             ),
           ),
         ),
