@@ -15,12 +15,8 @@ class AutocompleteExampleApp extends StatelessWidget {
   Widget build(BuildContext context) {
     return MaterialApp(
       home: Scaffold(
-        appBar: AppBar(
-          title: const Text('RawAutocomplete Form'),
-        ),
-        body: const Center(
-          child: AutocompleteFormExample(),
-        ),
+        appBar: AppBar(title: const Text('RawAutocomplete Form')),
+        body: const Center(child: AutocompleteFormExample()),
       ),
     );
   }
@@ -39,11 +35,7 @@ class AutocompleteFormExampleState extends State<AutocompleteFormExample> {
   String? _dropdownValue;
   String? _autocompleteSelection;
 
-  static const List<String> _options = <String>[
-    'aardvark',
-    'bobcat',
-    'chameleon',
-  ];
+  static const List<String> _options = <String>['aardvark', 'bobcat', 'chameleon'];
 
   @override
   Widget build(BuildContext context) {
@@ -52,7 +44,7 @@ class AutocompleteFormExampleState extends State<AutocompleteFormExample> {
       child: Column(
         children: <Widget>[
           DropdownButtonFormField<String>(
-            value: _dropdownValue,
+            initialValue: _dropdownValue,
             icon: const Icon(Icons.arrow_downward),
             hint: const Text('This is a regular DropdownButtonFormField'),
             elevation: 16,
@@ -62,11 +54,10 @@ class AutocompleteFormExampleState extends State<AutocompleteFormExample> {
                 _dropdownValue = newValue;
               });
             },
-            items: <String>['One', 'Two', 'Free', 'Four'].map<DropdownMenuItem<String>>((String value) {
-              return DropdownMenuItem<String>(
-                value: value,
-                child: Text(value),
-              );
+            items: <String>['One', 'Two', 'Free', 'Four'].map<DropdownMenuItem<String>>((
+              String value,
+            ) {
+              return DropdownMenuItem<String>(value: value, child: Text(value));
             }).toList(),
             validator: (String? value) {
               if (value == null) {
@@ -77,9 +68,7 @@ class AutocompleteFormExampleState extends State<AutocompleteFormExample> {
           ),
           TextFormField(
             controller: _textEditingController,
-            decoration: const InputDecoration(
-              hintText: 'This is a regular TextFormField',
-            ),
+            decoration: const InputDecoration(hintText: 'This is a regular TextFormField'),
             validator: (String? value) {
               if (value == null || value.isEmpty) {
                 return "Can't be empty.";
@@ -98,59 +87,57 @@ class AutocompleteFormExampleState extends State<AutocompleteFormExample> {
                 _autocompleteSelection = selection;
               });
             },
-            fieldViewBuilder: (
-              BuildContext context,
-              TextEditingController textEditingController,
-              FocusNode focusNode,
-              VoidCallback onFieldSubmitted,
-            ) {
-              return TextFormField(
-                controller: textEditingController,
-                decoration: const InputDecoration(
-                  hintText: 'This is a RawAutocomplete!',
-                ),
-                focusNode: focusNode,
-                onFieldSubmitted: (String value) {
-                  onFieldSubmitted();
+            fieldViewBuilder:
+                (
+                  BuildContext context,
+                  TextEditingController textEditingController,
+                  FocusNode focusNode,
+                  VoidCallback onFieldSubmitted,
+                ) {
+                  return TextFormField(
+                    controller: textEditingController,
+                    decoration: const InputDecoration(hintText: 'This is a RawAutocomplete!'),
+                    focusNode: focusNode,
+                    onFieldSubmitted: (String value) {
+                      onFieldSubmitted();
+                    },
+                    validator: (String? value) {
+                      if (!_options.contains(value)) {
+                        return 'Nothing selected.';
+                      }
+                      return null;
+                    },
+                  );
                 },
-                validator: (String? value) {
-                  if (!_options.contains(value)) {
-                    return 'Nothing selected.';
-                  }
-                  return null;
-                },
-              );
-            },
-            optionsViewBuilder: (
-              BuildContext context,
-              AutocompleteOnSelected<String> onSelected,
-              Iterable<String> options,
-            ) {
-              return Align(
-                alignment: Alignment.topLeft,
-                child: Material(
-                  elevation: 4.0,
-                  child: SizedBox(
-                    height: 200.0,
-                    child: ListView.builder(
-                      padding: const EdgeInsets.all(8.0),
-                      itemCount: options.length,
-                      itemBuilder: (BuildContext context, int index) {
-                        final String option = options.elementAt(index);
-                        return GestureDetector(
-                          onTap: () {
-                            onSelected(option);
+            optionsViewBuilder:
+                (
+                  BuildContext context,
+                  AutocompleteOnSelected<String> onSelected,
+                  Iterable<String> options,
+                ) {
+                  return Align(
+                    alignment: Alignment.topLeft,
+                    child: Material(
+                      elevation: 4.0,
+                      child: SizedBox(
+                        height: 200.0,
+                        child: ListView.builder(
+                          padding: const EdgeInsets.all(8.0),
+                          itemCount: options.length,
+                          itemBuilder: (BuildContext context, int index) {
+                            final String option = options.elementAt(index);
+                            return GestureDetector(
+                              onTap: () {
+                                onSelected(option);
+                              },
+                              child: ListTile(title: Text(option)),
+                            );
                           },
-                          child: ListTile(
-                            title: Text(option),
-                          ),
-                        );
-                      },
+                        ),
+                      ),
                     ),
-                  ),
-                ),
-              );
-            },
+                  );
+                },
           ),
           ElevatedButton(
             onPressed: () {
