@@ -2,23 +2,18 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-// Flutter code sample for FocusScope
-
 import 'package:flutter/material.dart';
 
-void main() => runApp(const MyApp());
+/// Flutter code sample for [FocusScope].
 
-class MyApp extends StatelessWidget {
-  const MyApp({super.key});
+void main() => runApp(const FocusScopeExampleApp());
 
-  static const String _title = 'Flutter Code Sample';
+class FocusScopeExampleApp extends StatelessWidget {
+  const FocusScopeExampleApp({super.key});
 
   @override
   Widget build(BuildContext context) {
-    return const MaterialApp(
-      title: _title,
-      home: MyStatefulWidget(),
-    );
+    return const MaterialApp(home: FocusScopeExample());
   }
 }
 
@@ -48,9 +43,7 @@ class Pane extends StatelessWidget {
       child: Stack(
         fit: StackFit.expand,
         children: <Widget>[
-          Center(
-            child: child,
-          ),
+          Center(child: child),
           Align(
             alignment: Alignment.topLeft,
             child: IconButton(
@@ -66,14 +59,14 @@ class Pane extends StatelessWidget {
   }
 }
 
-class MyStatefulWidget extends StatefulWidget {
-  const MyStatefulWidget({super.key});
+class FocusScopeExample extends StatefulWidget {
+  const FocusScopeExample({super.key});
 
   @override
-  State<MyStatefulWidget> createState() => _MyStatefulWidgetState();
+  State<FocusScopeExample> createState() => _FocusScopeExampleState();
 }
 
-class _MyStatefulWidgetState extends State<MyStatefulWidget> {
+class _FocusScopeExampleState extends State<FocusScopeExample> {
   bool backdropIsVisible = false;
   FocusNode backdropNode = FocusNode(debugLabel: 'Close Backdrop Button');
   FocusNode foregroundNode = FocusNode(debugLabel: 'Option Button');
@@ -119,8 +112,9 @@ class _MyStatefulWidgetState extends State<MyStatefulWidget> {
                   child: const Text('ANOTHER BUTTON TO FOCUS'),
                 ),
                 DefaultTextStyle(
-                    style: Theme.of(context).textTheme.headline2!,
-                    child: const Text('BACKDROP')),
+                  style: Theme.of(context).textTheme.displayMedium!,
+                  child: const Text('BACKDROP'),
+                ),
               ],
             ),
           ),
@@ -144,12 +138,11 @@ class _MyStatefulWidgetState extends State<MyStatefulWidget> {
             // TRY THIS: Try changing this to Colors.green.withOpacity(0.8) to see for
             // yourself that the hidden components do/don't get focus.
             backgroundColor: Colors.green,
-            onPressed: backdropIsVisible
-                ? null
-                : () => setState(() => backdropIsVisible = true),
+            onPressed: backdropIsVisible ? null : () => setState(() => backdropIsVisible = true),
             child: DefaultTextStyle(
-                style: Theme.of(context).textTheme.headline2!,
-                child: const Text('FOREGROUND')),
+              style: Theme.of(context).textTheme.displayMedium!,
+              child: const Text('FOREGROUND'),
+            ),
           ),
         ),
       ],
