@@ -8,20 +8,22 @@ import 'package:flutter_test/flutter_test.dart';
 
 void main() {
   testWidgets('shows font features', (WidgetTester tester) async {
-    await tester.pumpWidget(
-      const MaterialApp(
-        home: example.ExampleWidget(),
-      ),
-    );
+    await tester.pumpWidget(const MaterialApp(home: example.ExampleWidget()));
 
     expect(find.byType(Text), findsNWidgets(9));
     expect((tester.widget(find.byType(Text).at(0)) as Text).style!.fontSize, equals(18.0));
     expect((tester.widget(find.byType(Text).at(1)) as Text).style!.fontFamily, equals('Cardo'));
-    expect((tester.widget(find.byType(Text).at(3)) as Text).style!.fontFeatures,
-        equals(const <FontFeature>[FontFeature.oldstyleFigures()]));
-    expect((tester.widget(find.byType(Text).at(5)) as Text).style!.fontFeatures,
-        equals(const <FontFeature>[FontFeature.alternativeFractions()]));
-    expect((tester.widget(find.byType(Text).at(8)) as Text).style!.fontFeatures,
-        equals(<FontFeature>[FontFeature.stylisticSet(1)]));
+    expect(
+      (tester.widget(find.byType(Text).at(3)) as Text).style!.fontFeatures,
+      equals(const <FontFeature>[FontFeature.oldstyleFigures()]),
+    );
+    expect(
+      (tester.widget(find.byType(Text).at(5)) as Text).style!.fontFeatures,
+      equals(const <FontFeature>[FontFeature.alternativeFractions()]),
+    );
+    expect(
+      (tester.widget(find.byType(Text).at(8)) as Text).style!.fontFeatures,
+      equals(<FontFeature>[FontFeature.stylisticSet(1)]),
+    );
   });
 }
