@@ -16,7 +16,7 @@ typedef OnResultListener = void Function(String result);
 // The choice of JSON parsing here is meant as an example that might surface
 // in real-world applications.
 class Calculator {
-  Calculator({ required this.onProgressListener, required this.onResultListener, String? data })
+  Calculator({required this.onProgressListener, required this.onResultListener, String? data})
     : _data = _replicateJson(data, 10000);
 
   final OnProgressListener onProgressListener;
@@ -31,14 +31,12 @@ class Calculator {
   // Run the computation associated with this Calculator.
   void run() {
     int i = 0;
-    final JsonDecoder decoder = JsonDecoder(
-      (dynamic key, dynamic value) {
-        if (key is int && i++ % _NOTIFY_INTERVAL == 0) {
-          onProgressListener(i.toDouble(), _NUM_ITEMS.toDouble());
-        }
-        return value;
-      },
-    );
+    final JsonDecoder decoder = JsonDecoder((dynamic key, dynamic value) {
+      if (key is int && i++ % _NOTIFY_INTERVAL == 0) {
+        onProgressListener(i.toDouble(), _NUM_ITEMS.toDouble());
+      }
+      return value;
+    });
     try {
       final List<dynamic> result = decoder.convert(_data) as List<dynamic>;
       final int n = result.length;
@@ -63,11 +61,7 @@ class Calculator {
 }
 
 // The current state of the calculation.
-enum CalculationState {
-  idle,
-  loading,
-  calculating
-}
+enum CalculationState { idle, loading, calculating }
 
 // Structured message to initialize the spawned isolate.
 class CalculationMessage {
@@ -82,7 +76,7 @@ class CalculationMessage {
 // This class manages these ports and maintains state related to the
 // progress of the background computation.
 class CalculationManager {
-  CalculationManager({ required this.onProgressListener, required this.onResultListener })
+  CalculationManager({required this.onProgressListener, required this.onResultListener})
     : _receivePort = ReceivePort() {
     _receivePort.listen(_handleMessage);
   }
@@ -175,7 +169,7 @@ class CalculationManager {
     final SendPort sender = message.sendPort;
     final Calculator calculator = Calculator(
       onProgressListener: (double completed, double total) {
-        sender.send(<double>[ completed, total ]);
+        sender.send(<double>[completed, total]);
       },
       onResultListener: sender.send,
       data: message.data,
@@ -201,7 +195,6 @@ class IsolateExampleWidget extends StatefulWidget {
 
 // Main application state.
 class IsolateExampleState extends State<StatefulWidget> with SingleTickerProviderStateMixin {
-
   String _status = 'Idle';
   String _label = 'Start';
   String _result = ' ';
@@ -229,24 +222,15 @@ class IsolateExampleState extends State<StatefulWidget> with SingleTickerProvide
         children: <Widget>[
           RotationTransition(
             turns: _animation,
-            child: Container(
-              width: 120.0,
-              height: 120.0,
-              color: const Color(0xFF882222),
-            ),
+            child: Container(width: 120.0, height: 120.0, color: const Color(0xFF882222)),
           ),
           Opacity(
             opacity: _calculationManager.isRunning ? 1.0 : 0.0,
-            child: CircularProgressIndicator(
-              value: _progress,
-            ),
+            child: CircularProgressIndicator(value: _progress),
           ),
           Text(_status),
           Center(
-            child: ElevatedButton(
-              onPressed: _handleButtonPressed,
-              child: Text(_label),
-            ),
+            child: ElevatedButton(onPressed: _handleButtonPressed, child: Text(_label)),
           ),
           Text(_result),
         ],
@@ -272,14 +256,11 @@ class IsolateExampleState extends State<StatefulWidget> with SingleTickerProvide
   }
 
   String _getStatus(CalculationState state) {
-    switch (state) {
-      case CalculationState.loading:
-        return 'Loading...';
-      case CalculationState.calculating:
-        return 'In Progress';
-      case CalculationState.idle:
-        return 'Idle';
-    }
+    return switch (state) {
+      CalculationState.loading => 'Loading...',
+      CalculationState.calculating => 'In Progress',
+      CalculationState.idle => 'Idle',
+    };
   }
 
   void _updateState(String result, double progress) {
