@@ -1,7 +1,9 @@
-// Copyright 2019 The Flutter team. All rights reserved.
+// Copyright 2013 The Flutter Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
+// ignore_for_file: avoid_print
+
 import 'dart:io';
 
 import 'package:crypto/crypto.dart';
@@ -10,46 +12,44 @@ import 'package:mustache_template/mustache.dart';
 
 import 'fonts.pb.dart';
 
-const _generatedMainFilePath = 'lib/google_fonts.dart';
-_generatedPartFilePath(String part) =>
-    'lib/src/google_fonts_parts/part_$part.dart';
-const _familiesSupportedPath = 'generator/families_supported';
-const _familiesDiffPath = 'generator/families_diff';
+const String _generatedAllPartsFilePath =
+    'lib/src/google_fonts_all_parts.g.dart';
+String _generatedPartFilePath(String part) =>
+    'lib/src/google_fonts_parts/part_$part.g.dart';
+const String _familiesSupportedPath = 'generator/families_supported';
+const String _familiesDiffPath = 'generator/families_diff';
 
 Future<void> main() async {
   print('Getting latest font directory...');
-  final protoUrl = await _getProtoUrl();
+  final Uri protoUrl = await _getProtoUrl();
   print('Success! Using $protoUrl');
 
-  final fontDirectory = await _readFontsProtoData(protoUrl);
+  final Directory fontDirectory = await _readFontsProtoData(protoUrl);
   print('\nValidating font URLs and file contents...');
   await _verifyUrls(fontDirectory);
   print(_success);
 
   print('\nDetermining font families delta...');
-  final familiesDelta = _FamiliesDelta(fontDirectory);
+  final _FamiliesDelta familiesDelta = _FamiliesDelta(fontDirectory);
   print(_success);
 
   print('\nGenerating $_familiesSupportedPath & $_familiesDiffPath ...');
-  File(_familiesSupportedPath)
-      .writeAsStringSync(familiesDelta.printableSupported());
+  File(
+    _familiesSupportedPath,
+  ).writeAsStringSync(familiesDelta.printableSupported());
   File(_familiesDiffPath).writeAsStringSync(familiesDelta.markdownDiff());
   print(_success);
 
-  print('\nUpdating CHANGELOG.md and pubspec.yaml...');
-  await familiesDelta.updateChangelogAndPubspec();
-  print(_success);
-
-  print('\nGenerating $_generatedMainFilePath and part files...');
+  print('\nGenerating $_generatedAllPartsFilePath and part files...');
   _generateDartCode(fontDirectory);
   print(_success);
 
-  print('\nFormatting $_generatedMainFilePath and part files...');
-  await Process.run('dart', ['format', 'lib']);
+  print('\nFormatting $_generatedAllPartsFilePath and part files...');
+  await Process.run('dart', <String>['format', 'lib']);
   print(_success);
 }
 
-const _success = 'Success!';
+const String _success = 'Success!';
 
 /// Gets the latest font directory.
 ///
@@ -61,17 +61,19 @@ const _success = 'Success!';
 /// that's okay for now, because the generator is only executed in trusted
 /// environments by individual developers.
 Future<Uri> _getProtoUrl({int initialVersion = 7}) async {
-  var directoryVersion = initialVersion;
+  int directoryVersion = initialVersion;
 
   Uri url(int directoryVersion) {
-    final paddedVersion = directoryVersion.toString().padLeft(3, '0');
-    return Uri.parse('http://fonts.gstatic.com/s/f/directory$paddedVersion.pb');
+    final String paddedVersion = directoryVersion.toString().padLeft(3, '0');
+    return Uri.parse(
+      'https://fonts.gstatic.com/s/f/directory$paddedVersion.pb',
+    );
   }
 
-  var didReachLatestUrl = false;
-  final httpClient = http.Client();
+  bool didReachLatestUrl = false;
+  final http.Client httpClient = http.Client();
   while (!didReachLatestUrl) {
-    final response = await httpClient.get(url(directoryVersion));
+    final http.Response response = await httpClient.get(url(directoryVersion));
     if (response.statusCode == 200) {
       directoryVersion += 1;
     } else if (response.statusCode == 404) {
@@ -87,16 +89,17 @@ Future<Uri> _getProtoUrl({int initialVersion = 7}) async {
 }
 
 Future<void> _verifyUrls(Directory fontDirectory) async {
-  final totalFonts =
-      fontDirectory.family.map((f) => f.fonts.length).reduce((a, b) => a + b);
+  final int totalFonts = fontDirectory.family
+      .map((FontFamily f) => f.fonts.length)
+      .reduce((int a, int b) => a + b);
 
-  final client = http.Client();
+  final http.Client client = http.Client();
   int i = 1;
-  for (final family in fontDirectory.family) {
-    for (final font in family.fonts) {
-      final urlString =
+  for (final FontFamily family in fontDirectory.family) {
+    for (final Font font in family.fonts) {
+      final String urlString =
           'https://fonts.gstatic.com/s/a/${_hashToString(font.file.hash)}.ttf';
-      final url = Uri.parse(urlString);
+      final Uri url = Uri.parse(urlString);
       await _tryUrl(client, url, font);
       print('Verified URL ($i/$totalFonts): $urlString');
       i += 1;
@@ -107,9 +110,10 @@ Future<void> _verifyUrls(Directory fontDirectory) async {
 
 Future<void> _tryUrl(http.Client client, Uri url, Font font) async {
   try {
-    final fileContents = await client.get(url);
-    final actualFileLength = fileContents.bodyBytes.length;
-    final actualFileHash = sha256.convert(fileContents.bodyBytes).toString();
+    final http.Response fileContents = await client.get(url);
+    final int actualFileLength = fileContents.bodyBytes.length;
+    final String actualFileHash =
+        sha256.convert(fileContents.bodyBytes).toString();
     if (font.file.fileSize != actualFileLength ||
         _hashToString(font.file.hash) != actualFileHash) {
       throw Exception('Font from $url did not match length of or checksum.');
@@ -121,9 +125,9 @@ Future<void> _tryUrl(http.Client client, Uri url, Font font) async {
 }
 
 String _hashToString(List<int> bytes) {
-  var fileName = '';
-  for (final byte in bytes) {
-    final convertedByte = byte.toRadixString(16).padLeft(2, '0');
+  String fileName = '';
+  for (final int byte in bytes) {
+    final String convertedByte = byte.toRadixString(16).padLeft(2, '0');
     fileName += convertedByte;
   }
   return fileName;
@@ -143,12 +147,13 @@ class _FamiliesDelta {
 
   void _init(Directory fontDirectory) {
     // Currently supported families.
-    Set<String> familiesSupported =
-        Set.from(File(_familiesSupportedPath).readAsLinesSync());
+    final Set<String> familiesSupported = Set<String>.from(
+      File(_familiesSupportedPath).readAsLinesSync(),
+    );
 
     // Newly supported families.
     all = Set<String>.from(
-      fontDirectory.family.map<String>((item) => item.name),
+      fontDirectory.family.map<String>((FontFamily item) => item.name),
     );
 
     added = all.difference(familiesSupported);
@@ -161,8 +166,12 @@ class _FamiliesDelta {
   // Diff of font families, suitable for markdown
   // (e.g. CHANGELOG, PR description).
   String markdownDiff() {
-    final addedPrintable = added.map((family) => '  - Added `$family`');
-    final removedPrintable = removed.map((family) => '  - Removed `$family`');
+    final Iterable<String> addedPrintable = added.map(
+      (String family) => '  - Added `$family`',
+    );
+    final Iterable<String> removedPrintable = removed.map(
+      (String family) => '  - Removed `$family`',
+    );
 
     String diff = '';
     if (removedPrintable.isNotEmpty) {
@@ -176,37 +185,18 @@ class _FamiliesDelta {
 
     return diff;
   }
-
-  // Use cider to update CHANGELOG.md and pubspec.yaml.
-  Future<void> updateChangelogAndPubspec() async {
-    for (final family in removed) {
-      await Process.run('cider', ['log', 'remove', '`$family`']);
-    }
-    for (final family in added) {
-      await Process.run('cider', ['log', 'add', '`$family`']);
-    }
-
-    await Process.run(
-      'cider',
-      ['bump', removed.isNotEmpty ? 'breaking' : 'minor'],
-    );
-    await Process.run(
-      'cider',
-      ['release'],
-    );
-  }
 }
 
 void _generateDartCode(Directory fontDirectory) {
-  final methods = <Map<String, dynamic>>[];
+  final List<Map<String, dynamic>> methods = <Map<String, dynamic>>[];
 
-  for (final item in fontDirectory.family) {
-    final family = item.name;
-    final familyNoSpaces = family.replaceAll(' ', '');
-    final familyWithPlusSigns = family.replaceAll(' ', '+');
-    final methodName = _familyToMethodName(family);
+  for (final FontFamily item in fontDirectory.family) {
+    final String family = item.name;
+    final String familyNoSpaces = family.replaceAll(' ', '');
+    final String familyWithPlusSigns = family.replaceAll(' ', '+');
+    final String methodName = _familyToMethodName(family);
 
-    const themeParams = [
+    const List<String> themeParams = <String>[
       'displayLarge',
       'displayMedium',
       'displaySmall',
@@ -230,9 +220,9 @@ void _generateDartCode(Directory fontDirectory) {
       'fontFamily': familyNoSpaces,
       'fontFamilyDisplay': family,
       'docsUrl': 'https://fonts.google.com/specimen/$familyWithPlusSigns',
-      'fontUrls': [
-        for (final variant in item.fonts)
-          {
+      'fontUrls': <Map<String, Object>>[
+        for (final Font variant in item.fonts)
+          <String, Object>{
             'variantWeight': variant.weight.start,
             'variantStyle':
                 variant.italic.start.round() == 1 ? 'italic' : 'normal',
@@ -240,39 +230,43 @@ void _generateDartCode(Directory fontDirectory) {
             'length': variant.file.fileSize,
           },
       ],
-      'themeParams': [
-        for (final themeParam in themeParams) {'value': themeParam},
+      'themeParams': <Map<String, String>>[
+        for (final String themeParam in themeParams)
+          <String, String>{'value': themeParam},
       ],
     });
   }
 
   // Part font methods by first letter.
-  Map<String, List<Map<String, dynamic>>> methodsByLetter = {};
-  final allParts = <Map<String, dynamic>>[];
+  final Map<String, List<Map<String, dynamic>>> methodsByLetter =
+      <String, List<Map<String, dynamic>>>{};
+  final List<Map<String, dynamic>> allParts = <Map<String, dynamic>>[];
 
-  for (var map in methods) {
-    String methodName = map['methodName'];
-    String firstLetter = methodName[0];
+  for (final Map<String, dynamic> map in methods) {
+    final String methodName = map['methodName'] as String;
+    final String firstLetter = methodName[0];
     if (!methodsByLetter.containsKey(firstLetter)) {
-      allParts.add({
-        'partFilePath': _generatedPartFilePath(firstLetter).replaceFirst(
-          'lib/',
-          '',
-        )
+      allParts.add(<String, dynamic>{
+        'partFilePath': _generatedPartFilePath(
+          firstLetter,
+        ).replaceFirst('lib/src/', ''),
       });
-      methodsByLetter[firstLetter] = [map];
+      methodsByLetter[firstLetter] = <Map<String, dynamic>>[map];
     } else {
       methodsByLetter[firstLetter]!.add(map);
     }
   }
 
   // Generate part files.
-  final partTemplate = Template(
+  final Template partTemplate = Template(
     File('generator/google_fonts_part.tmpl').readAsStringSync(),
     htmlEscapeValues: false,
   );
-  methodsByLetter.forEach((letter, methods) async {
-    final renderedTemplate = partTemplate.renderString({
+  methodsByLetter.forEach((
+    String letter,
+    List<Map<String, dynamic>> methods,
+  ) async {
+    final String renderedTemplate = partTemplate.renderString(<String, Object>{
       'part': letter.toUpperCase(),
       'method': methods,
     });
@@ -280,15 +274,17 @@ void _generateDartCode(Directory fontDirectory) {
   });
 
   // Generate main file.
-  final template = Template(
+  final Template template = Template(
     File('generator/google_fonts.tmpl').readAsStringSync(),
     htmlEscapeValues: false,
   );
-  final renderedTemplate = template.renderString({
-    'allParts': allParts,
-    'method': methods,
-  });
-  _writeDartFile(_generatedMainFilePath, renderedTemplate);
+  final String renderedTemplate = template.renderString(
+    <String, List<Map<String, dynamic>>>{
+      'allParts': allParts,
+      'method': methods,
+    },
+  );
+  _writeDartFile(_generatedAllPartsFilePath, renderedTemplate);
 }
 
 void _writeDartFile(String path, String content) {
@@ -296,18 +292,19 @@ void _writeDartFile(String path, String content) {
 }
 
 String _familyToMethodName(String family) {
-  final words = family.split(' ');
-  for (var i = 0; i < words.length; i++) {
-    final word = words[i];
-    final isFirst = i == 0;
-    final isUpperCase = word == word.toUpperCase();
-    words[i] = (isFirst ? word[0].toLowerCase() : word[0].toUpperCase()) +
+  final List<String> words = family.split(' ');
+  for (int i = 0; i < words.length; i++) {
+    final String word = words[i];
+    final bool isFirst = i == 0;
+    final bool isUpperCase = word == word.toUpperCase();
+    words[i] =
+        (isFirst ? word[0].toLowerCase() : word[0].toUpperCase()) +
         (isUpperCase ? word.substring(1).toLowerCase() : word.substring(1));
   }
   return words.join();
 }
 
 Future<Directory> _readFontsProtoData(Uri protoUrl) async {
-  final fontsProtoFile = await http.get(protoUrl);
+  final http.Response fontsProtoFile = await http.get(protoUrl);
   return Directory.fromBuffer(fontsProtoFile.bodyBytes);
 }
