@@ -2,14 +2,13 @@
 
 // ignore_for_file: camel_case_types
 // ignore_for_file: comment_references
-// ignore_for_file: file_names
-// ignore_for_file: library_names
+// ignore_for_file: deprecated_member_use_from_same_package
 // ignore_for_file: lines_longer_than_80_chars
 // ignore_for_file: non_constant_identifier_names
-// ignore_for_file: prefer_expression_function_bodies
 // ignore_for_file: prefer_interpolation_to_compose_strings
 // ignore_for_file: unnecessary_brace_in_string_interps
 // ignore_for_file: unnecessary_lambdas
+// ignore_for_file: unnecessary_library_directive
 // ignore_for_file: unnecessary_string_interpolations
 
 /// Domains RDAP API - v1
@@ -27,15 +26,15 @@
 /// - [IpResource]
 /// - [NameserverResource]
 /// - [V1Resource]
-library domainsrdap.v1;
+library domainsrdap_v1;
 
 import 'dart:async' as async;
-import 'dart:convert' as convert;
 import 'dart:core' as core;
 
 import 'package:_discoveryapis_commons/_discoveryapis_commons.dart' as commons;
 import 'package:http/http.dart' as http;
 
+import '../shared.dart';
 import '../src/user_agent.dart';
 
 export 'package:_discoveryapis_commons/_discoveryapis_commons.dart'
@@ -88,19 +87,19 @@ class AutnumResource {
     core.String autnumId, {
     core.String? $fields,
   }) async {
-    final _queryParams = <core.String, core.List<core.String>>{
+    final queryParams_ = <core.String, core.List<core.String>>{
       if ($fields != null) 'fields': [$fields],
     };
 
-    final _url = 'v1/autnum/' + commons.escapeVariable('$autnumId');
+    final url_ = 'v1/autnum/' + commons.escapeVariable('$autnumId');
 
-    final _response = await _requester.request(
-      _url,
+    final response_ = await _requester.request(
+      url_,
       'GET',
-      queryParams: _queryParams,
+      queryParams: queryParams_,
     );
     return RdapResponse.fromJson(
-        _response as core.Map<core.String, core.dynamic>);
+        response_ as core.Map<core.String, core.dynamic>);
   }
 }
 
@@ -130,18 +129,18 @@ class DomainResource {
     core.String domainName, {
     core.String? $fields,
   }) async {
-    final _queryParams = <core.String, core.List<core.String>>{
+    final queryParams_ = <core.String, core.List<core.String>>{
       if ($fields != null) 'fields': [$fields],
     };
 
-    final _url = 'v1/domain/' + core.Uri.encodeFull('$domainName');
+    final url_ = 'v1/domain/' + core.Uri.encodeFull('$domainName');
 
-    final _response = await _requester.request(
-      _url,
+    final response_ = await _requester.request(
+      url_,
       'GET',
-      queryParams: _queryParams,
+      queryParams: queryParams_,
     );
-    return HttpBody.fromJson(_response as core.Map<core.String, core.dynamic>);
+    return HttpBody.fromJson(response_ as core.Map<core.String, core.dynamic>);
   }
 }
 
@@ -173,19 +172,19 @@ class EntityResource {
     core.String entityId, {
     core.String? $fields,
   }) async {
-    final _queryParams = <core.String, core.List<core.String>>{
+    final queryParams_ = <core.String, core.List<core.String>>{
       if ($fields != null) 'fields': [$fields],
     };
 
-    final _url = 'v1/entity/' + commons.escapeVariable('$entityId');
+    final url_ = 'v1/entity/' + commons.escapeVariable('$entityId');
 
-    final _response = await _requester.request(
-      _url,
+    final response_ = await _requester.request(
+      url_,
       'GET',
-      queryParams: _queryParams,
+      queryParams: queryParams_,
     );
     return RdapResponse.fromJson(
-        _response as core.Map<core.String, core.dynamic>);
+        response_ as core.Map<core.String, core.dynamic>);
   }
 }
 
@@ -220,22 +219,22 @@ class IpResource {
     core.String ipId1, {
     core.String? $fields,
   }) async {
-    final _queryParams = <core.String, core.List<core.String>>{
+    final queryParams_ = <core.String, core.List<core.String>>{
       if ($fields != null) 'fields': [$fields],
     };
 
-    final _url = 'v1/ip/' +
+    final url_ = 'v1/ip/' +
         commons.escapeVariable('$ipId') +
         '/' +
         commons.escapeVariable('$ipId1');
 
-    final _response = await _requester.request(
-      _url,
+    final response_ = await _requester.request(
+      url_,
       'GET',
-      queryParams: _queryParams,
+      queryParams: queryParams_,
     );
     return RdapResponse.fromJson(
-        _response as core.Map<core.String, core.dynamic>);
+        response_ as core.Map<core.String, core.dynamic>);
   }
 }
 
@@ -267,19 +266,19 @@ class NameserverResource {
     core.String nameserverId, {
     core.String? $fields,
   }) async {
-    final _queryParams = <core.String, core.List<core.String>>{
+    final queryParams_ = <core.String, core.List<core.String>>{
       if ($fields != null) 'fields': [$fields],
     };
 
-    final _url = 'v1/nameserver/' + commons.escapeVariable('$nameserverId');
+    final url_ = 'v1/nameserver/' + commons.escapeVariable('$nameserverId');
 
-    final _response = await _requester.request(
-      _url,
+    final response_ = await _requester.request(
+      url_,
       'GET',
-      queryParams: _queryParams,
+      queryParams: queryParams_,
     );
     return RdapResponse.fromJson(
-        _response as core.Map<core.String, core.dynamic>);
+        response_ as core.Map<core.String, core.dynamic>);
   }
 }
 
@@ -308,19 +307,19 @@ class V1Resource {
   async.Future<RdapResponse> getDomains({
     core.String? $fields,
   }) async {
-    final _queryParams = <core.String, core.List<core.String>>{
+    final queryParams_ = <core.String, core.List<core.String>>{
       if ($fields != null) 'fields': [$fields],
     };
 
-    const _url = 'v1/domains';
+    const url_ = 'v1/domains';
 
-    final _response = await _requester.request(
-      _url,
+    final response_ = await _requester.request(
+      url_,
       'GET',
-      queryParams: _queryParams,
+      queryParams: queryParams_,
     );
     return RdapResponse.fromJson(
-        _response as core.Map<core.String, core.dynamic>);
+        response_ as core.Map<core.String, core.dynamic>);
   }
 
   /// The RDAP API recognizes this command from the RDAP specification but does
@@ -343,19 +342,19 @@ class V1Resource {
   async.Future<RdapResponse> getEntities({
     core.String? $fields,
   }) async {
-    final _queryParams = <core.String, core.List<core.String>>{
+    final queryParams_ = <core.String, core.List<core.String>>{
       if ($fields != null) 'fields': [$fields],
     };
 
-    const _url = 'v1/entities';
+    const url_ = 'v1/entities';
 
-    final _response = await _requester.request(
-      _url,
+    final response_ = await _requester.request(
+      url_,
       'GET',
-      queryParams: _queryParams,
+      queryParams: queryParams_,
     );
     return RdapResponse.fromJson(
-        _response as core.Map<core.String, core.dynamic>);
+        response_ as core.Map<core.String, core.dynamic>);
   }
 
   /// Get help information for the RDAP API, including links to documentation.
@@ -375,18 +374,18 @@ class V1Resource {
   async.Future<HttpBody> getHelp({
     core.String? $fields,
   }) async {
-    final _queryParams = <core.String, core.List<core.String>>{
+    final queryParams_ = <core.String, core.List<core.String>>{
       if ($fields != null) 'fields': [$fields],
     };
 
-    const _url = 'v1/help';
+    const url_ = 'v1/help';
 
-    final _response = await _requester.request(
-      _url,
+    final response_ = await _requester.request(
+      url_,
       'GET',
-      queryParams: _queryParams,
+      queryParams: queryParams_,
     );
-    return HttpBody.fromJson(_response as core.Map<core.String, core.dynamic>);
+    return HttpBody.fromJson(response_ as core.Map<core.String, core.dynamic>);
   }
 
   /// The RDAP API recognizes this command from the RDAP specification but does
@@ -409,18 +408,18 @@ class V1Resource {
   async.Future<HttpBody> getIp({
     core.String? $fields,
   }) async {
-    final _queryParams = <core.String, core.List<core.String>>{
+    final queryParams_ = <core.String, core.List<core.String>>{
       if ($fields != null) 'fields': [$fields],
     };
 
-    const _url = 'v1/ip';
+    const url_ = 'v1/ip';
 
-    final _response = await _requester.request(
-      _url,
+    final response_ = await _requester.request(
+      url_,
       'GET',
-      queryParams: _queryParams,
+      queryParams: queryParams_,
     );
-    return HttpBody.fromJson(_response as core.Map<core.String, core.dynamic>);
+    return HttpBody.fromJson(response_ as core.Map<core.String, core.dynamic>);
   }
 
   /// The RDAP API recognizes this command from the RDAP specification but does
@@ -443,19 +442,19 @@ class V1Resource {
   async.Future<RdapResponse> getNameservers({
     core.String? $fields,
   }) async {
-    final _queryParams = <core.String, core.List<core.String>>{
+    final queryParams_ = <core.String, core.List<core.String>>{
       if ($fields != null) 'fields': [$fields],
     };
 
-    const _url = 'v1/nameservers';
+    const url_ = 'v1/nameservers';
 
-    final _response = await _requester.request(
-      _url,
+    final response_ = await _requester.request(
+      url_,
       'GET',
-      queryParams: _queryParams,
+      queryParams: queryParams_,
     );
     return RdapResponse.fromJson(
-        _response as core.Map<core.String, core.dynamic>);
+        response_ as core.Map<core.String, core.dynamic>);
   }
 }
 
@@ -477,56 +476,7 @@ class V1Resource {
 /// (stream google.api.HttpBody); } Use of this type only changes how the
 /// request and response bodies are handled, all other features will continue to
 /// work unchanged.
-class HttpBody {
-  /// The HTTP Content-Type header value specifying the content type of the
-  /// body.
-  core.String? contentType;
-
-  /// The HTTP request/response body as raw binary.
-  core.String? data;
-  core.List<core.int> get dataAsBytes => convert.base64.decode(data!);
-
-  set dataAsBytes(core.List<core.int> _bytes) {
-    data =
-        convert.base64.encode(_bytes).replaceAll('/', '_').replaceAll('+', '-');
-  }
-
-  /// Application specific response metadata.
-  ///
-  /// Must be set in the first response for streaming APIs.
-  ///
-  /// The values for Object must be JSON objects. It can consist of `num`,
-  /// `String`, `bool` and `null` as well as `Map` and `List` values.
-  core.List<core.Map<core.String, core.Object>>? extensions;
-
-  HttpBody();
-
-  HttpBody.fromJson(core.Map _json) {
-    if (_json.containsKey('contentType')) {
-      contentType = _json['contentType'] as core.String;
-    }
-    if (_json.containsKey('data')) {
-      data = _json['data'] as core.String;
-    }
-    if (_json.containsKey('extensions')) {
-      extensions = (_json['extensions'] as core.List)
-          .map<core.Map<core.String, core.Object>>(
-              (value) => (value as core.Map<core.String, core.dynamic>).map(
-                    (key, item) => core.MapEntry(
-                      key,
-                      item as core.Object,
-                    ),
-                  ))
-          .toList();
-    }
-  }
-
-  core.Map<core.String, core.dynamic> toJson() => {
-        if (contentType != null) 'contentType': contentType!,
-        if (data != null) 'data': data!,
-        if (extensions != null) 'extensions': extensions!,
-      };
-}
+typedef HttpBody = $HttpBody;
 
 /// Links object defined in
 /// [section 4.2 of RFC 7483](https://tools.ietf.org/html/rfc7483#section-4.2).
@@ -566,31 +516,31 @@ class Link {
   /// Example: "http://example.com/current".
   core.String? value;
 
-  Link();
+  Link({
+    this.href,
+    this.hreflang,
+    this.media,
+    this.rel,
+    this.title,
+    this.type,
+    this.value,
+  });
 
-  Link.fromJson(core.Map _json) {
-    if (_json.containsKey('href')) {
-      href = _json['href'] as core.String;
-    }
-    if (_json.containsKey('hreflang')) {
-      hreflang = _json['hreflang'] as core.String;
-    }
-    if (_json.containsKey('media')) {
-      media = _json['media'] as core.String;
-    }
-    if (_json.containsKey('rel')) {
-      rel = _json['rel'] as core.String;
-    }
-    if (_json.containsKey('title')) {
-      title = _json['title'] as core.String;
-    }
-    if (_json.containsKey('type')) {
-      type = _json['type'] as core.String;
-    }
-    if (_json.containsKey('value')) {
-      value = _json['value'] as core.String;
-    }
-  }
+  Link.fromJson(core.Map json_)
+      : this(
+          href: json_.containsKey('href') ? json_['href'] as core.String : null,
+          hreflang: json_.containsKey('hreflang')
+              ? json_['hreflang'] as core.String
+              : null,
+          media:
+              json_.containsKey('media') ? json_['media'] as core.String : null,
+          rel: json_.containsKey('rel') ? json_['rel'] as core.String : null,
+          title:
+              json_.containsKey('title') ? json_['title'] as core.String : null,
+          type: json_.containsKey('type') ? json_['type'] as core.String : null,
+          value:
+              json_.containsKey('value') ? json_['value'] as core.String : null,
+        );
 
   core.Map<core.String, core.dynamic> toJson() => {
         if (href != null) 'href': href!,
@@ -624,32 +574,34 @@ class Notice {
   /// unexplainable reasons".
   core.String? type;
 
-  Notice();
+  Notice({
+    this.description,
+    this.links,
+    this.title,
+    this.type,
+  });
 
-  Notice.fromJson(core.Map _json) {
-    if (_json.containsKey('description')) {
-      description = (_json['description'] as core.List)
-          .map<core.String>((value) => value as core.String)
-          .toList();
-    }
-    if (_json.containsKey('links')) {
-      links = (_json['links'] as core.List)
-          .map<Link>((value) =>
-              Link.fromJson(value as core.Map<core.String, core.dynamic>))
-          .toList();
-    }
-    if (_json.containsKey('title')) {
-      title = _json['title'] as core.String;
-    }
-    if (_json.containsKey('type')) {
-      type = _json['type'] as core.String;
-    }
-  }
+  Notice.fromJson(core.Map json_)
+      : this(
+          description: json_.containsKey('description')
+              ? (json_['description'] as core.List)
+                  .map((value) => value as core.String)
+                  .toList()
+              : null,
+          links: json_.containsKey('links')
+              ? (json_['links'] as core.List)
+                  .map((value) => Link.fromJson(
+                      value as core.Map<core.String, core.dynamic>))
+                  .toList()
+              : null,
+          title:
+              json_.containsKey('title') ? json_['title'] as core.String : null,
+          type: json_.containsKey('type') ? json_['type'] as core.String : null,
+        );
 
   core.Map<core.String, core.dynamic> toJson() => {
         if (description != null) 'description': description!,
-        if (links != null)
-          'links': links!.map((value) => value.toJson()).toList(),
+        if (links != null) 'links': links!,
         if (title != null) 'title': title!,
         if (type != null) 'type': type!,
       };
@@ -683,47 +635,52 @@ class RdapResponse {
   /// Error title.
   core.String? title;
 
-  RdapResponse();
+  RdapResponse({
+    this.description,
+    this.errorCode,
+    this.jsonResponse,
+    this.lang,
+    this.notices,
+    this.rdapConformance,
+    this.title,
+  });
 
-  RdapResponse.fromJson(core.Map _json) {
-    if (_json.containsKey('description')) {
-      description = (_json['description'] as core.List)
-          .map<core.String>((value) => value as core.String)
-          .toList();
-    }
-    if (_json.containsKey('errorCode')) {
-      errorCode = _json['errorCode'] as core.int;
-    }
-    if (_json.containsKey('jsonResponse')) {
-      jsonResponse = HttpBody.fromJson(
-          _json['jsonResponse'] as core.Map<core.String, core.dynamic>);
-    }
-    if (_json.containsKey('lang')) {
-      lang = _json['lang'] as core.String;
-    }
-    if (_json.containsKey('notices')) {
-      notices = (_json['notices'] as core.List)
-          .map<Notice>((value) =>
-              Notice.fromJson(value as core.Map<core.String, core.dynamic>))
-          .toList();
-    }
-    if (_json.containsKey('rdapConformance')) {
-      rdapConformance = (_json['rdapConformance'] as core.List)
-          .map<core.String>((value) => value as core.String)
-          .toList();
-    }
-    if (_json.containsKey('title')) {
-      title = _json['title'] as core.String;
-    }
-  }
+  RdapResponse.fromJson(core.Map json_)
+      : this(
+          description: json_.containsKey('description')
+              ? (json_['description'] as core.List)
+                  .map((value) => value as core.String)
+                  .toList()
+              : null,
+          errorCode: json_.containsKey('errorCode')
+              ? json_['errorCode'] as core.int
+              : null,
+          jsonResponse: json_.containsKey('jsonResponse')
+              ? HttpBody.fromJson(
+                  json_['jsonResponse'] as core.Map<core.String, core.dynamic>)
+              : null,
+          lang: json_.containsKey('lang') ? json_['lang'] as core.String : null,
+          notices: json_.containsKey('notices')
+              ? (json_['notices'] as core.List)
+                  .map((value) => Notice.fromJson(
+                      value as core.Map<core.String, core.dynamic>))
+                  .toList()
+              : null,
+          rdapConformance: json_.containsKey('rdapConformance')
+              ? (json_['rdapConformance'] as core.List)
+                  .map((value) => value as core.String)
+                  .toList()
+              : null,
+          title:
+              json_.containsKey('title') ? json_['title'] as core.String : null,
+        );
 
   core.Map<core.String, core.dynamic> toJson() => {
         if (description != null) 'description': description!,
         if (errorCode != null) 'errorCode': errorCode!,
-        if (jsonResponse != null) 'jsonResponse': jsonResponse!.toJson(),
+        if (jsonResponse != null) 'jsonResponse': jsonResponse!,
         if (lang != null) 'lang': lang!,
-        if (notices != null)
-          'notices': notices!.map((value) => value.toJson()).toList(),
+        if (notices != null) 'notices': notices!,
         if (rdapConformance != null) 'rdapConformance': rdapConformance!,
         if (title != null) 'title': title!,
       };
