@@ -6,7 +6,7 @@
 ///
 /// The integer implementations in this library are designed to work
 /// identically whether executed on the Dart VM or compiled to JavaScript.
-library fixnum;
+library;
 
 export 'src/int32.dart';
 export 'src/int64.dart';
