@@ -26,8 +26,8 @@ typedef WebViewCreatedCallback = void Function(WebViewController controller);
 /// `navigation` should be handled.
 ///
 /// See also: [WebView.navigationDelegate].
-typedef NavigationDelegate = FutureOr<NavigationDecision> Function(
-    NavigationRequest navigation);
+typedef NavigationDelegate =
+    FutureOr<NavigationDecision> Function(NavigationRequest navigation);
 
 /// Signature for when a [WebView] has started loading a page.
 typedef PageStartedCallback = void Function(String url);
@@ -252,8 +252,9 @@ class _WebViewState extends State<WebView> {
   void initState() {
     super.initState();
     _platformCallbacksHandler = _PlatformCallbacksHandler(widget);
-    _javascriptChannelRegistry =
-        JavascriptChannelRegistry(widget.javascriptChannels);
+    _javascriptChannelRegistry = JavascriptChannelRegistry(
+      widget.javascriptChannels,
+    );
   }
 
   @override
@@ -270,23 +271,23 @@ class _WebViewState extends State<WebView> {
       context: context,
       onWebViewPlatformCreated:
           (WebViewPlatformController? webViewPlatformController) {
-        final WebViewController controller = WebViewController._(
-          widget,
-          webViewPlatformController!,
-          _javascriptChannelRegistry,
-        );
-        _controller.complete(controller);
+            final WebViewController controller = WebViewController._(
+              widget,
+              webViewPlatformController!,
+              _javascriptChannelRegistry,
+            );
+            _controller.complete(controller);
 
-        if (widget.onWebViewCreated != null) {
-          widget.onWebViewCreated!(controller);
-        }
-      },
+            if (widget.onWebViewCreated != null) {
+              widget.onWebViewCreated!(controller);
+            }
+          },
       webViewPlatformCallbacksHandler: _platformCallbacksHandler,
       creationParams: CreationParams(
         initialUrl: widget.initialUrl,
         webSettings: _webSettingsFromWidget(widget),
-        javascriptChannelNames:
-            _javascriptChannelRegistry.channels.keys.toSet(),
+        javascriptChannelNames: _javascriptChannelRegistry.channels.keys
+            .toSet(),
         autoMediaPlaybackPolicy: widget.initialMediaPlaybackPolicy,
         userAgent: widget.userAgent,
         cookies: widget.initialCookies,
@@ -333,9 +334,7 @@ class WebViewController {
   /// `/Users/username/Documents/www/index.html`.
   ///
   /// Throws an ArgumentError if the [absoluteFilePath] does not exist.
-  Future<void> loadFile(
-    String absoluteFilePath,
-  ) {
+  Future<void> loadFile(String absoluteFilePath) {
     assert(absoluteFilePath.isNotEmpty);
     return _webViewPlatformController.loadFile(absoluteFilePath);
   }
@@ -344,15 +343,9 @@ class WebViewController {
   ///
   /// The [baseUrl] parameter is used when resolving relative URLs within the
   /// HTML string.
-  Future<void> loadHtmlString(
-    String html, {
-    String? baseUrl,
-  }) {
+  Future<void> loadHtmlString(String html, {String? baseUrl}) {
     assert(html.isNotEmpty);
-    return _webViewPlatformController.loadHtmlString(
-      html,
-      baseUrl: baseUrl,
-    );
+    return _webViewPlatformController.loadHtmlString(html, baseUrl: baseUrl);
   }
 
   /// Loads the specified URL.
@@ -363,10 +356,7 @@ class WebViewController {
   /// `url` must not be null.
   ///
   /// Throws an ArgumentError if `url` is not a valid URL string.
-  Future<void> loadUrl(
-    String url, {
-    Map<String, String>? headers,
-  }) async {
+  Future<void> loadUrl(String url, {Map<String, String>? headers}) async {
     _validateUrlString(url);
     return _webViewPlatformController.loadUrl(url, headers);
   }
@@ -441,28 +431,35 @@ class WebViewController {
     _widget = widget;
     await _updateSettings(_webSettingsFromWidget(widget));
     await _updateJavascriptChannels(
-        _javascriptChannelRegistry.channels.values.toSet());
+      _javascriptChannelRegistry.channels.values.toSet(),
+    );
   }
 
   Future<void> _updateSettings(WebSettings newSettings) {
-    final WebSettings update =
-        _clearUnchangedWebSettings(_settings, newSettings);
+    final WebSettings update = _clearUnchangedWebSettings(
+      _settings,
+      newSettings,
+    );
     _settings = newSettings;
     return _webViewPlatformController.updateSettings(update);
   }
 
   Future<void> _updateJavascriptChannels(
-      Set<JavascriptChannel>? newChannels) async {
-    final Set<String> currentChannels =
-        _javascriptChannelRegistry.channels.keys.toSet();
+    Set<JavascriptChannel>? newChannels,
+  ) async {
+    final Set<String> currentChannels = _javascriptChannelRegistry.channels.keys
+        .toSet();
     final Set<String> newChannelNames = _extractChannelNames(newChannels);
-    final Set<String> channelsToAdd =
-        newChannelNames.difference(currentChannels);
-    final Set<String> channelsToRemove =
-        currentChannels.difference(newChannelNames);
+    final Set<String> channelsToAdd = newChannelNames.difference(
+      currentChannels,
+    );
+    final Set<String> channelsToRemove = currentChannels.difference(
+      newChannelNames,
+    );
     if (channelsToRemove.isNotEmpty) {
-      await _webViewPlatformController
-          .removeJavascriptChannels(channelsToRemove);
+      await _webViewPlatformController.removeJavascriptChannels(
+        channelsToRemove,
+      );
     }
     if (channelsToAdd.isNotEmpty) {
       await _webViewPlatformController.addJavascriptChannels(channelsToAdd);
@@ -474,8 +471,11 @@ class WebViewController {
   // ignore: public_member_api_docs
   Future<String> evaluateJavascript(String javascriptString) {
     if (_settings.javascriptMode == JavascriptMode.disabled) {
-      return Future<String>.error(FlutterError(
-          'JavaScript mode must be enabled/unrestricted when calling evaluateJavascript.'));
+      return Future<String>.error(
+        FlutterError(
+          'JavaScript mode must be enabled/unrestricted when calling evaluateJavascript.',
+        ),
+      );
     }
     return _webViewPlatformController.evaluateJavascript(javascriptString);
   }
@@ -489,8 +489,11 @@ class WebViewController {
   ///  embedded in the main frame HTML has been loaded.
   Future<void> runJavascript(String javaScriptString) {
     if (_settings.javascriptMode == JavascriptMode.disabled) {
-      return Future<void>.error(FlutterError(
-          'Javascript mode must be enabled/unrestricted when calling runJavascript.'));
+      return Future<void>.error(
+        FlutterError(
+          'Javascript mode must be enabled/unrestricted when calling runJavascript.',
+        ),
+      );
     }
     return _webViewPlatformController.runJavascript(javaScriptString);
   }
@@ -510,11 +513,15 @@ class WebViewController {
   /// embedded in the main frame HTML has been loaded.
   Future<String> runJavascriptReturningResult(String javaScriptString) {
     if (_settings.javascriptMode == JavascriptMode.disabled) {
-      return Future<String>.error(FlutterError(
-          'Javascript mode must be enabled/unrestricted when calling runJavascriptReturningResult.'));
+      return Future<String>.error(
+        FlutterError(
+          'Javascript mode must be enabled/unrestricted when calling runJavascriptReturningResult.',
+        ),
+      );
     }
-    return _webViewPlatformController
-        .runJavascriptReturningResult(javaScriptString);
+    return _webViewPlatformController.runJavascriptReturningResult(
+      javaScriptString,
+    );
   }
 
   /// Returns the title of the currently loaded page.
@@ -552,7 +559,9 @@ class WebViewController {
 
   // This method assumes that no fields in `currentValue` are null.
   WebSettings _clearUnchangedWebSettings(
-      WebSettings currentValue, WebSettings newValue) {
+    WebSettings currentValue,
+    WebSettings newValue,
+  ) {
     assert(currentValue.javascriptMode != null);
     assert(currentValue.hasNavigationDelegate != null);
     assert(currentValue.hasProgressTracking != null);
@@ -598,7 +607,7 @@ class WebViewController {
     return channelNames;
   }
 
-// Throws an ArgumentError if `url` is not a valid URL string.
+  // Throws an ArgumentError if `url` is not a valid URL string.
   void _validateUrlString(String url) {
     try {
       final Uri uri = Uri.parse(url);
@@ -682,7 +691,8 @@ class WebViewCookieManager extends WebViewCookieManagerPlatform {
         WebViewCookieManagerPlatform.instance = WKWebViewCookieManager();
       } else {
         throw AssertionError(
-            'This platform is currently unsupported for webview_flutter_wkwebview.');
+          'This platform is currently unsupported for webview_flutter_wkwebview.',
+        );
       }
     }
     return WebViewCookieManagerPlatform.instance!;
