@@ -2,8 +2,9 @@
 // for details. All rights reserved. Use of this source code is governed by a
 // BSD-style license that can be found in the LICENSE file.
 
+import 'package:code_assets/code_assets.dart';
+import 'package:hooks/hooks.dart';
 import 'package:meta/meta.dart';
-import 'package:native_assets_cli/code_assets.dart';
 
 import 'cbuilder.dart';
 import 'clinker.dart';
@@ -25,6 +26,11 @@ abstract class CTool {
   /// File will be placed in [LinkInput.outputDirectory].
   final String name;
 
+  /// The package name to associate the asset with.
+  ///
+  /// If this is null, it defaults to the [HookInput.packageName].
+  final String? packageName;
+
   /// Asset identifier.
   ///
   /// Used to output the [CodeAsset].
@@ -67,9 +73,8 @@ abstract class CTool {
   /// Frameworks will not be automatically reported as dependencies of the hook.
   /// Frameworks can be mentioned by name if they are available on the system,
   /// so the file path is not known. If you're depending on your own frameworks
-  /// report them as dependencies of the hook by calling
-  /// [BuildOutputBuilder.addDependency] / [LinkOutputBuilder.addDependency]
-  /// manually.
+  /// report them as dependencies of the hook by adding them to
+  /// [HookOutputBuilder.dependencies] manually.
   final List<String> frameworks;
 
   /// The default [frameworks].
@@ -163,6 +168,7 @@ abstract class CTool {
 
   CTool({
     required this.name,
+    required this.packageName,
     required this.assetName,
     required this.sources,
     required this.includes,
