@@ -2,6 +2,8 @@
 // for details. All rights reserved. Use of this source code is governed by a
 // BSD-style license that can be found in the LICENSE file.
 
+import '../visitor/ast.dart';
+
 import 'binding.dart';
 import 'binding_string.dart';
 import 'utils.dart';
@@ -41,10 +43,7 @@ class Constant extends NoLookUpBinding {
     final s = StringBuffer();
     final constantName = name;
 
-    if (dartDoc != null) {
-      s.write(makeDartDoc(dartDoc!));
-    }
-
+    s.write(makeDartDoc(dartDoc));
     s.write('\nconst $rawType $constantName = $rawValue;\n\n');
 
     return BindingString(
@@ -52,9 +51,36 @@ class Constant extends NoLookUpBinding {
   }
 
   @override
-  void addDependencies(Set<Binding> dependencies) {
-    if (dependencies.contains(this)) return;
+  void visit(Visitation visitation) => visitation.visitConstant(this);
+}
 
-    dependencies.add(this);
-  }
+/// A [Constant] defined by an unnamed enum.
+class UnnamedEnumConstant extends Constant {
+  UnnamedEnumConstant({
+    super.usr,
+    super.originalName,
+    required super.name,
+    super.dartDoc,
+    required super.rawType,
+    required super.rawValue,
+  });
+
+  @override
+  void visit(Visitation visitation) =>
+      visitation.visitUnnamedEnumConstant(this);
+}
+
+/// A [Constant] defined by a macro.
+class MacroConstant extends Constant {
+  MacroConstant({
+    super.usr,
+    super.originalName,
+    required super.name,
+    super.dartDoc,
+    required super.rawType,
+    required super.rawValue,
+  });
+
+  @override
+  void visit(Visitation visitation) => visitation.visitMacroConstant(this);
 }
