@@ -13,7 +13,6 @@ import 'package:analyzer/dart/analysis/declared_variables.dart';
 import 'package:analyzer/dart/analysis/features.dart';
 import 'package:analyzer/dart/ast/token.dart';
 import 'package:analyzer/dart/element/element.dart';
-import 'package:analyzer/error/error.dart';
 import 'package:analyzer/error/listener.dart';
 import 'package:analyzer/file_system/file_system.dart';
 import 'package:analyzer/source/file_source.dart';
@@ -58,9 +57,7 @@ import 'package:pub_semver/pub_semver.dart';
 sealed class DirectiveState {
   final FileKind container;
 
-  DirectiveState({
-    required this.container,
-  });
+  DirectiveState({required this.container});
 
   void dispose() {}
 }
@@ -139,9 +136,7 @@ sealed class DirectiveUriWithSource extends DirectiveUriWithUri {
 final class DirectiveUriWithString extends DirectiveUri {
   final String relativeUriStr;
 
-  DirectiveUriWithString({
-    required this.relativeUriStr,
-  });
+  DirectiveUriWithString({required this.relativeUriStr});
 
   @override
   String toString() => relativeUriStr;
@@ -204,35 +199,31 @@ abstract class FileKind {
   List<PartIncludeState>? _partIncludes;
   List<LibraryImportState>? _docLibraryImports;
 
-  FileKind({
-    required this.file,
-  }) {
+  FileKind({required this.file}) {
     disposeLibraryCycle();
   }
 
   /// When [library] returns `null`, this getter is used to look at this
   /// file itself as a library.
   LibraryFileKind get asLibrary {
-    return LibraryFileKind(
-      file: file,
-      name: null,
-      recoveredFrom: this,
-    );
+    return LibraryFileKind(file: file, name: null, recoveredFrom: this);
   }
 
   /// The import states of each `@docImport` on the library directive or
   /// part-of directive.
   List<LibraryImportState> get docLibraryImports {
-    return _docLibraryImports ??=
-        _unlinkedDocImports.map(_buildLibraryImportState).toFixedList();
+    return _docLibraryImports ??= _unlinkedDocImports
+        .map(_buildLibraryImportState)
+        .toFixedList();
   }
 
   /// Returns the library in which this file should be analyzed.
   LibraryFileKind? get library;
 
   List<LibraryExportState> get libraryExports {
-    return _libraryExports ??=
-        file.unlinked2.exports.map<LibraryExportState>((unlinked) {
+    return _libraryExports ??= file.unlinked2.exports.map<LibraryExportState>((
+      unlinked,
+    ) {
       var uris = file._buildConfigurableDirectiveUris(unlinked);
       var selectedUri = uris.selected;
       switch (selectedUri) {
@@ -307,8 +298,9 @@ abstract class FileKind {
   }
 
   List<PartIncludeState> get partIncludes {
-    return _partIncludes ??=
-        file.unlinked2.parts.map<PartIncludeState>((unlinked) {
+    return _partIncludes ??= file.unlinked2.parts.map<PartIncludeState>((
+      unlinked,
+    ) {
       var uris = file._buildConfigurableDirectiveUris(unlinked);
       var selectedUri = uris.selected;
       switch (selectedUri) {
@@ -416,9 +408,9 @@ abstract class FileKind {
 
   /// Returns `true` if [file] is imported as a library.
   bool importsFile(FileState file) {
-    return libraryImports
-        .whereType<LibraryImportWithFile>()
-        .any((import) => import.importedFile == file);
+    return libraryImports.whereType<LibraryImportWithFile>().any(
+      (import) => import.importedFile == file,
+    );
   }
 
   /// Creates a [LibraryImportState] with the given unlinked [directive].
@@ -492,10 +484,10 @@ class FileState {
   /// The [FileSource] of the file with the [uri].
   final FileSource source;
 
-  /// The [WorkspacePackage] that contains this file.
+  /// The [WorkspacePackageImpl] that contains this file.
   ///
   /// It might be `null` if the file is outside of the workspace.
-  final WorkspacePackage? workspacePackage;
+  final WorkspacePackageImpl? workspacePackage;
 
   /// The [FeatureSet] for this file.
   ///
@@ -597,69 +589,37 @@ class FileState {
     return other is FileState && other.uri == uri;
   }
 
-  /// Returns either new, or cached parsed result for this file.
-  ParsedFileState getParsed({
-    required OperationPerformanceImpl performance,
-  }) {
-    var result = _fsState.parsedFileStateCache.get(this);
-    if (result != null) {
-      return result;
-    }
-
-    var errorListener = RecordingErrorListener();
-    var unit = parseCode(
-      code: content,
-      errorListener: errorListener,
-      performance: performance,
-    );
-
-    result = ParsedFileState(
-      code: content,
-      unit: unit,
-      errors: errorListener.errors,
-    );
-    _fsState.parsedFileStateCache.put(this, result);
-
-    return result;
-  }
-
   /// Return a new parsed unresolved [CompilationUnit].
   CompilationUnitImpl parse({
-    AnalysisErrorListener? errorListener,
+    DiagnosticOrErrorListener diagnosticListener =
+        DiagnosticListener.nullListener,
     required OperationPerformanceImpl performance,
   }) {
-    errorListener ??= AnalysisErrorListener.NULL_LISTENER;
     try {
       return parseCode(
         code: content,
-        errorListener: errorListener,
+        diagnosticListener: diagnosticListener,
         performance: performance,
       );
     } catch (exception, stackTrace) {
-      throw CaughtExceptionWithFiles(
-        exception,
-        stackTrace,
-        {path: content},
-      );
+      throw CaughtExceptionWithFiles(exception, stackTrace, {path: content});
     }
   }
 
   /// Parses given [code] with the same features as this file.
   CompilationUnitImpl parseCode({
     required String code,
-    required AnalysisErrorListener errorListener,
+    required DiagnosticOrErrorListener diagnosticListener,
     required OperationPerformanceImpl performance,
   }) {
     return performance.run('parseCode', (performance) {
       performance.getDataInt('length').add(code.length);
 
       CharSequenceReader reader = CharSequenceReader(code);
-      Scanner scanner = Scanner(source, reader, errorListener)
+      Scanner scanner = Scanner(source, reader, diagnosticListener)
         ..configureFeatures(
           featureSetForOverriding: featureSet,
-          featureSet: featureSet.restrictToVersion(
-            packageLanguageVersion,
-          ),
+          featureSet: featureSet.restrictToVersion(packageLanguageVersion),
         );
       Token token = scanner.tokenize(reportScannerErrors: false);
       LineInfo lineInfo = LineInfo(scanner.lineStarts);
@@ -670,7 +630,7 @@ class FileState {
 
       Parser parser = Parser(
         source,
-        errorListener,
+        diagnosticListener,
         featureSet: scanner.featureSet,
         lineInfo: lineInfo,
         languageVersion: languageVersion,
@@ -689,16 +649,13 @@ class FileState {
   /// consistent with the read content, including API signature.
   ///
   /// Return how the file changed since the last refresh.
-  FileStateRefreshResult refresh({
-    OperationPerformanceImpl? performance,
-  }) {
+  FileStateRefreshResult refresh({OperationPerformanceImpl? performance}) {
     performance ??= OperationPerformanceImpl('<root>');
     _invalidateCurrentUnresolvedData();
 
     var rawFileState = _fsState.fileContentStrategy.get(path);
     var contentChanged = _fileContent?.contentHash != rawFileState.contentHash;
     _fileContent = rawFileState;
-    _fsState.parsedFileStateCache.remove(this);
 
     // Prepare the unlinked bundle key.
     var previousUnlinkedKey = _unlinkedKey;
@@ -728,15 +685,13 @@ class FileState {
     _prefetchDirectReferences();
 
     for (var template in unlinked2.dartdocTemplates) {
-      _fsState.dartdocDirectiveInfo.addTemplate(
-        template.name,
-        template.value,
-      );
+      _fsState.dartdocDirectiveInfo.addTemplate(template.name, template.value);
     }
 
     // Prepare API signature.
     var newApiSignature = _unlinked2!.apiSignature;
-    bool apiSignatureChanged = _apiSignature != null &&
+    bool apiSignatureChanged =
+        _apiSignature != null &&
         !_equalByteLists(_apiSignature, newApiSignature);
     _apiSignature = newApiSignature;
 
@@ -801,9 +756,7 @@ class FileState {
 
     var relativeUri = uriCache.tryParse(relativeUriStr);
     if (relativeUri == null) {
-      return DirectiveUriWithString(
-        relativeUriStr: relativeUriStr,
-      );
+      return DirectiveUriWithString(relativeUriStr: relativeUriStr);
     }
 
     var absoluteUri = uriCache.resolveRelative(uri, relativeUri);
@@ -876,22 +829,19 @@ class FileState {
       return result;
     }
 
-    var unit = getParsed(
-      performance: performance,
-    ).unit;
+    var unit = parse(performance: performance);
 
     return performance.run('compute', (performance) {
-      var unlinkedUnit = performance.run(
-        'serializeAstUnlinked2',
-        (performance) {
-          return serializeAstUnlinked2(
-            unit,
-            exists: exists,
-            isDartCore: uriStr == 'dart:core',
-            performance: performance,
-          );
-        },
-      );
+      var unlinkedUnit = performance.run('serializeAstUnlinked2', (
+        performance,
+      ) {
+        return serializeAstUnlinked2(
+          unit,
+          exists: exists,
+          isDartCore: uriStr == 'dart:core',
+          performance: performance,
+        );
+      });
       var definedNames = computeDefinedNames(unit);
       var referencedNames = computeReferencedNames(unit);
       var subtypedNames = computeSubtypedNames(unit);
@@ -967,15 +917,9 @@ class FileState {
     var partOfNameDirective = unlinked2.partOfNameDirective;
     var partOfUriDirective = unlinked2.partOfUriDirective;
     if (libraryDirective != null) {
-      _kind = LibraryFileKind(
-        file: this,
-        name: libraryDirective.name,
-      );
+      _kind = LibraryFileKind(file: this, name: libraryDirective.name);
     } else if (partOfNameDirective != null) {
-      _kind = PartOfNameFileKind(
-        file: this,
-        unlinked: partOfNameDirective,
-      );
+      _kind = PartOfNameFileKind(file: this, unlinked: partOfNameDirective);
     } else if (partOfUriDirective != null) {
       var uriStr = partOfUriDirective.uri;
       var uriResolution = _fileForRelativeUri(uriStr);
@@ -993,10 +937,7 @@ class FileState {
           );
       }
     } else {
-      _kind = LibraryFileKind(
-        file: this,
-        name: null,
-      );
+      _kind = LibraryFileKind(file: this, name: null);
     }
   }
 
@@ -1006,19 +947,14 @@ class FileState {
     required bool isDartCore,
     required OperationPerformanceImpl performance,
   }) {
-    List<UnlinkedLibraryImportDirective> buildDocImports(
-      Directive directive,
-    ) {
+    List<UnlinkedLibraryImportDirective> buildDocImports(Directive directive) {
       var comment = directive.documentationComment;
       if (comment == null) {
         return const [];
       }
 
       return comment.docImports.map((docImport) {
-        return _serializeImport(
-          node: docImport.import,
-          isDocImport: true,
-        );
+        return _serializeImport(node: docImport.import, isDocImport: true);
       }).toFixedList();
     }
 
@@ -1034,10 +970,7 @@ class FileState {
         var builder = _serializeExport(directive);
         exports.add(builder);
       } else if (directive is ImportDirectiveImpl) {
-        var builder = _serializeImport(
-          node: directive,
-          isDocImport: false,
-        );
+        var builder = _serializeImport(node: directive, isDocImport: false);
         imports.add(builder);
         if (builder.uri == 'dart:core') {
           hasDartCoreImport = true;
@@ -1045,7 +978,7 @@ class FileState {
       } else if (directive is LibraryDirective) {
         libraryDirective = UnlinkedLibraryDirective(
           docImports: buildDocImports(directive),
-          name: directive.name2?.name,
+          name: directive.name?.name,
         );
       } else if (directive is PartDirective) {
         var unlinked = _serializePart(directive);
@@ -1098,12 +1031,10 @@ class FileState {
     }
 
     var dartdocDirectiveInfo = DartdocDirectiveInfo.extractFromUnit(unit);
-    var dartdocTemplates =
-        dartdocDirectiveInfo.templateMap.entries.map((entry) {
-      return UnlinkedDartdocTemplate(
-        name: entry.key,
-        value: entry.value,
-      );
+    var dartdocTemplates = dartdocDirectiveInfo.templateMap.entries.map((
+      entry,
+    ) {
+      return UnlinkedDartdocTemplate(name: entry.key, value: entry.value);
     }).toList();
 
     var apiSignature = performance.run('apiSignature', (performance) {
@@ -1230,6 +1161,7 @@ class FileState {
   static UnlinkedPartDirective _serializePart(PartDirective node) {
     return UnlinkedPartDirective(
       configurations: _serializeConfigurations(node.configurations),
+      partKeywordOffset: node.partKeyword.offset,
       uri: node.uri.stringValue,
     );
   }
@@ -1263,6 +1195,7 @@ class FileSystemState {
   final SourceFactory _sourceFactory;
   final Workspace? _workspace;
   final DeclaredVariables _declaredVariables;
+  final bool withFineDependencies;
   final Uint32List _saltForUnlinked;
   final Uint32List _saltForElements;
 
@@ -1324,12 +1257,6 @@ class FileSystemState {
   /// store here the instance to attach [_newFile] operations.
   OperationPerformanceImpl? newFileOperationPerformance;
 
-  /// We cache results of parsing [FileState]s because they might be useful
-  /// in the process of a single analysis operation. But after that, even
-  /// if these results are still valid, they are often never used again. So,
-  /// currently we clear the cache after each operation.
-  ParsedFileStateCache parsedFileStateCache = ParsedFileStateCache();
-
   FileSystemState(
     this._byteStore,
     this.resourceProvider,
@@ -1347,6 +1274,7 @@ class FileSystemState {
     required this.isGenerated,
     required this.onNewFile,
     required this.testData,
+    required this.withFineDependencies,
   }) : _analysisOptionsMap = analysisOptionsMap {
     _testView = FileSystemStateTestView(this);
   }
@@ -1499,12 +1427,7 @@ class FileSystemState {
         return null;
       }
 
-      file = _newFile(
-        resource,
-        path,
-        rewrittenUri,
-        performance: performance,
-      );
+      file = _newFile(resource, path, rewrittenUri, performance: performance);
     }
     return UriResolutionFile(file);
   }
@@ -1601,7 +1524,7 @@ class FileSystemState {
   FeatureSet _getFeatureSet(
     String path,
     Uri uri,
-    WorkspacePackage? workspacePackage,
+    WorkspacePackageImpl? workspacePackage,
     AnalysisOptionsImpl analysisOptions,
   ) {
     var workspacePackageExperiments = workspacePackage?.enabledExperiments;
@@ -1611,15 +1534,18 @@ class FileSystemState {
       );
     }
 
-    return featureSetProvider.getFeatureSet(path, uri,
-        contextFeatures: analysisOptions.contextFeatures,
-        nonPackageFeatureSet: analysisOptions.nonPackageFeatureSet);
+    return featureSetProvider.getFeatureSet(
+      path,
+      uri,
+      contextFeatures: analysisOptions.contextFeatures,
+      nonPackageFeatureSet: analysisOptions.nonPackageFeatureSet,
+    );
   }
 
   Version _getLanguageVersion(
     String path,
     Uri uri,
-    WorkspacePackage? workspacePackage,
+    WorkspacePackageImpl? workspacePackage,
     AnalysisOptionsImpl analysisOptions,
   ) {
     var workspaceLanguageVersion = workspacePackage?.languageVersion;
@@ -1627,8 +1553,11 @@ class FileSystemState {
       return workspaceLanguageVersion;
     }
 
-    return featureSetProvider.getLanguageVersion(path, uri,
-        nonPackageLanguageVersion: analysisOptions.nonPackageLanguageVersion);
+    return featureSetProvider.getLanguageVersion(
+      path,
+      uri,
+      nonPackageLanguageVersion: analysisOptions.nonPackageLanguageVersion,
+    );
   }
 
   FileState _newFile(
@@ -1638,14 +1567,30 @@ class FileSystemState {
     OperationPerformanceImpl? performance,
   }) {
     FileSource uriSource = FileSource(resource, uri);
-    WorkspacePackage? workspacePackage = _workspace?.findPackageFor(path);
+    WorkspacePackageImpl? workspacePackage = _workspace?.findPackageFor(path);
     AnalysisOptionsImpl analysisOptions = _getAnalysisOptions(resource);
-    FeatureSet featureSet =
-        _getFeatureSet(path, uri, workspacePackage, analysisOptions);
-    Version packageLanguageVersion =
-        _getLanguageVersion(path, uri, workspacePackage, analysisOptions);
-    var file = FileState._(this, path, uri, uriSource, workspacePackage,
-        featureSet, packageLanguageVersion, analysisOptions);
+    FeatureSet featureSet = _getFeatureSet(
+      path,
+      uri,
+      workspacePackage,
+      analysisOptions,
+    );
+    Version packageLanguageVersion = _getLanguageVersion(
+      path,
+      uri,
+      workspacePackage,
+      analysisOptions,
+    );
+    var file = FileState._(
+      this,
+      path,
+      uri,
+      uriSource,
+      workspacePackage,
+      featureSet,
+      packageLanguageVersion,
+      analysisOptions,
+    );
     _pathToFile[path] = file;
     _uriToFile[uri] = file;
     knownFilePaths.add(path);
@@ -1655,9 +1600,7 @@ class FileSystemState {
     performance ??= newFileOperationPerformance;
     performance ??= OperationPerformanceImpl('<root>');
     performance.run('fileState.refresh', (performance) {
-      file.refresh(
-        performance: performance,
-      );
+      file.refresh(performance: performance);
     });
 
     onNewFile(file);
@@ -1731,19 +1674,14 @@ class FileUriProperties {
     return const FileUriProperties._unknown();
   }
 
-  const FileUriProperties._dart({
-    required bool isInternal,
-  })  : _flags = _isDart | (isInternal ? _isDartInternal : 0),
-        packageName = null;
+  const FileUriProperties._dart({required bool isInternal})
+    : _flags = _isDart | (isInternal ? _isDartInternal : 0),
+      packageName = null;
 
-  FileUriProperties._package({
-    required this.packageName,
-    required bool isSrc,
-  }) : _flags = isSrc ? _isSrc : 0;
+  FileUriProperties._package({required this.packageName, required bool isSrc})
+    : _flags = isSrc ? _isSrc : 0;
 
-  const FileUriProperties._unknown()
-      : _flags = 0,
-        packageName = null;
+  const FileUriProperties._unknown() : _flags = 0, packageName = null;
 
   bool get isDart => (_flags & _isDart) != 0;
 
@@ -1872,6 +1810,13 @@ class LibraryFileKind extends LibraryOrAugmentationFileKind {
   /// The cache for [apiSignature].
   Uint8List? _apiSignature;
 
+  /// The cache for the library diagnostics bundle key.
+  ///
+  /// It is based on the content of all library files, plus other data that
+  /// affects diagnostics (analysis options, etc). But it does not include
+  /// signatures of dependencies.
+  String? diagnosticsBundleKey;
+
   LibraryCycle? _libraryCycle;
 
   LibraryFileKind({
@@ -1934,7 +1879,11 @@ class LibraryFileKind extends LibraryOrAugmentationFileKind {
   /// just this file.  If the library cycle is not known yet, compute it.
   LibraryCycle get libraryCycle {
     if (_libraryCycle == null) {
-      computeLibraryCycle(file._fsState._saltForElements, this);
+      computeLibraryCycle(
+        file._fsState.withFineDependencies,
+        file._fsState._saltForElements,
+        this,
+      );
     }
 
     return _libraryCycle!;
@@ -1948,6 +1897,7 @@ class LibraryFileKind extends LibraryOrAugmentationFileKind {
   @override
   void dispose() {
     file._fsState._libraryNameToFiles.remove(this);
+    invalidateDiagnosticsBundleKey();
     super.dispose();
   }
 
@@ -1961,6 +1911,10 @@ class LibraryFileKind extends LibraryOrAugmentationFileKind {
     _libraryCycle = cycle;
   }
 
+  void invalidateDiagnosticsBundleKey() {
+    diagnosticsBundleKey = null;
+  }
+
   @override
   String toString() {
     return 'LibraryFileKind($file)';
@@ -2081,48 +2035,12 @@ final class LibraryImportWithUriStr<U extends DirectiveUriWithString>
 }
 
 abstract class LibraryOrAugmentationFileKind extends FileKind {
-  LibraryOrAugmentationFileKind({
-    required super.file,
-  });
-}
-
-class ParsedFileState {
-  final String code;
-  final CompilationUnitImpl unit;
-  final List<AnalysisError> errors;
-
-  ParsedFileState({
-    required this.code,
-    required this.unit,
-    required this.errors,
-  });
-}
-
-class ParsedFileStateCache {
-  final Map<FileState, ParsedFileState> _map = Map.identity();
-
-  void clear() {
-    _map.clear();
-  }
-
-  ParsedFileState? get(FileState file) {
-    return _map[file];
-  }
-
-  void put(FileState file, ParsedFileState result) {
-    _map[file] = result;
-  }
-
-  void remove(FileState file) {
-    _map.remove(file);
-  }
+  LibraryOrAugmentationFileKind({required super.file});
 }
 
 /// The file has `part of` directive.
 sealed class PartFileKind extends FileKind {
-  PartFileKind({
-    required super.file,
-  });
+  PartFileKind({required super.file});
 
   /// Returns `true` if the `part of` directive confirms the [container].
   bool isPartOf(FileKind container);
@@ -2198,10 +2116,7 @@ final class PartIncludeWithUriStr<U extends DirectiveUriWithString>
 class PartOfNameFileKind extends PartFileKind {
   final UnlinkedPartOfNameDirective unlinked;
 
-  PartOfNameFileKind({
-    required super.file,
-    required this.unlinked,
-  });
+  PartOfNameFileKind({required super.file, required this.unlinked});
 
   /// Libraries with the same name as in [unlinked].
   List<LibraryFileKind> get libraries {
@@ -2262,10 +2177,7 @@ class PartOfNameFileKind extends PartFileKind {
 abstract class PartOfUriFileKind extends PartFileKind {
   final UnlinkedPartOfUriDirective unlinked;
 
-  PartOfUriFileKind({
-    required super.file,
-    required this.unlinked,
-  });
+  PartOfUriFileKind({required super.file, required this.unlinked});
 
   @override
   List<UnlinkedLibraryImportDirective> get _unlinkedDocImports {
@@ -2318,10 +2230,7 @@ class PartOfUriKnownFileKind extends PartOfUriFileKind {
 
 /// The file has `part of URI` directive, and the URI cannot be resolved.
 class PartOfUriUnknownFileKind extends PartOfUriFileKind {
-  PartOfUriUnknownFileKind({
-    required super.file,
-    required super.unlinked,
-  });
+  PartOfUriUnknownFileKind({required super.file, required super.unlinked});
 
   @override
   LibraryFileKind? get library => null;
