@@ -2,9 +2,8 @@
 // for details. All rights reserved. Use of this source code is governed by a
 // BSD-style license that can be found in the LICENSE file.
 
-import '../config.dart';
-import '../encoded_asset.dart';
-import '../extension.dart';
+import 'package:hooks/hooks.dart';
+
 import 'data_asset.dart';
 import 'validation.dart';
 
@@ -24,7 +23,7 @@ final class DataAssetsExtension implements ProtocolExtension {
   }
 
   void _setupConfig(HookInputBuilder input) {
-    input.config.addBuildAssetTypes(DataAssetType.typesForBuildAssetTypes);
+    input.config.addBuildAssetTypes([DataAssetType.type]);
   }
 
   @override
