@@ -16,13 +16,13 @@ bool isNotSerializableMarker(SimpleIdentifier node) {
 /// If [node] is fully serializable, returns it.
 /// Otherwise returns a marker node.
 ExpressionImpl replaceNotSerializableNode(ExpressionImpl node) {
-  final visitor = _IsSerializableNodeVisitor();
+  var visitor = _IsSerializableNodeVisitor();
   node.accept(visitor);
   if (visitor.result) {
     return node;
   }
   return SimpleIdentifierImpl(
-    StringToken(TokenType.STRING, _notSerializableName, -1),
+    token: StringToken(TokenType.STRING, _notSerializableName, -1),
   );
 }
 
