@@ -3,7 +3,8 @@
 // found in the LICENSE file.
 
 import '_capabilities_io.dart'
-  if (dart.library.js_util) '_capabilities_web.dart' as capabilities;
+    if (dart.library.js_interop) '_capabilities_web.dart'
+    as capabilities;
 
 /// Returns true if the application is using CanvasKit.
 ///
