@@ -14,6 +14,8 @@ import 'dart:async';
 /// rare occasions you want the ability to switch to an asynchronous model. **In
 /// general use of this class should be avoided as it is very difficult to debug
 /// such bimodal behavior.**
+///
+/// A [SynchronousFuture] will never complete with an error.
 class SynchronousFuture<T> implements Future<T> {
   /// Creates a synchronous future.
   ///
@@ -34,19 +36,19 @@ class SynchronousFuture<T> implements Future<T> {
   }
 
   @override
-  Future<T> catchError(Function onError, { bool Function(Object error)? test }) => Completer<T>().future;
+  Future<T> catchError(Function onError, {bool Function(Object error)? test}) =>
+      Completer<T>().future;
 
   @override
-  Future<R> then<R>(FutureOr<R> Function(T value) onValue, { Function? onError }) {
-    final dynamic result = onValue(_value);
-    if (result is Future<R>) {
-      return result;
-    }
-    return SynchronousFuture<R>(result as R);
+  Future<R> then<R>(FutureOr<R> Function(T value) onValue, {Function? onError}) {
+    return switch (onValue(_value)) {
+      final Future<R> result => result,
+      final R result => SynchronousFuture<R>(result),
+    };
   }
 
   @override
-  Future<T> timeout(Duration timeLimit, { FutureOr<T> Function()? onTimeout }) {
+  Future<T> timeout(Duration timeLimit, {FutureOr<T> Function()? onTimeout}) {
     return Future<T>.value(_value).timeout(timeLimit, onTimeout: onTimeout);
   }
 
