@@ -2,6 +2,18 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
+/// @docImport 'card.dart';
+/// @docImport 'color_scheme.dart';
+/// @docImport 'colors.dart';
+/// @docImport 'ink_decoration.dart';
+/// @docImport 'ink_highlight.dart';
+/// @docImport 'ink_splash.dart';
+/// @docImport 'ink_well.dart';
+/// @docImport 'list_tile.dart';
+/// @docImport 'material_button.dart';
+/// @docImport 'mergeable_material.dart';
+library;
+
 import 'package:flutter/foundation.dart';
 import 'package:flutter/rendering.dart';
 import 'package:flutter/widgets.dart';
@@ -48,7 +60,7 @@ enum MaterialType {
   ///
   /// Prefer using the [Ink] widget for showing ink effects on top of opaque
   /// widgets.
-  transparency
+  transparency,
 }
 
 /// The border radii used by the various kinds of material in Material Design.
@@ -192,6 +204,7 @@ class Material extends StatefulWidget {
     this.clipBehavior = Clip.none,
     this.animationDuration = kThemeChangeDuration,
     this.child,
+    this.animateColor = false,
   }) : assert(elevation >= 0.0),
        assert(!(shape != null && borderRadius != null)),
        assert(!(identical(type, MaterialType.circle) && (borderRadius != null || shape != null)));
@@ -206,6 +219,9 @@ class Material extends StatefulWidget {
   /// the shape is rectangular, and the default color.
   final MaterialType type;
 
+  /// Whether the color should be animated.
+  final bool animateColor;
+
   /// {@template flutter.material.material.elevation}
   /// The z-coordinate at which to place this material relative to its parent.
   ///
@@ -420,8 +436,12 @@ class Material extends StatefulWidget {
     properties.add(ColorProperty('surfaceTintColor', surfaceTintColor, defaultValue: null));
     textStyle?.debugFillProperties(properties, prefix: 'textStyle.');
     properties.add(DiagnosticsProperty<ShapeBorder>('shape', shape, defaultValue: null));
-    properties.add(DiagnosticsProperty<bool>('borderOnForeground', borderOnForeground, defaultValue: true));
-    properties.add(DiagnosticsProperty<BorderRadiusGeometry>('borderRadius', borderRadius, defaultValue: null));
+    properties.add(
+      DiagnosticsProperty<bool>('borderOnForeground', borderOnForeground, defaultValue: true),
+    );
+    properties.add(
+      DiagnosticsProperty<BorderRadiusGeometry>('borderRadius', borderRadius, defaultValue: null),
+    );
   }
 
   /// The default radius of an ink splash in logical pixels.
@@ -434,13 +454,15 @@ class _MaterialState extends State<Material> with TickerProviderStateMixin {
   @override
   Widget build(BuildContext context) {
     final ThemeData theme = Theme.of(context);
-    final Color? backgroundColor = widget.color ?? switch (widget.type) {
-      MaterialType.canvas => theme.canvasColor,
-      MaterialType.card => theme.cardColor,
-      MaterialType.button || MaterialType.circle || MaterialType.transparency => null,
-    };
-    final Color modelShadowColor = widget.shadowColor
-        ?? (theme.useMaterial3 ? theme.colorScheme.shadow : theme.shadowColor);
+    final Color? backgroundColor =
+        widget.color ??
+        switch (widget.type) {
+          MaterialType.canvas => theme.canvasColor,
+          MaterialType.card => theme.cardColor,
+          MaterialType.button || MaterialType.circle || MaterialType.transparency => null,
+        };
+    final Color modelShadowColor =
+        widget.shadowColor ?? (theme.useMaterial3 ? theme.colorScheme.shadow : theme.shadowColor);
     assert(
       backgroundColor != null || widget.type == MaterialType.transparency,
       'If Material type is not MaterialType.transparency, a color must '
@@ -459,7 +481,8 @@ class _MaterialState extends State<Material> with TickerProviderStateMixin {
     }
     contents = NotificationListener<LayoutChangedNotification>(
       onNotification: (LayoutChangedNotification notification) {
-        final _RenderInkFeatures renderer = _inkFeatureRenderer.currentContext!.findRenderObject()! as _RenderInkFeatures;
+        final _RenderInkFeatures renderer =
+            _inkFeatureRenderer.currentContext!.findRenderObject()! as _RenderInkFeatures;
         renderer._didChangeLayout();
         return false;
       },
@@ -487,8 +510,12 @@ class _MaterialState extends State<Material> with TickerProviderStateMixin {
     // slow-path to be noticeable in the construction site of Material.
     if (widget.type == MaterialType.canvas && shape == null) {
       final Color color = theme.useMaterial3
-        ? ElevationOverlay.applySurfaceTint(backgroundColor!, widget.surfaceTintColor, widget.elevation)
-        : ElevationOverlay.applyOverlay(context, backgroundColor!, widget.elevation);
+          ? ElevationOverlay.applySurfaceTint(
+              backgroundColor!,
+              widget.surfaceTintColor,
+              widget.elevation,
+            )
+          : ElevationOverlay.applyOverlay(context, backgroundColor!, widget.elevation);
 
       return AnimatedPhysicalModel(
         curve: Curves.fastOutSlowIn,
@@ -497,7 +524,7 @@ class _MaterialState extends State<Material> with TickerProviderStateMixin {
         elevation: widget.elevation,
         color: color,
         shadowColor: modelShadowColor,
-        animateColor: false,
+        animateColor: widget.animateColor,
         child: contents,
       );
     }
@@ -506,16 +533,13 @@ class _MaterialState extends State<Material> with TickerProviderStateMixin {
       MaterialType.circle => const CircleBorder(),
       MaterialType.canvas || MaterialType.transparency => const RoundedRectangleBorder(),
       MaterialType.card || MaterialType.button => const RoundedRectangleBorder(
-          borderRadius: BorderRadius.all(Radius.circular(2.0)),
-        ),
+        borderRadius: BorderRadius.all(Radius.circular(2.0)),
+      ),
     };
 
     if (widget.type == MaterialType.transparency) {
       return ClipPath(
-        clipper: ShapeBorderClipper(
-          shape: shape,
-          textDirection: Directionality.maybeOf(context),
-        ),
+        clipper: ShapeBorderClipper(shape: shape, textDirection: Directionality.maybeOf(context)),
         clipBehavior: widget.clipBehavior,
         child: _ShapeBorderPaint(shape: shape, child: contents),
       );
@@ -544,7 +568,7 @@ class _RenderInkFeatures extends RenderProxyBox implements MaterialInkController
     this.color,
   }) : super(child);
 
-  // This class should exist in a 1:1 relationship with a MaterialState object,
+  // This class should exist in a 1:1 relationship with a WidgetState object,
   // since there's no current support for dynamically changing the ticker
   // provider.
   @override
@@ -552,7 +576,7 @@ class _RenderInkFeatures extends RenderProxyBox implements MaterialInkController
 
   // This is here to satisfy the MaterialInkController contract.
   // The actual painting of this color is done by a Container in the
-  // MaterialState build method.
+  // WidgetState build method.
   @override
   Color? color;
 
@@ -565,6 +589,7 @@ class _RenderInkFeatures extends RenderProxyBox implements MaterialInkController
     }
     return null;
   }
+
   List<InkFeature>? _inkFeatures;
 
   @override
@@ -619,8 +644,8 @@ class _InkFeatures extends SingleChildRenderObjectWidget {
     super.child,
   });
 
-  // This widget must be owned by a MaterialState, which must be provided as the vsync.
-  // This relationship must be 1:1 and cannot change for the lifetime of the MaterialState.
+  // This widget must be owned by a WidgetState, which must be provided as the vsync.
+  // This relationship must be 1:1 and cannot change for the lifetime of the WidgetState.
 
   final Color? color;
 
@@ -630,17 +655,14 @@ class _InkFeatures extends SingleChildRenderObjectWidget {
 
   @override
   _RenderInkFeatures createRenderObject(BuildContext context) {
-    return _RenderInkFeatures(
-      color: color,
-      absorbHitTest: absorbHitTest,
-      vsync: vsync,
-    );
+    return _RenderInkFeatures(color: color, absorbHitTest: absorbHitTest, vsync: vsync);
   }
 
   @override
   void updateRenderObject(BuildContext context, _RenderInkFeatures renderObject) {
-    renderObject..color = color
-                ..absorbHitTest = absorbHitTest;
+    renderObject
+      ..color = color
+      ..absorbHitTest = absorbHitTest;
     assert(vsync == renderObject.vsync);
   }
 }
@@ -657,15 +679,7 @@ abstract class InkFeature {
     required this.referenceBox,
     this.onRemoved,
   }) : _controller = controller as _RenderInkFeatures {
-    // TODO(polina-c): stop duplicating code across disposables
-    // https://github.com/flutter/flutter/issues/137435
-    if (kFlutterMemoryAllocationsEnabled) {
-      FlutterMemoryAllocations.instance.dispatchObjectCreated(
-        library: 'package:flutter/material.dart',
-        className: '$InkFeature',
-        object: this,
-      );
-    }
+    assert(debugMaybeDispatchCreated('material', 'InkFeature', this));
   }
 
   /// The [MaterialInkController] associated with this [InkFeature].
@@ -691,11 +705,7 @@ abstract class InkFeature {
       _debugDisposed = true;
       return true;
     }());
-    // TODO(polina-c): stop duplicating code across disposables
-    // https://github.com/flutter/flutter/issues/137435
-    if (kFlutterMemoryAllocationsEnabled) {
-      FlutterMemoryAllocations.instance.dispatchObjectDisposed(object: this);
-    }
+    assert(debugMaybeDispatchDisposed(this));
     _controller._removeFeature(this);
     onRemoved?.call();
   }
@@ -706,10 +716,7 @@ abstract class InkFeature {
   // Returns null if either `fromRenderObject` or `toRenderObject` is not in the
   // same render tree, or either of them is in an offscreen subtree (see
   // RenderObject.paintsChild).
-  static Matrix4? _getPaintTransform(
-    RenderObject fromRenderObject,
-    RenderObject toRenderObject,
-  ) {
+  static Matrix4? _getPaintTransform(RenderObject fromRenderObject, RenderObject toRenderObject) {
     // The paths to fromRenderObject and toRenderObject's common ancestor.
     final List<RenderObject> fromPath = <RenderObject>[fromRenderObject];
     final List<RenderObject> toPath = <RenderObject>[toRenderObject];
@@ -873,28 +880,35 @@ class _MaterialInteriorState extends AnimatedWidgetBaseState<_MaterialInterior>
 
   @override
   void forEachTween(TweenVisitor<dynamic> visitor) {
-    _elevation = visitor(
-      _elevation,
-      widget.elevation,
-      (dynamic value) => Tween<double>(begin: value as double),
-    ) as Tween<double>?;
-    _shadowColor = visitor(
-      _shadowColor,
-      widget.shadowColor,
-      (dynamic value) => ColorTween(begin: value as Color),
-    ) as ColorTween?;
-    _surfaceTintColor = widget.surfaceTintColor != null
-      ? visitor(
-          _surfaceTintColor,
-          widget.surfaceTintColor,
+    _elevation =
+        visitor(
+              _elevation,
+              widget.elevation,
+              (dynamic value) => Tween<double>(begin: value as double),
+            )
+            as Tween<double>?;
+    _shadowColor =
+        visitor(
+              _shadowColor,
+              widget.shadowColor,
               (dynamic value) => ColorTween(begin: value as Color),
-        ) as ColorTween?
-      : null;
-    _border = visitor(
-      _border,
-      widget.shape,
-      (dynamic value) => ShapeBorderTween(begin: value as ShapeBorder),
-    ) as ShapeBorderTween?;
+            )
+            as ColorTween?;
+    _surfaceTintColor = widget.surfaceTintColor != null
+        ? visitor(
+                _surfaceTintColor,
+                widget.surfaceTintColor,
+                (dynamic value) => ColorTween(begin: value as Color),
+              )
+              as ColorTween?
+        : null;
+    _border =
+        visitor(
+              _border,
+              widget.shape,
+              (dynamic value) => ShapeBorderTween(begin: value as ShapeBorder),
+            )
+            as ShapeBorderTween?;
   }
 
   @override
@@ -902,15 +916,16 @@ class _MaterialInteriorState extends AnimatedWidgetBaseState<_MaterialInterior>
     final ShapeBorder shape = _border!.evaluate(animation)!;
     final double elevation = _elevation!.evaluate(animation);
     final Color color = Theme.of(context).useMaterial3
-      ? ElevationOverlay.applySurfaceTint(widget.color, _surfaceTintColor?.evaluate(animation), elevation)
-      : ElevationOverlay.applyOverlay(context, widget.color, elevation);
+        ? ElevationOverlay.applySurfaceTint(
+            widget.color,
+            _surfaceTintColor?.evaluate(animation),
+            elevation,
+          )
+        : ElevationOverlay.applyOverlay(context, widget.color, elevation);
     final Color shadowColor = _shadowColor!.evaluate(animation)!;
 
     return PhysicalShape(
-      clipper: ShapeBorderClipper(
-        shape: shape,
-        textDirection: Directionality.maybeOf(context),
-      ),
+      clipper: ShapeBorderClipper(shape: shape, textDirection: Directionality.maybeOf(context)),
       clipBehavior: widget.clipBehavior,
       elevation: elevation,
       color: color,
@@ -938,8 +953,12 @@ class _ShapeBorderPaint extends StatelessWidget {
   @override
   Widget build(BuildContext context) {
     return CustomPaint(
-      painter: borderOnForeground ? null : _ShapeBorderPainter(shape, Directionality.maybeOf(context)),
-      foregroundPainter: borderOnForeground ? _ShapeBorderPainter(shape, Directionality.maybeOf(context)) : null,
+      painter: borderOnForeground
+          ? null
+          : _ShapeBorderPainter(shape, Directionality.maybeOf(context)),
+      foregroundPainter: borderOnForeground
+          ? _ShapeBorderPainter(shape, Directionality.maybeOf(context))
+          : null,
       child: child,
     );
   }
