@@ -2,12 +2,13 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
+/// @docImport 'ink_well.dart';
+library;
+
 import 'package:flutter/foundation.dart';
 import 'package:flutter/widgets.dart';
 
-import 'material_state.dart';
-
-/// Mixin for [State] classes that require knowledge of changing [MaterialState]
+/// Mixin for [State] classes that require knowledge of changing [WidgetState]
 /// values for their child widgets.
 ///
 /// This mixin does nothing by mere application to a [State] class, but is
@@ -15,18 +16,18 @@ import 'material_state.dart';
 /// [GestureDetector], [MouseRegion], or [Focus] widgets. Instead of manually
 /// creating handlers for each type of user interaction, such [State] classes can
 /// instead provide a `ValueChanged<bool>` function and allow [MaterialStateMixin]
-/// to manage the set of active [MaterialState]s, and the calling of [setState]
+/// to manage the set of active [WidgetState]s, and the calling of [setState]
 /// as necessary.
 ///
 /// {@tool snippet}
 /// This example shows how to write a [StatefulWidget] that uses the
-/// [MaterialStateMixin] class to watch [MaterialState] values.
+/// [MaterialStateMixin] class to watch [WidgetState] values.
 ///
 /// ```dart
 /// class MyWidget extends StatefulWidget {
 ///   const MyWidget({super.key, required this.color, required this.child});
 ///
-///   final MaterialStateColor color;
+///   final WidgetStateColor color;
 ///   final Widget child;
 ///
 ///   @override
@@ -37,7 +38,7 @@ import 'material_state.dart';
 ///   @override
 ///   Widget build(BuildContext context) {
 ///     return InkWell(
-///       onFocusChange: updateMaterialState(MaterialState.focused),
+///       onFocusChange: updateMaterialState(WidgetState.focused),
 ///       child: ColoredBox(
 ///         color: widget.color.resolve(materialStates),
 ///         child: widget.child,
@@ -49,8 +50,8 @@ import 'material_state.dart';
 /// {@end-tool}
 @optionalTypeArgs
 mixin MaterialStateMixin<T extends StatefulWidget> on State<T> {
-  /// Managed set of active [MaterialState] values; designed to be passed to
-  /// [MaterialStateProperty.resolve] methods.
+  /// Managed set of active [WidgetState] values; designed to be passed to
+  /// [WidgetStateProperty.resolve] methods.
   ///
   /// To mutate and have [setState] called automatically for you, use
   /// [setMaterialState], [addMaterialState], or [removeMaterialState]. Directly
@@ -58,17 +59,17 @@ mixin MaterialStateMixin<T extends StatefulWidget> on State<T> {
   /// list without calling [setState] (and thus triggering a re-render).
   ///
   /// To check for a single condition, convenience getters [isPressed], [isHovered],
-  /// [isFocused], etc, are available for each [MaterialState] value.
+  /// [isFocused], etc, are available for each [WidgetState] value.
   @protected
-  Set<MaterialState> materialStates = <MaterialState>{};
+  Set<WidgetState> materialStates = <WidgetState>{};
 
-  /// Callback factory which accepts a [MaterialState] value and returns a
+  /// Callback factory which accepts a [WidgetState] value and returns a
   /// closure to mutate [materialStates] and call [setState].
   ///
   /// Accepts an optional second named parameter, `onChanged`, which allows
   /// arbitrary functionality to be wired through the [MaterialStateMixin].
   /// If supplied, the [onChanged] function is only called when child widgets
-  /// report events that make changes to the current set of [MaterialState]s.
+  /// report events that make changes to the current set of [WidgetState]s.
   ///
   /// {@tool snippet}
   /// This example shows how to use the [updateMaterialState] callback factory
@@ -92,7 +93,7 @@ mixin MaterialStateMixin<T extends StatefulWidget> on State<T> {
   ///       color: isPressed ? Colors.black : Colors.white,
   ///       child: InkWell(
   ///         onHighlightChanged: updateMaterialState(
-  ///           MaterialState.pressed,
+  ///           WidgetState.pressed,
   ///           onChanged: (bool val) {
   ///             if (val) {
   ///               widget.onPressed?.call();
@@ -106,7 +107,7 @@ mixin MaterialStateMixin<T extends StatefulWidget> on State<T> {
   /// ```
   /// {@end-tool}
   @protected
-  ValueChanged<bool> updateMaterialState(MaterialState key, {ValueChanged<bool>? onChanged}) {
+  ValueChanged<bool> updateMaterialState(WidgetState key, {ValueChanged<bool>? onChanged}) {
     return (bool value) {
       if (materialStates.contains(key) == value) {
         return;
@@ -116,55 +117,61 @@ mixin MaterialStateMixin<T extends StatefulWidget> on State<T> {
     };
   }
 
-  /// Mutator to mark a [MaterialState] value as either active or inactive.
+  /// Mutator to mark a [WidgetState] value as either active or inactive.
   @protected
-  void setMaterialState(MaterialState state, bool isSet) {
+  void setMaterialState(WidgetState state, bool isSet) {
     return isSet ? addMaterialState(state) : removeMaterialState(state);
   }
 
-  /// Mutator to mark a [MaterialState] value as active.
+  /// Mutator to mark a [WidgetState] value as active.
   @protected
-  void addMaterialState(MaterialState state) {
+  void addMaterialState(WidgetState state) {
     if (materialStates.add(state)) {
-      setState((){});
+      setState(() {});
     }
   }
 
-  /// Mutator to mark a [MaterialState] value as inactive.
+  /// Mutator to mark a [WidgetState] value as inactive.
   @protected
-  void removeMaterialState(MaterialState state) {
+  void removeMaterialState(WidgetState state) {
     if (materialStates.remove(state)) {
-      setState((){});
+      setState(() {});
     }
   }
 
-  /// Getter for whether this class considers [MaterialState.disabled] to be active.
-  bool get isDisabled => materialStates.contains(MaterialState.disabled);
+  /// Getter for whether this class considers [WidgetState.disabled] to be active.
+  bool get isDisabled => materialStates.contains(WidgetState.disabled);
 
-  /// Getter for whether this class considers [MaterialState.dragged] to be active.
-  bool get isDragged => materialStates.contains(MaterialState.dragged);
+  /// Getter for whether this class considers [WidgetState.dragged] to be active.
+  bool get isDragged => materialStates.contains(WidgetState.dragged);
 
-  /// Getter for whether this class considers [MaterialState.error] to be active.
-  bool get isErrored => materialStates.contains(MaterialState.error);
+  /// Getter for whether this class considers [WidgetState.error] to be active.
+  bool get isErrored => materialStates.contains(WidgetState.error);
 
-  /// Getter for whether this class considers [MaterialState.focused] to be active.
-  bool get isFocused => materialStates.contains(MaterialState.focused);
+  /// Getter for whether this class considers [WidgetState.focused] to be active.
+  bool get isFocused => materialStates.contains(WidgetState.focused);
 
-  /// Getter for whether this class considers [MaterialState.hovered] to be active.
-  bool get isHovered => materialStates.contains(MaterialState.hovered);
+  /// Getter for whether this class considers [WidgetState.hovered] to be active.
+  bool get isHovered => materialStates.contains(WidgetState.hovered);
 
-  /// Getter for whether this class considers [MaterialState.pressed] to be active.
-  bool get isPressed => materialStates.contains(MaterialState.pressed);
+  /// Getter for whether this class considers [WidgetState.pressed] to be active.
+  bool get isPressed => materialStates.contains(WidgetState.pressed);
 
-  /// Getter for whether this class considers [MaterialState.scrolledUnder] to be active.
-  bool get isScrolledUnder => materialStates.contains(MaterialState.scrolledUnder);
+  /// Getter for whether this class considers [WidgetState.scrolledUnder] to be active.
+  bool get isScrolledUnder => materialStates.contains(WidgetState.scrolledUnder);
 
-  /// Getter for whether this class considers [MaterialState.selected] to be active.
-  bool get isSelected => materialStates.contains(MaterialState.selected);
+  /// Getter for whether this class considers [WidgetState.selected] to be active.
+  bool get isSelected => materialStates.contains(WidgetState.selected);
 
   @override
   void debugFillProperties(DiagnosticPropertiesBuilder properties) {
     super.debugFillProperties(properties);
-    properties.add(DiagnosticsProperty<Set<MaterialState>>('materialStates', materialStates, defaultValue: <MaterialState>{}));
+    properties.add(
+      DiagnosticsProperty<Set<WidgetState>>(
+        'materialStates',
+        materialStates,
+        defaultValue: <WidgetState>{},
+      ),
+    );
   }
 }
