@@ -36,8 +36,9 @@ Color _sample(List<Color> colors, List<double> stops, double t) {
   final int index = stops.lastIndexWhere((double s) => s <= t);
   assert(index != -1);
   return Color.lerp(
-      colors[index], colors[index + 1],
-      (t - stops[index]) / (stops[index + 1] - stops[index]),
+    colors[index],
+    colors[index + 1],
+    (t - stops[index]) / (stops[index + 1] - stops[index]),
   )!;
 }
 
@@ -56,9 +57,12 @@ _ColorsAndStops _interpolateColorsAndStops(
     ..addAll(aStops)
     ..addAll(bStops);
   final List<double> interpolatedStops = stops.toList(growable: false);
-  final List<Color> interpolatedColors = interpolatedStops.map<Color>(
-          (double stop) => Color.lerp(_sample(aColors, aStops, stop), _sample(bColors, bStops, stop), t)!,
-  ).toList(growable: false);
+  final List<Color> interpolatedColors = interpolatedStops
+      .map<Color>(
+        (double stop) =>
+            Color.lerp(_sample(aColors, aStops, stop), _sample(bColors, bStops, stop), t)!,
+      )
+      .toList(growable: false);
   return _ColorsAndStops(interpolatedColors, interpolatedStops);
 }
 
@@ -116,7 +120,7 @@ class GradientRotation extends GradientTransform {
     final double originY = -sinRadians * center.dx + oneMinusCosRadians * center.dy;
 
     return Matrix4.identity()
-      ..translate(originX, originY)
+      ..translateByDouble(originX, originY, 0, 1)
       ..rotateZ(radians);
   }
 
@@ -128,8 +132,7 @@ class GradientRotation extends GradientTransform {
     if (other.runtimeType != runtimeType) {
       return false;
     }
-    return other is GradientRotation
-        && other.radians == radians;
+    return other is GradientRotation && other.radians == radians;
   }
 
   @override
@@ -167,11 +170,7 @@ abstract class Gradient {
   /// that starts from a position of 6 o'clock instead of 3 o'clock, assuming
   /// no other rotation or perspective transformations have been applied to the
   /// [Canvas]. If null, no transformation is applied.
-  const Gradient({
-    required this.colors,
-    this.stops,
-    this.transform,
-  });
+  const Gradient({required this.colors, this.stops, this.transform});
 
   /// The colors the gradient should obtain at each of the stops.
   ///
@@ -211,11 +210,7 @@ abstract class Gradient {
     }
     assert(colors.length >= 2, 'colors list must have at least two colors');
     final double separation = 1.0 / (colors.length - 1);
-    return List<double>.generate(
-      colors.length,
-      (int index) => index * separation,
-      growable: false,
-    );
+    return List<double>.generate(colors.length, (int index) => index * separation, growable: false);
   }
 
   /// Creates a [Shader] for this gradient to fill the given rect.
@@ -227,7 +222,7 @@ abstract class Gradient {
   /// The shader's transform will be resolved from the [transform] of this
   /// gradient.
   @factory
-  Shader createShader(Rect rect, { TextDirection? textDirection });
+  Shader createShader(Rect rect, {TextDirection? textDirection});
 
   /// Returns a new gradient with its properties scaled by the given factor.
   ///
@@ -240,6 +235,9 @@ abstract class Gradient {
   /// Typically this is the same as interpolating from null (with [lerp]).
   Gradient scale(double factor);
 
+  /// Returns a new [Gradient] with each color set to the given opacity.
+  Gradient withOpacity(double opacity);
+
   /// Linearly interpolates from another [Gradient] to `this`.
   ///
   /// When implementing this method in subclasses, return null if this class
@@ -431,11 +429,14 @@ class LinearGradient extends Gradient {
   final TileMode tileMode;
 
   @override
-  Shader createShader(Rect rect, { TextDirection? textDirection }) {
+  Shader createShader(Rect rect, {TextDirection? textDirection}) {
     return ui.Gradient.linear(
       begin.resolve(textDirection).withinRect(rect),
       end.resolve(textDirection).withinRect(rect),
-      colors, _impliedStops(), tileMode, _resolveTransform(rect, textDirection),
+      colors,
+      _impliedStops(),
+      tileMode,
+      _resolveTransform(rect, textDirection),
     );
   }
 
@@ -456,16 +457,16 @@ class LinearGradient extends Gradient {
 
   @override
   Gradient? lerpFrom(Gradient? a, double t) {
-    if (a == null || (a is LinearGradient)) {
-      return LinearGradient.lerp(a as LinearGradient?, this, t);
+    if (a is LinearGradient?) {
+      return LinearGradient.lerp(a, this, t);
     }
     return super.lerpFrom(a, t);
   }
 
   @override
   Gradient? lerpTo(Gradient? b, double t) {
-    if (b == null || (b is LinearGradient)) {
-      return LinearGradient.lerp(this, b as LinearGradient?, t);
+    if (b is LinearGradient?) {
+      return LinearGradient.lerp(this, b, t);
     }
     return super.lerpTo(b, t);
   }
@@ -500,11 +501,11 @@ class LinearGradient extends Gradient {
       return a.scale(1.0 - t);
     }
     final _ColorsAndStops interpolated = _interpolateColorsAndStops(
-        a.colors,
-        a._impliedStops(),
-        b.colors,
-        b._impliedStops(),
-        t,
+      a.colors,
+      a._impliedStops(),
+      b.colors,
+      b._impliedStops(),
+      t,
     );
     return LinearGradient(
       begin: AlignmentGeometry.lerp(a.begin, b.begin, t)!,
@@ -524,13 +525,13 @@ class LinearGradient extends Gradient {
     if (other.runtimeType != runtimeType) {
       return false;
     }
-    return other is LinearGradient
-        && other.begin == begin
-        && other.end == end
-        && other.tileMode == tileMode
-        && other.transform == transform
-        && listEquals<Color>(other.colors, colors)
-        && listEquals<double>(other.stops, stops);
+    return other is LinearGradient &&
+        other.begin == begin &&
+        other.end == end &&
+        other.tileMode == tileMode &&
+        other.transform == transform &&
+        listEquals<Color>(other.colors, colors) &&
+        listEquals<double>(other.stops, stops);
   }
 
   @override
@@ -556,6 +557,18 @@ class LinearGradient extends Gradient {
 
     return '${objectRuntimeType(this, 'LinearGradient')}(${description.join(', ')})';
   }
+
+  @override
+  LinearGradient withOpacity(double opacity) {
+    return LinearGradient(
+      begin: begin,
+      end: end,
+      colors: <Color>[for (final Color color in colors) color.withOpacity(opacity)],
+      stops: stops,
+      tileMode: tileMode,
+      transform: transform,
+    );
+  }
 }
 
 /// A 2D radial gradient.
@@ -705,11 +718,13 @@ class RadialGradient extends Gradient {
   final double focalRadius;
 
   @override
-  Shader createShader(Rect rect, { TextDirection? textDirection }) {
+  Shader createShader(Rect rect, {TextDirection? textDirection}) {
     return ui.Gradient.radial(
       center.resolve(textDirection).withinRect(rect),
       radius * rect.shortestSide,
-      colors, _impliedStops(), tileMode,
+      colors,
+      _impliedStops(),
+      tileMode,
       _resolveTransform(rect, textDirection),
       focal?.resolve(textDirection).withinRect(rect),
       focalRadius * rect.shortestSide,
@@ -735,16 +750,16 @@ class RadialGradient extends Gradient {
 
   @override
   Gradient? lerpFrom(Gradient? a, double t) {
-    if (a == null || (a is RadialGradient)) {
-      return RadialGradient.lerp(a as RadialGradient?, this, t);
+    if (a is RadialGradient?) {
+      return RadialGradient.lerp(a, this, t);
     }
     return super.lerpFrom(a, t);
   }
 
   @override
   Gradient? lerpTo(Gradient? b, double t) {
-    if (b == null || (b is RadialGradient)) {
-      return RadialGradient.lerp(this, b as RadialGradient?, t);
+    if (b is RadialGradient?) {
+      return RadialGradient.lerp(this, b, t);
     }
     return super.lerpTo(b, t);
   }
@@ -779,11 +794,11 @@ class RadialGradient extends Gradient {
       return a.scale(1.0 - t);
     }
     final _ColorsAndStops interpolated = _interpolateColorsAndStops(
-        a.colors,
-        a._impliedStops(),
-        b.colors,
-        b._impliedStops(),
-        t,
+      a.colors,
+      a._impliedStops(),
+      b.colors,
+      b._impliedStops(),
+      t,
     );
     return RadialGradient(
       center: AlignmentGeometry.lerp(a.center, b.center, t)!,
@@ -805,15 +820,15 @@ class RadialGradient extends Gradient {
     if (other.runtimeType != runtimeType) {
       return false;
     }
-    return other is RadialGradient
-        && other.center == center
-        && other.radius == radius
-        && other.tileMode == tileMode
-        && other.transform == transform
-        && listEquals<Color>(other.colors, colors)
-        && listEquals<double>(other.stops, stops)
-        && other.focal == focal
-        && other.focalRadius == focalRadius;
+    return other is RadialGradient &&
+        other.center == center &&
+        other.radius == radius &&
+        other.tileMode == tileMode &&
+        other.transform == transform &&
+        listEquals<Color>(other.colors, colors) &&
+        listEquals<double>(other.stops, stops) &&
+        other.focal == focal &&
+        other.focalRadius == focalRadius;
   }
 
   @override
@@ -843,6 +858,20 @@ class RadialGradient extends Gradient {
 
     return '${objectRuntimeType(this, 'RadialGradient')}(${description.join(', ')})';
   }
+
+  @override
+  RadialGradient withOpacity(double opacity) {
+    return RadialGradient(
+      center: center,
+      radius: radius,
+      colors: <Color>[for (final Color color in colors) color.withOpacity(opacity)],
+      stops: stops,
+      tileMode: tileMode,
+      focal: focal,
+      focalRadius: focalRadius,
+      transform: transform,
+    );
+  }
 }
 
 /// A 2D sweep gradient.
@@ -955,18 +984,41 @@ class SweepGradient extends Gradient {
 
   /// The angle in radians at which stop 0.0 of the gradient is placed.
   ///
+  /// The angle is measured in radians clockwise from the positive x-axis.
+  ///
+  /// Values outside the range `[0, 2π]` are normalized to the equivalent angle
+  /// within this range using modulo arithmetic.
+  ///
+  /// The gradient will be painted in the sector between [startAngle] and [endAngle].
+  /// The behavior outside this sector is determined by [tileMode].
+  ///
   /// Defaults to 0.0.
   final double startAngle;
 
   /// The angle in radians at which stop 1.0 of the gradient is placed.
   ///
-  /// Defaults to math.pi * 2.
+  /// The angle is measured in radians clockwise from the positive x-axis.
+  ///
+  /// Values outside the range `[0, 2π]` are normalized to the equivalent angle
+  /// within this range using modulo arithmetic.
+  ///
+  /// The gradient will be painted in the sector between [startAngle] and [endAngle].
+  /// The behavior outside this sector is determined by [tileMode].
+  ///
+  /// Defaults to math.pi * 2 (2π = a full circle).
   final double endAngle;
 
-  /// How this gradient should tile the plane beyond in the region before
+  /// How this gradient should tile the plane in the region before
   /// [startAngle] and after [endAngle].
   ///
-  /// For details, see [TileMode].
+  /// The gradient will be painted in the sector between [startAngle] and
+  /// [endAngle]. The [tileMode] determines what happens in the remaining area:
+  ///
+  /// * [TileMode.clamp]: The edge colors are extended to fill the remaining area.
+  /// * [TileMode.repeated]: The gradient is repeated in the angular direction.
+  /// * [TileMode.mirror]: The gradient is mirrored in the angular direction.
+  /// * [TileMode.decal]: Only the gradient is drawn, leaving the remaining area
+  ///   transparent.
   ///
   /// ![](https://flutter.github.io/assets-for-api-docs/assets/dart-ui/tile_mode_clamp_sweep.png)
   /// ![](https://flutter.github.io/assets-for-api-docs/assets/dart-ui/tile_mode_decal_sweep.png)
@@ -975,10 +1027,12 @@ class SweepGradient extends Gradient {
   final TileMode tileMode;
 
   @override
-  Shader createShader(Rect rect, { TextDirection? textDirection }) {
+  Shader createShader(Rect rect, {TextDirection? textDirection}) {
     return ui.Gradient.sweep(
       center.resolve(textDirection).withinRect(rect),
-      colors, _impliedStops(), tileMode,
+      colors,
+      _impliedStops(),
+      tileMode,
       startAngle,
       endAngle,
       _resolveTransform(rect, textDirection),
@@ -1003,16 +1057,16 @@ class SweepGradient extends Gradient {
 
   @override
   Gradient? lerpFrom(Gradient? a, double t) {
-    if (a == null || (a is SweepGradient)) {
-      return SweepGradient.lerp(a as SweepGradient?, this, t);
+    if (a is SweepGradient?) {
+      return SweepGradient.lerp(a, this, t);
     }
     return super.lerpFrom(a, t);
   }
 
   @override
   Gradient? lerpTo(Gradient? b, double t) {
-    if (b == null || (b is SweepGradient)) {
-      return SweepGradient.lerp(this, b as SweepGradient?, t);
+    if (b is SweepGradient?) {
+      return SweepGradient.lerp(this, b, t);
     }
     return super.lerpTo(b, t);
   }
@@ -1046,11 +1100,11 @@ class SweepGradient extends Gradient {
       return a.scale(1.0 - t);
     }
     final _ColorsAndStops interpolated = _interpolateColorsAndStops(
-        a.colors,
-        a._impliedStops(),
-        b.colors,
-        b._impliedStops(),
-        t,
+      a.colors,
+      a._impliedStops(),
+      b.colors,
+      b._impliedStops(),
+      t,
     );
     return SweepGradient(
       center: AlignmentGeometry.lerp(a.center, b.center, t)!,
@@ -1071,14 +1125,14 @@ class SweepGradient extends Gradient {
     if (other.runtimeType != runtimeType) {
       return false;
     }
-    return other is SweepGradient
-        && other.center == center
-        && other.startAngle == startAngle
-        && other.endAngle == endAngle
-        && other.tileMode == tileMode
-        && other.transform == transform
-        && listEquals<Color>(other.colors, colors)
-        && listEquals<double>(other.stops, stops);
+    return other is SweepGradient &&
+        other.center == center &&
+        other.startAngle == startAngle &&
+        other.endAngle == endAngle &&
+        other.tileMode == tileMode &&
+        other.transform == transform &&
+        listEquals<Color>(other.colors, colors) &&
+        listEquals<double>(other.stops, stops);
   }
 
   @override
@@ -1106,4 +1160,17 @@ class SweepGradient extends Gradient {
 
     return '${objectRuntimeType(this, 'SweepGradient')}(${description.join(', ')})';
   }
+
+  @override
+  SweepGradient withOpacity(double opacity) {
+    return SweepGradient(
+      center: center,
+      startAngle: startAngle,
+      endAngle: endAngle,
+      colors: <Color>[for (final Color color in colors) color.withOpacity(opacity)],
+      stops: stops,
+      tileMode: tileMode,
+      transform: transform,
+    );
+  }
 }
