@@ -45,17 +45,11 @@ extension type CSSStyleDeclaration._(JSObject _) implements JSObject {
 }
 
 extension type CSSStyleSheet._(JSObject _) implements JSObject {
-  external int insertRule(
-    String rule, [
-    int index,
-  ]);
+  external int insertRule(String rule, [int index]);
 }
 
 extension type Document._(JSObject _) implements JSObject {
-  external Element createElement(
-    String localName, [
-    JSAny options,
-  ]);
+  external Element createElement(String localName, [JSAny options]);
   external Range createRange();
   external HTMLHeadElement? get head;
 }
@@ -67,22 +61,20 @@ extension type DOMTokenList._(JSObject _) implements JSObject {
 extension type Element._(JSObject _) implements Node, JSObject {
   external DOMTokenList get classList;
   external void append(JSAny nodes);
+  external void remove();
 }
 
 extension type Event._(JSObject _) implements JSObject {}
 
 extension type EventTarget._(JSObject _) implements JSObject {
-  external void addEventListener(
-    String type,
-    EventListener? callback, [
-    JSAny options,
-  ]);
+  external void addEventListener(String type, EventListener? callback, [JSAny options]);
 }
 
 extension type HTMLElement._(JSObject _) implements Element, JSObject {
   external String get innerText;
   external set innerText(String value);
   external CSSStyleDeclaration get style;
+  external HTMLElement cloneNode(bool deep);
 }
 
 extension type HTMLHeadElement._(JSObject _) implements HTMLElement, JSObject {}
@@ -91,6 +83,22 @@ extension type HTMLStyleElement._(JSObject _) implements HTMLElement, JSObject {
   external CSSStyleSheet? get sheet;
 }
 
+extension type HTMLImageElement._(JSObject _) implements HTMLElement, JSObject {
+  external String get src;
+  external set src(String value);
+  external num get naturalWidth;
+  external num get naturalHeight;
+  external JSPromise<JSAny?> decode();
+}
+
+extension type HTMLCanvasElement._(JSObject _) implements HTMLElement, JSObject {
+  external int get width;
+  external set width(int value);
+  external int get height;
+  external set height(int value);
+  external String toDataURL();
+}
+
 extension type MediaQueryList._(JSObject _) implements EventTarget, JSObject {
   external bool get matches;
 }
@@ -99,6 +107,7 @@ extension type MouseEvent._(JSObject _) implements JSObject {
   external num get offsetX;
   external num get offsetY;
   external int get button;
+  external void preventDefault();
 }
 
 extension type Navigator._(JSObject _) implements JSObject {
@@ -120,22 +129,13 @@ extension type Window._(JSObject _) implements EventTarget, JSObject {
   external Navigator get navigator;
   external MediaQueryList matchMedia(String query);
   external Selection? getSelection();
+  external String get origin;
 }
 
-extension type XMLHttpRequest._(JSObject _)
-    implements XMLHttpRequestEventTarget, JSObject {
+extension type XMLHttpRequest._(JSObject _) implements XMLHttpRequestEventTarget, JSObject {
   external factory XMLHttpRequest();
-  external void open(
-    String method,
-    String url, [
-    bool async,
-    String? username,
-    String? password,
-  ]);
-  external void setRequestHeader(
-    String name,
-    String value,
-  );
+  external void open(String method, String url, [bool async, String? username, String? password]);
+  external void setRequestHeader(String name, String value);
   external void send([JSAny? body]);
   external int get status;
   external set responseType(XMLHttpRequestResponseType value);
@@ -143,5 +143,4 @@ extension type XMLHttpRequest._(JSObject _)
   external JSAny? get response;
 }
 
-extension type XMLHttpRequestEventTarget._(JSObject _)
-    implements EventTarget, JSObject {}
+extension type XMLHttpRequestEventTarget._(JSObject _) implements EventTarget, JSObject {}
