@@ -4,10 +4,11 @@
 
 import 'package:flutter/gestures.dart';
 import 'package:flutter_test/flutter_test.dart';
+import 'package:leak_tracker_flutter_testing/leak_tracker_flutter_testing.dart';
 
 import 'gesture_tester.dart';
 
-class TestDrag extends Drag { }
+class TestDrag extends Drag {}
 
 void main() {
   TestWidgetsFlutterBinding.ensureInitialized();
@@ -28,7 +29,9 @@ void main() {
     expect(didStartDrag, isFalse);
     tester.async.flushMicrotasks();
     expect(didStartDrag, isFalse);
-    tester.route(pointer.move(const Offset(20.0, 60.0))); // move more than touch slop before delay expires
+    tester.route(
+      pointer.move(const Offset(20.0, 60.0)),
+    ); // move more than touch slop before delay expires
     expect(didStartDrag, isFalse);
     tester.async.elapse(kLongPressTimeout * 2); // expire delay
     expect(didStartDrag, isFalse);
@@ -53,18 +56,22 @@ void main() {
     expect(didStartDrag, isFalse);
     tester.async.flushMicrotasks();
     expect(didStartDrag, isFalse);
-    tester.route(pointer.move(const Offset(20.0, 20.0))); // move less than touch slop before delay expires
+    tester.route(
+      pointer.move(const Offset(20.0, 20.0)),
+    ); // move less than touch slop before delay expires
     expect(didStartDrag, isFalse);
     tester.async.elapse(kLongPressTimeout * 2); // expire delay
     expect(didStartDrag, isTrue);
-    tester.route(pointer.move(const Offset(30.0, 70.0))); // move more than touch slop after delay expires
+    tester.route(
+      pointer.move(const Offset(30.0, 70.0)),
+    ); // move more than touch slop after delay expires
     expect(didStartDrag, isTrue);
     drag.dispose();
   });
 
   testGesture('MultiDrag: can filter based on device kind', (GestureTester tester) {
     final DelayedMultiDragGestureRecognizer drag = DelayedMultiDragGestureRecognizer(
-      supportedDevices: <PointerDeviceKind>{ PointerDeviceKind.touch },
+      supportedDevices: <PointerDeviceKind>{PointerDeviceKind.touch},
     );
 
     bool didStartDrag = false;
@@ -80,12 +87,16 @@ void main() {
     expect(didStartDrag, isFalse);
     tester.async.flushMicrotasks();
     expect(didStartDrag, isFalse);
-    tester.route(mousePointer.move(const Offset(20.0, 20.0))); // move less than touch slop before delay expires
+    tester.route(
+      mousePointer.move(const Offset(20.0, 20.0)),
+    ); // move less than touch slop before delay expires
     expect(didStartDrag, isFalse);
     tester.async.elapse(kLongPressTimeout * 2); // expire delay
     // Still false because it shouldn't recognize mouse events.
     expect(didStartDrag, isFalse);
-    tester.route(mousePointer.move(const Offset(30.0, 70.0))); // move more than touch slop after delay expires
+    tester.route(
+      mousePointer.move(const Offset(30.0, 70.0)),
+    ); // move more than touch slop after delay expires
     // And still false.
     expect(didStartDrag, isFalse);
     drag.dispose();
@@ -95,8 +106,9 @@ void main() {
     // Regression test for https://github.com/flutter/flutter/pull/122227
 
     final ImmediateMultiDragGestureRecognizer recognizer1 = ImmediateMultiDragGestureRecognizer();
-    // ignore: avoid_redundant_argument_values
-    final ImmediateMultiDragGestureRecognizer recognizer2 = ImmediateMultiDragGestureRecognizer(allowedButtonsFilter: null);
+    final ImmediateMultiDragGestureRecognizer recognizer2 = ImmediateMultiDragGestureRecognizer(
+      allowedButtonsFilter: null, // ignore: avoid_redundant_argument_values
+    );
 
     // We want to test _allowedButtonsFilter, which is called in this method.
     const PointerDownEvent allowedPointer = PointerDownEvent(timeStamp: Duration(days: 10));
@@ -105,10 +117,35 @@ void main() {
     // ignore: invalid_use_of_protected_member
     expect(recognizer2.isPointerAllowed(allowedPointer), true);
 
-    const PointerDownEvent rejectedPointer = PointerDownEvent(timeStamp: Duration(days: 10), buttons: kMiddleMouseButton);
+    const PointerDownEvent rejectedPointer = PointerDownEvent(
+      timeStamp: Duration(days: 10),
+      buttons: kMiddleMouseButton,
+    );
     // ignore: invalid_use_of_protected_member
     expect(recognizer1.isPointerAllowed(rejectedPointer), false);
     // ignore: invalid_use_of_protected_member
     expect(recognizer2.isPointerAllowed(rejectedPointer), false);
   });
+
+  test('$MultiDragPointerState dispatches memory events', () async {
+    await expectLater(
+      await memoryEvents(
+        () => _MultiDragPointerState(Offset.zero, PointerDeviceKind.touch, null).dispose(),
+        _MultiDragPointerState,
+      ),
+      areCreateAndDispose,
+    );
+  });
+}
+
+class _MultiDragPointerState extends MultiDragPointerState {
+  _MultiDragPointerState(super.initialPosition, super.kind, super.gestureSettings);
+
+  @override
+  void accepted(GestureMultiDragStartCallback starter) {}
+
+  @override
+  void dispose() {
+    super.dispose();
+  }
 }
