@@ -35,9 +35,9 @@ void main() {
     const BadgeThemeData().debugFillProperties(builder);
 
     final List<String> description = builder.properties
-      .where((DiagnosticsNode node) => !node.isFiltered(DiagnosticLevel.info))
-      .map((DiagnosticsNode node) => node.toString())
-      .toList();
+        .where((DiagnosticsNode node) => !node.isFiltered(DiagnosticLevel.info))
+        .map((DiagnosticsNode node) => node.toString())
+        .toList();
 
     expect(description, <String>[]);
   });
@@ -61,14 +61,14 @@ void main() {
         .toList();
 
     expect(description, <String>[
-      'backgroundColor: Color(0xfffffff0)',
-      'textColor: Color(0xfffffff1)',
+      'backgroundColor: ${const Color(0xfffffff0)}',
+      'textColor: ${const Color(0xfffffff1)}',
       'smallSize: 1.0',
       'largeSize: 2.0',
       'textStyle: TextStyle(inherit: true, size: 4.0)',
       'padding: EdgeInsets.all(5.0)',
       'alignment: AlignmentDirectional(6.0, 7.0)',
-      'offset: Offset(0.0, 0.0)'
+      'offset: Offset(0.0, 0.0)',
     ]);
   });
 
@@ -88,14 +88,9 @@ void main() {
 
     await tester.pumpWidget(
       MaterialApp(
-        theme: ThemeData.light(useMaterial3: true).copyWith(
-          badgeTheme: badgeTheme,
-        ),
+        theme: ThemeData(badgeTheme: badgeTheme),
         home: const Scaffold(
-          body: Badge(
-            label: Text('1234'),
-            child: Icon(Icons.add),
-          ),
+          body: Badge(label: Text('1234'), child: Icon(Icons.add)),
         ),
       ),
     );
@@ -103,8 +98,7 @@ void main() {
     // text width = 48 = fontSize * 4, text height = fontSize
     expect(tester.getSize(find.text('1234')), const Size(48, 12));
 
-    expect(tester.getTopLeft(find.text('1234')), const Offset(33, 4));
-
+    expect(tester.getTopLeft(find.text('1234')), const Offset(33, 2));
 
     expect(tester.getSize(find.byType(Badge)), const Size(24, 24)); // default Icon size
     expect(tester.getTopLeft(find.byType(Badge)), Offset.zero);
@@ -114,10 +108,13 @@ void main() {
     expect(textStyle.color, black);
 
     final RenderBox box = tester.renderObject(find.byType(Badge));
-    expect(box, paints..rrect(rrect: RRect.fromLTRBR(28, 0, 86, 20, const Radius.circular(10)), color: green));
+    expect(
+      box,
+      paints
+        ..rrect(rrect: RRect.fromLTRBR(28, -2, 86, 18, const Radius.circular(10)), color: green),
+    );
   });
 
-
   // This test is essentially the same as 'Badge uses ThemeData badge theme'. In
   // this case the theme is introduced with the BadgeTheme widget instead of
   // ThemeData.badgeTheme.
@@ -140,23 +137,24 @@ void main() {
         home: BadgeTheme(
           data: badgeTheme,
           child: Scaffold(
-            body: Badge(
-              label: Text('1234'),
-              child: Icon(Icons.add),
-            ),
+            body: Badge(label: Text('1234'), child: Icon(Icons.add)),
           ),
         ),
       ),
     );
 
     expect(tester.getSize(find.text('1234')), const Size(48, 12));
-    expect(tester.getTopLeft(find.text('1234')), const Offset(33, 4));
+    expect(tester.getTopLeft(find.text('1234')), const Offset(33, 2));
     expect(tester.getSize(find.byType(Badge)), const Size(24, 24)); // default Icon size
     expect(tester.getTopLeft(find.byType(Badge)), Offset.zero);
     final TextStyle textStyle = tester.renderObject<RenderParagraph>(find.text('1234')).text.style!;
     expect(textStyle.fontSize, 12);
     expect(textStyle.color, black);
     final RenderBox box = tester.renderObject(find.byType(Badge));
-    expect(box, paints..rrect(rrect: RRect.fromLTRBR(28, 0, 86, 20, const Radius.circular(10)), color: green));
+    expect(
+      box,
+      paints
+        ..rrect(rrect: RRect.fromLTRBR(28, -2, 86, 18, const Radius.circular(10)), color: green),
+    );
   });
 }
