@@ -10,12 +10,17 @@ import 'package:flutter_test/flutter_test.dart';
 
 void main() {
   RenderObject getOverlayColor(WidgetTester tester) {
-    return tester.allRenderObjects.firstWhere((RenderObject object) => object.runtimeType.toString() == '_RenderInkFeatures');
+    return tester.allRenderObjects.firstWhere(
+      (RenderObject object) => object.runtimeType.toString() == '_RenderInkFeatures',
+    );
   }
 
   test('SegmentedButtonThemeData copyWith, ==, hashCode basics', () {
     expect(const SegmentedButtonThemeData(), const SegmentedButtonThemeData().copyWith());
-    expect(const SegmentedButtonThemeData().hashCode, const SegmentedButtonThemeData().copyWith().hashCode);
+    expect(
+      const SegmentedButtonThemeData().hashCode,
+      const SegmentedButtonThemeData().copyWith().hashCode,
+    );
 
     const SegmentedButtonThemeData custom = SegmentedButtonThemeData(
       style: ButtonStyle(backgroundColor: MaterialStatePropertyAll<Color>(Colors.green)),
@@ -39,15 +44,15 @@ void main() {
     const SegmentedButtonThemeData().debugFillProperties(builder);
 
     final List<String> description = builder.properties
-      .where((DiagnosticsNode node) => !node.isFiltered(DiagnosticLevel.info))
-      .map((DiagnosticsNode node) => node.toString())
-      .toList();
+        .where((DiagnosticsNode node) => !node.isFiltered(DiagnosticLevel.info))
+        .map((DiagnosticsNode node) => node.toString())
+        .toList();
 
     expect(description, <String>[]);
   });
 
   testWidgets('With no other configuration, defaults are used', (WidgetTester tester) async {
-    final ThemeData theme = ThemeData(useMaterial3: true);
+    final ThemeData theme = ThemeData();
     await tester.pumpWidget(
       MaterialApp(
         theme: theme,
@@ -60,7 +65,7 @@ void main() {
                 ButtonSegment<int>(value: 3, label: Text('3'), enabled: false),
               ],
               selected: const <int>{2},
-              onSelectionChanged: (Set<int> selected) { },
+              onSelectionChanged: (Set<int> selected) {},
             ),
           ),
         ),
@@ -115,23 +120,22 @@ void main() {
 
   testWidgets('ThemeData.segmentedButtonTheme overrides defaults', (WidgetTester tester) async {
     final ThemeData theme = ThemeData(
-      useMaterial3: true,
       segmentedButtonTheme: SegmentedButtonThemeData(
         style: ButtonStyle(
-          backgroundColor: MaterialStateProperty.resolveWith((Set<MaterialState> states) {
-            if (states.contains(MaterialState.disabled)) {
+          backgroundColor: WidgetStateProperty.resolveWith((Set<WidgetState> states) {
+            if (states.contains(WidgetState.disabled)) {
               return Colors.blue;
             }
-            if (states.contains(MaterialState.selected)) {
+            if (states.contains(WidgetState.selected)) {
               return Colors.purple;
             }
             return null;
           }),
-          foregroundColor: MaterialStateProperty.resolveWith((Set<MaterialState> states) {
-            if (states.contains(MaterialState.disabled)) {
+          foregroundColor: WidgetStateProperty.resolveWith((Set<WidgetState> states) {
+            if (states.contains(WidgetState.disabled)) {
               return Colors.yellow;
             }
-            if (states.contains(MaterialState.selected)) {
+            if (states.contains(WidgetState.selected)) {
               return Colors.brown;
             } else {
               return Colors.cyan;
@@ -153,7 +157,7 @@ void main() {
                 ButtonSegment<int>(value: 3, label: Text('3'), enabled: false),
               ],
               selected: const <int>{2},
-              onSelectionChanged: (Set<int> selected) { },
+              onSelectionChanged: (Set<int> selected) {},
             ),
           ),
         ),
@@ -209,20 +213,20 @@ void main() {
   testWidgets('SegmentedButtonTheme overrides ThemeData and defaults', (WidgetTester tester) async {
     final SegmentedButtonThemeData global = SegmentedButtonThemeData(
       style: ButtonStyle(
-        backgroundColor: MaterialStateProperty.resolveWith((Set<MaterialState> states) {
-          if (states.contains(MaterialState.disabled)) {
+        backgroundColor: WidgetStateProperty.resolveWith((Set<WidgetState> states) {
+          if (states.contains(WidgetState.disabled)) {
             return Colors.blue;
           }
-          if (states.contains(MaterialState.selected)) {
+          if (states.contains(WidgetState.selected)) {
             return Colors.purple;
           }
           return null;
         }),
-        foregroundColor: MaterialStateProperty.resolveWith((Set<MaterialState> states) {
-          if (states.contains(MaterialState.disabled)) {
+        foregroundColor: WidgetStateProperty.resolveWith((Set<WidgetState> states) {
+          if (states.contains(WidgetState.disabled)) {
             return Colors.yellow;
           }
-          if (states.contains(MaterialState.selected)) {
+          if (states.contains(WidgetState.selected)) {
             return Colors.brown;
           } else {
             return Colors.cyan;
@@ -233,20 +237,20 @@ void main() {
     );
     final SegmentedButtonThemeData segmentedTheme = SegmentedButtonThemeData(
       style: ButtonStyle(
-        backgroundColor: MaterialStateProperty.resolveWith((Set<MaterialState> states) {
-          if (states.contains(MaterialState.disabled)) {
+        backgroundColor: WidgetStateProperty.resolveWith((Set<WidgetState> states) {
+          if (states.contains(WidgetState.disabled)) {
             return Colors.lightBlue;
           }
-          if (states.contains(MaterialState.selected)) {
+          if (states.contains(WidgetState.selected)) {
             return Colors.lightGreen;
           }
           return null;
         }),
-        foregroundColor: MaterialStateProperty.resolveWith((Set<MaterialState> states) {
-          if (states.contains(MaterialState.disabled)) {
+        foregroundColor: WidgetStateProperty.resolveWith((Set<WidgetState> states) {
+          if (states.contains(WidgetState.disabled)) {
             return Colors.lime;
           }
-          if (states.contains(MaterialState.selected)) {
+          if (states.contains(WidgetState.selected)) {
             return Colors.amber;
           } else {
             return Colors.deepPurple;
@@ -255,10 +259,7 @@ void main() {
       ),
       selectedIcon: const Icon(Icons.plus_one),
     );
-    final ThemeData theme = ThemeData(
-      useMaterial3: true,
-      segmentedButtonTheme: global,
-    );
+    final ThemeData theme = ThemeData(segmentedButtonTheme: global);
     await tester.pumpWidget(
       MaterialApp(
         theme: theme,
@@ -273,7 +274,7 @@ void main() {
                   ButtonSegment<int>(value: 3, label: Text('3'), enabled: false),
                 ],
                 selected: const <int>{2},
-                onSelectionChanged: (Set<int> selected) { },
+                onSelectionChanged: (Set<int> selected) {},
               ),
             ),
           ),
@@ -285,7 +286,10 @@ void main() {
     {
       final Finder text = find.text('1');
       final Finder parent = find.ancestor(of: text, matching: find.byType(Material)).first;
-      final Finder selectedIcon = find.descendant(of: parent, matching: find.byIcon(Icons.plus_one));
+      final Finder selectedIcon = find.descendant(
+        of: parent,
+        matching: find.byIcon(Icons.plus_one),
+      );
       final Material material = tester.widget<Material>(parent);
       expect(material.animationDuration, const Duration(milliseconds: 200));
       expect(material.borderRadius, null);
@@ -302,7 +306,10 @@ void main() {
     {
       final Finder text = find.text('2');
       final Finder parent = find.ancestor(of: text, matching: find.byType(Material)).first;
-      final Finder selectedIcon = find.descendant(of: parent, matching: find.byIcon(Icons.plus_one));
+      final Finder selectedIcon = find.descendant(
+        of: parent,
+        matching: find.byIcon(Icons.plus_one),
+      );
       final Material material = tester.widget<Material>(parent);
       expect(material.animationDuration, const Duration(milliseconds: 200));
       expect(material.borderRadius, null);
@@ -319,7 +326,10 @@ void main() {
     {
       final Finder text = find.text('3');
       final Finder parent = find.ancestor(of: text, matching: find.byType(Material)).first;
-      final Finder selectedIcon = find.descendant(of: parent, matching: find.byIcon(Icons.plus_one));
+      final Finder selectedIcon = find.descendant(
+        of: parent,
+        matching: find.byIcon(Icons.plus_one),
+      );
       final Material material = tester.widget<Material>(parent);
       expect(material.animationDuration, const Duration(milliseconds: 200));
       expect(material.borderRadius, null);
@@ -333,23 +343,25 @@ void main() {
     }
   });
 
-  testWidgets('Widget parameters overrides SegmentedTheme, ThemeData and defaults', (WidgetTester tester) async {
+  testWidgets('Widget parameters overrides SegmentedTheme, ThemeData and defaults', (
+    WidgetTester tester,
+  ) async {
     final SegmentedButtonThemeData global = SegmentedButtonThemeData(
       style: ButtonStyle(
-        backgroundColor: MaterialStateProperty.resolveWith((Set<MaterialState> states) {
-          if (states.contains(MaterialState.disabled)) {
+        backgroundColor: WidgetStateProperty.resolveWith((Set<WidgetState> states) {
+          if (states.contains(WidgetState.disabled)) {
             return Colors.blue;
           }
-          if (states.contains(MaterialState.selected)) {
+          if (states.contains(WidgetState.selected)) {
             return Colors.purple;
           }
           return null;
         }),
-        foregroundColor: MaterialStateProperty.resolveWith((Set<MaterialState> states) {
-          if (states.contains(MaterialState.disabled)) {
+        foregroundColor: WidgetStateProperty.resolveWith((Set<WidgetState> states) {
+          if (states.contains(WidgetState.disabled)) {
             return Colors.yellow;
           }
-          if (states.contains(MaterialState.selected)) {
+          if (states.contains(WidgetState.selected)) {
             return Colors.brown;
           } else {
             return Colors.cyan;
@@ -360,20 +372,20 @@ void main() {
     );
     final SegmentedButtonThemeData segmentedTheme = SegmentedButtonThemeData(
       style: ButtonStyle(
-        backgroundColor: MaterialStateProperty.resolveWith((Set<MaterialState> states) {
-          if (states.contains(MaterialState.disabled)) {
+        backgroundColor: WidgetStateProperty.resolveWith((Set<WidgetState> states) {
+          if (states.contains(WidgetState.disabled)) {
             return Colors.lightBlue;
           }
-          if (states.contains(MaterialState.selected)) {
+          if (states.contains(WidgetState.selected)) {
             return Colors.lightGreen;
           }
           return null;
         }),
-        foregroundColor: MaterialStateProperty.resolveWith((Set<MaterialState> states) {
-          if (states.contains(MaterialState.disabled)) {
+        foregroundColor: WidgetStateProperty.resolveWith((Set<WidgetState> states) {
+          if (states.contains(WidgetState.disabled)) {
             return Colors.lime;
           }
-          if (states.contains(MaterialState.selected)) {
+          if (states.contains(WidgetState.selected)) {
             return Colors.amber;
           } else {
             return Colors.deepPurple;
@@ -382,10 +394,7 @@ void main() {
       ),
       selectedIcon: const Icon(Icons.plus_one),
     );
-    final ThemeData theme = ThemeData(
-      useMaterial3: true,
-      segmentedButtonTheme: global,
-    );
+    final ThemeData theme = ThemeData(segmentedButtonTheme: global);
     await tester.pumpWidget(
       MaterialApp(
         theme: theme,
@@ -400,22 +409,22 @@ void main() {
                   ButtonSegment<int>(value: 3, label: Text('3'), enabled: false),
                 ],
                 selected: const <int>{2},
-                onSelectionChanged: (Set<int> selected) { },
+                onSelectionChanged: (Set<int> selected) {},
                 style: ButtonStyle(
-                  backgroundColor: MaterialStateProperty.resolveWith((Set<MaterialState> states) {
-                    if (states.contains(MaterialState.disabled)) {
+                  backgroundColor: WidgetStateProperty.resolveWith((Set<WidgetState> states) {
+                    if (states.contains(WidgetState.disabled)) {
                       return Colors.black12;
                     }
-                    if (states.contains(MaterialState.selected)) {
+                    if (states.contains(WidgetState.selected)) {
                       return Colors.grey;
                     }
                     return null;
                   }),
-                  foregroundColor: MaterialStateProperty.resolveWith((Set<MaterialState> states) {
-                    if (states.contains(MaterialState.disabled)) {
+                  foregroundColor: WidgetStateProperty.resolveWith((Set<WidgetState> states) {
+                    if (states.contains(WidgetState.disabled)) {
                       return Colors.amberAccent;
                     }
-                    if (states.contains(MaterialState.selected)) {
+                    if (states.contains(WidgetState.selected)) {
                       return Colors.deepOrange;
                     } else {
                       return Colors.deepPurpleAccent;
@@ -482,92 +491,87 @@ void main() {
     }
   });
 
-  testWidgets('SegmentedButtonTheme SegmentedButton.styleFrom overlayColor overrides default overlay color', (WidgetTester tester) async {
-    const Color overlayColor = Color(0xffff0000);
-    await tester.pumpWidget(
-      MaterialApp(
-        theme: ThemeData(
-          segmentedButtonTheme: SegmentedButtonThemeData(
-            style: SegmentedButton.styleFrom(overlayColor: overlayColor),
+  testWidgets(
+    'SegmentedButtonTheme SegmentedButton.styleFrom overlayColor overrides default overlay color',
+    (WidgetTester tester) async {
+      const Color overlayColor = Color(0xffff0000);
+      await tester.pumpWidget(
+        MaterialApp(
+          theme: ThemeData(
+            segmentedButtonTheme: SegmentedButtonThemeData(
+              style: SegmentedButton.styleFrom(overlayColor: overlayColor),
+            ),
           ),
-        ),
-        home: Scaffold(
-          body: Center(
-            child: SegmentedButton<int>(
-              segments: const <ButtonSegment<int>>[
-                ButtonSegment<int>(
-                  value: 0,
-                  label: Text('Option 1'),
-                ),
-                ButtonSegment<int>(
-                  value: 1,
-                  label: Text('Option 2'),
-                ),
-              ],
-              onSelectionChanged: (Set<int> selected) {},
-              selected: const <int>{1},
+          home: Scaffold(
+            body: Center(
+              child: SegmentedButton<int>(
+                segments: const <ButtonSegment<int>>[
+                  ButtonSegment<int>(value: 0, label: Text('Option 1')),
+                  ButtonSegment<int>(value: 1, label: Text('Option 2')),
+                ],
+                onSelectionChanged: (Set<int> selected) {},
+                selected: const <int>{1},
+              ),
             ),
           ),
         ),
-      ),
-    );
+      );
 
-    // Hovered selected segment,
-    Offset center = tester.getCenter(find.text('Option 1'));
-    final TestGesture gesture = await tester.createGesture(
-      kind: PointerDeviceKind.mouse,
-    );
-    await gesture.addPointer();
-    await gesture.moveTo(center);
-    await tester.pumpAndSettle();
-    expect(getOverlayColor(tester), paints..rect(color: overlayColor.withOpacity(0.08)));
+      // Hovered selected segment,
+      Offset center = tester.getCenter(find.text('Option 1'));
+      final TestGesture gesture = await tester.createGesture(kind: PointerDeviceKind.mouse);
+      await gesture.addPointer();
+      await gesture.moveTo(center);
+      await tester.pumpAndSettle();
+      expect(getOverlayColor(tester), paints..rect(color: overlayColor.withOpacity(0.08)));
 
-    // Hovered unselected segment,
-    center = tester.getCenter(find.text('Option 2'));
-    await gesture.moveTo(center);
-    await tester.pumpAndSettle();
-    expect(getOverlayColor(tester), paints..rect(color: overlayColor.withOpacity(0.08)));
+      // Hovered unselected segment,
+      center = tester.getCenter(find.text('Option 2'));
+      await gesture.moveTo(center);
+      await tester.pumpAndSettle();
+      expect(getOverlayColor(tester), paints..rect(color: overlayColor.withOpacity(0.08)));
 
-    // Highlighted unselected segment (pressed).
-    center = tester.getCenter(find.text('Option 1'));
-    await gesture.down(center);
-    await tester.pumpAndSettle();
-    expect(
-      getOverlayColor(tester),
-      paints
-        ..rect(color: overlayColor.withOpacity(0.08))
-        ..rect(color: overlayColor.withOpacity(0.1)),
-    );
-    // Remove pressed and hovered states,
-    await gesture.up();
-    await tester.pumpAndSettle();
-    await gesture.moveTo(const Offset(0, 50));
-    await tester.pumpAndSettle();
+      // Highlighted unselected segment (pressed).
+      center = tester.getCenter(find.text('Option 1'));
+      await gesture.down(center);
+      await tester.pumpAndSettle();
+      expect(
+        getOverlayColor(tester),
+        paints
+          ..rect(color: overlayColor.withOpacity(0.08))
+          ..rect(color: overlayColor.withOpacity(0.1)),
+      );
+      // Remove pressed and hovered states,
+      await gesture.up();
+      await tester.pumpAndSettle();
+      await gesture.moveTo(const Offset(0, 50));
+      await tester.pumpAndSettle();
 
-    // Highlighted selected segment (pressed)
-    center = tester.getCenter(find.text('Option 2'));
-    await gesture.down(center);
-    await tester.pumpAndSettle();
-    expect(
-      getOverlayColor(tester),
-      paints
-        ..rect(color: overlayColor.withOpacity(0.08))
-        ..rect(color: overlayColor.withOpacity(0.1)),
-    );
-    // Remove pressed and hovered states,
-    await gesture.up();
-    await tester.pumpAndSettle();
-    await gesture.moveTo(const Offset(0, 50));
-    await tester.pumpAndSettle();
+      // Highlighted selected segment (pressed)
+      center = tester.getCenter(find.text('Option 2'));
+      await gesture.down(center);
+      await tester.pumpAndSettle();
+      expect(
+        getOverlayColor(tester),
+        paints
+          ..rect(color: overlayColor.withOpacity(0.08))
+          ..rect(color: overlayColor.withOpacity(0.1)),
+      );
+      // Remove pressed and hovered states,
+      await gesture.up();
+      await tester.pumpAndSettle();
+      await gesture.moveTo(const Offset(0, 50));
+      await tester.pumpAndSettle();
 
-    // Focused unselected segment.
-    await tester.sendKeyEvent(LogicalKeyboardKey.tab);
-    await tester.pumpAndSettle();
-    expect(getOverlayColor(tester), paints..rect(color: overlayColor.withOpacity(0.1)));
+      // Focused unselected segment.
+      await tester.sendKeyEvent(LogicalKeyboardKey.tab);
+      await tester.pumpAndSettle();
+      expect(getOverlayColor(tester), paints..rect(color: overlayColor.withOpacity(0.1)));
 
-    // Focused selected segment.
-    await tester.sendKeyEvent(LogicalKeyboardKey.tab);
-    await tester.pumpAndSettle();
-    expect(getOverlayColor(tester), paints..rect(color: overlayColor.withOpacity(0.1)));
-  });
+      // Focused selected segment.
+      await tester.sendKeyEvent(LogicalKeyboardKey.tab);
+      await tester.pumpAndSettle();
+      expect(getOverlayColor(tester), paints..rect(color: overlayColor.withOpacity(0.1)));
+    },
+  );
 }
