@@ -13,8 +13,8 @@ void main() {
   test('TextSpan equals', () {
     const TextSpan a1 = TextSpan(text: 'a');
     const TextSpan a2 = TextSpan(text: 'a');
-    const TextSpan b1 = TextSpan(children: <TextSpan>[ a1 ]);
-    const TextSpan b2 = TextSpan(children: <TextSpan>[ a2 ]);
+    const TextSpan b1 = TextSpan(children: <TextSpan>[a1]);
+    const TextSpan b2 = TextSpan(children: <TextSpan>[a2]);
     const TextSpan c1 = TextSpan();
     const TextSpan c2 = TextSpan();
 
@@ -36,8 +36,16 @@ void main() {
     final TextSpan d1 = TextSpan(text: 'a', onEnter: callback1);
     final TextSpan d2 = TextSpan(text: 'a', onEnter: callback1);
     final TextSpan d3 = TextSpan(text: 'a', onEnter: callback2);
-    final TextSpan e1 = TextSpan(text: 'a', onEnter: callback2, mouseCursor: SystemMouseCursors.forbidden);
-    final TextSpan e2 = TextSpan(text: 'a', onEnter: callback2, mouseCursor: SystemMouseCursors.forbidden);
+    final TextSpan e1 = TextSpan(
+      text: 'a',
+      onEnter: callback2,
+      mouseCursor: SystemMouseCursors.forbidden,
+    );
+    final TextSpan e2 = TextSpan(
+      text: 'a',
+      onEnter: callback2,
+      mouseCursor: SystemMouseCursors.forbidden,
+    );
 
     expect(a1 == d1, isFalse);
     expect(d1 == d2, isTrue);
@@ -49,43 +57,38 @@ void main() {
   test('TextSpan toStringDeep', () {
     const TextSpan test = TextSpan(
       text: 'a',
-      style: TextStyle(
-        fontSize: 10.0,
-      ),
+      style: TextStyle(fontSize: 10.0),
       children: <TextSpan>[
-        TextSpan(
-          text: 'b',
-          children: <TextSpan>[
-            TextSpan(),
-          ],
-        ),
-        TextSpan(
-          text: 'c',
-        ),
+        TextSpan(text: 'b', children: <TextSpan>[TextSpan()]),
+        TextSpan(text: 'c'),
       ],
     );
-    expect(test.toStringDeep(), equals(
-      'TextSpan:\n'
-      '  inherit: true\n'
-      '  size: 10.0\n'
-      '  "a"\n'
-      '  TextSpan:\n'
-      '    "b"\n'
-      '    TextSpan:\n'
-      '      (empty)\n'
-      '  TextSpan:\n'
-      '    "c"\n',
-    ));
+    expect(
+      test.toStringDeep(),
+      equals(
+        'TextSpan:\n'
+        '  inherit: true\n'
+        '  size: 10.0\n'
+        '  "a"\n'
+        '  TextSpan:\n'
+        '    "b"\n'
+        '    TextSpan:\n'
+        '      (empty)\n'
+        '  TextSpan:\n'
+        '    "c"\n',
+      ),
+    );
   });
 
   test('TextSpan toStringDeep for mouse', () {
-    const TextSpan test1 = TextSpan(
-      text: 'a',
+    const TextSpan test1 = TextSpan(text: 'a');
+    expect(
+      test1.toStringDeep(),
+      equals(
+        'TextSpan:\n'
+        '  "a"\n',
+      ),
     );
-    expect(test1.toStringDeep(), equals(
-      'TextSpan:\n'
-      '  "a"\n',
-    ));
 
     final TextSpan test2 = TextSpan(
       text: 'a',
@@ -93,15 +96,17 @@ void main() {
       onExit: (_) {},
       mouseCursor: SystemMouseCursors.forbidden,
     );
-    expect(test2.toStringDeep(), equals(
-      'TextSpan:\n'
-      '  "a"\n'
-      '  callbacks: enter, exit\n'
-      '  mouseCursor: SystemMouseCursor(forbidden)\n',
-    ));
+    expect(
+      test2.toStringDeep(),
+      equals(
+        'TextSpan:\n'
+        '  "a"\n'
+        '  callbacks: enter, exit\n'
+        '  mouseCursor: SystemMouseCursor(forbidden)\n',
+      ),
+    );
   });
 
-
   test('TextSpan toPlainText', () {
     const TextSpan textSpan = TextSpan(
       text: 'a',
@@ -187,10 +192,7 @@ void main() {
       text: 'a',
       children: <InlineSpan>[
         TextSpan(text: 'b'),
-        WidgetSpan(
-          child: SizedBox(width: 10, height: 10),
-          alignment: PlaceholderAlignment.top,
-        ),
+        WidgetSpan(child: SizedBox(width: 10, height: 10), alignment: PlaceholderAlignment.top),
         TextSpan(text: 'c'),
       ],
     );
@@ -254,9 +256,10 @@ void main() {
     const TextSpan textSpan = TextSpan(
       text: '',
       children: <InlineSpan>[
-        TextSpan(text: '', children: <InlineSpan>[
-          TextSpan(text: 'a'),
-        ]),
+        TextSpan(
+          text: '',
+          children: <InlineSpan>[TextSpan(text: 'a')],
+        ),
         TextSpan(text: 'b'),
         TextSpan(text: 'c'),
       ],
@@ -295,9 +298,14 @@ void main() {
 
   test('TextSpan computeSemanticsInformation', () {
     final List<InlineSpanSemanticsInformation> collector = <InlineSpanSemanticsInformation>[];
-    const TextSpan(text: 'aaa', semanticsLabel: 'bbb').computeSemanticsInformation(collector);
+    const TextSpan(
+      text: 'aaa',
+      semanticsLabel: 'bbb',
+      semanticsIdentifier: 'ccc',
+    ).computeSemanticsInformation(collector);
     expect(collector[0].text, 'aaa');
     expect(collector[0].semanticsLabel, 'bbb');
+    expect(collector[0].semanticsIdentifier, 'ccc');
   });
 
   test('TextSpan visitDirectChildren', () {
@@ -334,6 +342,7 @@ void main() {
         index += 1;
         return subtreeRoot.visitDirectChildren(findInSubtree);
       }
+
       return findInSubtree(root) ? null : index;
     }
 
@@ -354,13 +363,8 @@ void main() {
             TextSpan(
               text: 'xxxxx',
               children: <InlineSpan>[
-                TextSpan(
-                  text: 'yyyyy',
-                  mouseCursor: SystemMouseCursors.forbidden,
-                ),
-                TextSpan(
-                  text: 'xxxxx',
-                ),
+                TextSpan(text: 'yyyyy', mouseCursor: SystemMouseCursors.forbidden),
+                TextSpan(text: 'xxxxx'),
               ],
             ),
             textAlign: TextAlign.center,
@@ -373,13 +377,22 @@ void main() {
     await gesture.addPointer();
 
     await gesture.moveTo(tester.getCenter(find.byType(RichText)) - const Offset(40, 0));
-    expect(RendererBinding.instance.mouseTracker.debugDeviceActiveCursor(1), SystemMouseCursors.basic);
+    expect(
+      RendererBinding.instance.mouseTracker.debugDeviceActiveCursor(1),
+      SystemMouseCursors.basic,
+    );
 
     await gesture.moveTo(tester.getCenter(find.byType(RichText)));
-    expect(RendererBinding.instance.mouseTracker.debugDeviceActiveCursor(1), SystemMouseCursors.forbidden);
+    expect(
+      RendererBinding.instance.mouseTracker.debugDeviceActiveCursor(1),
+      SystemMouseCursors.forbidden,
+    );
 
     await gesture.moveTo(tester.getCenter(find.byType(RichText)) + const Offset(40, 0));
-    expect(RendererBinding.instance.mouseTracker.debugDeviceActiveCursor(1), SystemMouseCursors.basic);
+    expect(
+      RendererBinding.instance.mouseTracker.debugDeviceActiveCursor(1),
+      SystemMouseCursors.basic,
+    );
   });
 
   testWidgets('handles onEnter and onExit', (WidgetTester tester) async {
@@ -401,9 +414,7 @@ void main() {
                     logEvents.add(event);
                   },
                 ),
-                const TextSpan(
-                  text: 'xxxxx',
-                ),
+                const TextSpan(text: 'xxxxx'),
               ],
             ),
             textAlign: TextAlign.center,
@@ -439,7 +450,7 @@ void main() {
           children: <InlineSpan>[
             TextSpan(text: 'zzzzz'),
             TextSpan(text: 'bbbbb', spellOut: true),
-          ]
+          ],
         ),
       ],
     );
@@ -454,7 +465,8 @@ void main() {
     expect(collector[1].stringAttributes[0].range, const TextRange(start: 0, end: 5));
     expect(collector[1].stringAttributes[1], isA<LocaleStringAttribute>());
     expect(collector[1].stringAttributes[1].range, const TextRange(start: 0, end: 5));
-    final LocaleStringAttribute localeStringAttribute = collector[1].stringAttributes[1] as LocaleStringAttribute;
+    final LocaleStringAttribute localeStringAttribute =
+        collector[1].stringAttributes[1] as LocaleStringAttribute;
     expect(localeStringAttribute.locale, const Locale('es', 'MX'));
     expect(collector[2].stringAttributes.length, 0);
     expect(collector[3].stringAttributes.length, 0);
@@ -471,7 +483,8 @@ void main() {
     expect(combined[0].stringAttributes[1].range, const TextRange(start: 5, end: 10));
     expect(combined[0].stringAttributes[2], isA<LocaleStringAttribute>());
     expect(combined[0].stringAttributes[2].range, const TextRange(start: 5, end: 10));
-    final LocaleStringAttribute combinedLocaleStringAttribute = combined[0].stringAttributes[2] as LocaleStringAttribute;
+    final LocaleStringAttribute combinedLocaleStringAttribute =
+        combined[0].stringAttributes[2] as LocaleStringAttribute;
     expect(combinedLocaleStringAttribute.locale, const Locale('es', 'MX'));
     expect(combined[0].stringAttributes[3], isA<SpellOutStringAttribute>());
     expect(combined[0].stringAttributes[3].range, const TextRange(start: 20, end: 25));
