@@ -17,8 +17,8 @@ void main() {
     });
 
     test('create Android view of unregistered type', () async {
-      await expectLater(() =>
-        PlatformViewsService.initAndroidView(
+      await expectLater(
+        () => PlatformViewsService.initAndroidView(
           id: 0,
           viewType: 'web',
           layoutDirection: TextDirection.ltr,
@@ -50,56 +50,108 @@ void main() {
 
     test('create VD-fallback Android views', () async {
       viewsController.registerViewType('webview');
-      await PlatformViewsService.initAndroidView(id: 0, viewType: 'webview', layoutDirection: TextDirection.ltr)
-          .create(size: const Size(100.0, 100.0));
-      await PlatformViewsService.initAndroidView( id: 1, viewType: 'webview', layoutDirection: TextDirection.rtl)
-          .create(size: const Size(200.0, 300.0));
+      await PlatformViewsService.initAndroidView(
+        id: 0,
+        viewType: 'webview',
+        layoutDirection: TextDirection.ltr,
+      ).create(size: const Size(100.0, 100.0));
+      await PlatformViewsService.initAndroidView(
+        id: 1,
+        viewType: 'webview',
+        layoutDirection: TextDirection.rtl,
+      ).create(size: const Size(200.0, 300.0));
       expect(
         viewsController.views,
         unorderedEquals(<FakeAndroidPlatformView>[
-          const FakeAndroidPlatformView(0, 'webview', Size(100.0, 100.0), AndroidViewController.kAndroidLayoutDirectionLtr),
-          const FakeAndroidPlatformView(1, 'webview', Size(200.0, 300.0), AndroidViewController.kAndroidLayoutDirectionRtl),
+          const FakeAndroidPlatformView(
+            0,
+            'webview',
+            Size(100.0, 100.0),
+            AndroidViewController.kAndroidLayoutDirectionLtr,
+          ),
+          const FakeAndroidPlatformView(
+            1,
+            'webview',
+            Size(200.0, 300.0),
+            AndroidViewController.kAndroidLayoutDirectionRtl,
+          ),
         ]),
       );
     });
 
     test('create HC-fallback Android views', () async {
       viewsController.registerViewType('webview');
-      await PlatformViewsService.initSurfaceAndroidView(id: 0, viewType: 'webview', layoutDirection: TextDirection.ltr)
-          .create(size: const Size(100.0, 100.0));
-      await PlatformViewsService.initSurfaceAndroidView( id: 1, viewType: 'webview', layoutDirection: TextDirection.rtl)
-          .create(size: const Size(200.0, 300.0));
+      await PlatformViewsService.initSurfaceAndroidView(
+        id: 0,
+        viewType: 'webview',
+        layoutDirection: TextDirection.ltr,
+      ).create(size: const Size(100.0, 100.0));
+      await PlatformViewsService.initSurfaceAndroidView(
+        id: 1,
+        viewType: 'webview',
+        layoutDirection: TextDirection.rtl,
+      ).create(size: const Size(200.0, 300.0));
       expect(
         viewsController.views,
         unorderedEquals(<FakeAndroidPlatformView>[
-          const FakeAndroidPlatformView(0, 'webview', Size(100.0, 100.0), AndroidViewController.kAndroidLayoutDirectionLtr,
-            hybridFallback: true),
-          const FakeAndroidPlatformView(1, 'webview', Size(200.0, 300.0), AndroidViewController.kAndroidLayoutDirectionRtl,
-            hybridFallback: true),
+          const FakeAndroidPlatformView(
+            0,
+            'webview',
+            Size(100.0, 100.0),
+            AndroidViewController.kAndroidLayoutDirectionLtr,
+            hybridFallback: true,
+          ),
+          const FakeAndroidPlatformView(
+            1,
+            'webview',
+            Size(200.0, 300.0),
+            AndroidViewController.kAndroidLayoutDirectionRtl,
+            hybridFallback: true,
+          ),
         ]),
       );
     });
 
     test('create HC-only Android views', () async {
       viewsController.registerViewType('webview');
-      await PlatformViewsService.initExpensiveAndroidView(id: 0, viewType: 'webview', layoutDirection: TextDirection.ltr)
-          .create(size: const Size(100.0, 100.0));
-      await PlatformViewsService.initExpensiveAndroidView( id: 1, viewType: 'webview', layoutDirection: TextDirection.rtl)
-          .create(size: const Size(200.0, 300.0));
+      await PlatformViewsService.initExpensiveAndroidView(
+        id: 0,
+        viewType: 'webview',
+        layoutDirection: TextDirection.ltr,
+      ).create(size: const Size(100.0, 100.0));
+      await PlatformViewsService.initExpensiveAndroidView(
+        id: 1,
+        viewType: 'webview',
+        layoutDirection: TextDirection.rtl,
+      ).create(size: const Size(200.0, 300.0));
       expect(
         viewsController.views,
         unorderedEquals(<FakeAndroidPlatformView>[
-          const FakeAndroidPlatformView(0, 'webview', null, AndroidViewController.kAndroidLayoutDirectionLtr,
-            hybrid: true),
-          const FakeAndroidPlatformView(1, 'webview', null, AndroidViewController.kAndroidLayoutDirectionRtl,
-            hybrid: true),
+          const FakeAndroidPlatformView(
+            0,
+            'webview',
+            null,
+            AndroidViewController.kAndroidLayoutDirectionLtr,
+            hybrid: true,
+          ),
+          const FakeAndroidPlatformView(
+            1,
+            'webview',
+            null,
+            AndroidViewController.kAndroidLayoutDirectionRtl,
+            hybrid: true,
+          ),
         ]),
       );
     });
 
     test('default view does not use view composition by default', () async {
       viewsController.registerViewType('webview');
-      final AndroidViewController controller = PlatformViewsService.initAndroidView(id: 0, viewType: 'webview', layoutDirection: TextDirection.ltr);
+      final AndroidViewController controller = PlatformViewsService.initAndroidView(
+        id: 0,
+        viewType: 'webview',
+        layoutDirection: TextDirection.ltr,
+      );
       await controller.create(size: const Size(100.0, 100.0));
       expect(controller.requiresViewComposition, false);
     });
@@ -107,7 +159,11 @@ void main() {
     test('default view does not use view composition in fallback mode', () async {
       viewsController.registerViewType('webview');
       viewsController.allowTextureLayerMode = false;
-      final AndroidViewController controller = PlatformViewsService.initAndroidView(id: 0, viewType: 'webview', layoutDirection: TextDirection.ltr);
+      final AndroidViewController controller = PlatformViewsService.initAndroidView(
+        id: 0,
+        viewType: 'webview',
+        layoutDirection: TextDirection.ltr,
+      );
       await controller.create(size: const Size(100.0, 100.0));
       viewsController.allowTextureLayerMode = true;
       expect(controller.requiresViewComposition, false);
@@ -115,7 +171,11 @@ void main() {
 
     test('surface view does not use view composition by default', () async {
       viewsController.registerViewType('webview');
-      final AndroidViewController controller = PlatformViewsService.initSurfaceAndroidView(id: 0, viewType: 'webview', layoutDirection: TextDirection.ltr);
+      final AndroidViewController controller = PlatformViewsService.initSurfaceAndroidView(
+        id: 0,
+        viewType: 'webview',
+        layoutDirection: TextDirection.ltr,
+      );
       await controller.create(size: const Size(100.0, 100.0));
       expect(controller.requiresViewComposition, false);
     });
@@ -123,7 +183,11 @@ void main() {
     test('surface view does uses view composition in fallback mode', () async {
       viewsController.registerViewType('webview');
       viewsController.allowTextureLayerMode = false;
-      final AndroidViewController controller = PlatformViewsService.initSurfaceAndroidView(id: 0, viewType: 'webview', layoutDirection: TextDirection.ltr);
+      final AndroidViewController controller = PlatformViewsService.initSurfaceAndroidView(
+        id: 0,
+        viewType: 'webview',
+        layoutDirection: TextDirection.ltr,
+      );
       await controller.create(size: const Size(100.0, 100.0));
       viewsController.allowTextureLayerMode = true;
       expect(controller.requiresViewComposition, true);
@@ -131,7 +195,11 @@ void main() {
 
     test('expensive view uses view composition', () async {
       viewsController.registerViewType('webview');
-      final AndroidViewController controller = PlatformViewsService.initExpensiveAndroidView(id: 0, viewType: 'webview', layoutDirection: TextDirection.ltr);
+      final AndroidViewController controller = PlatformViewsService.initExpensiveAndroidView(
+        id: 0,
+        viewType: 'webview',
+        layoutDirection: TextDirection.ltr,
+      );
       await controller.create(size: const Size(100.0, 100.0));
       expect(controller.requiresViewComposition, true);
     });
@@ -144,17 +212,14 @@ void main() {
         layoutDirection: TextDirection.ltr,
       );
       await controller.create(size: const Size(100.0, 100.0));
-      expectLater(
-        () {
-          final AndroidViewController controller = PlatformViewsService.initAndroidView(
-            id: 0,
-            viewType: 'web',
-            layoutDirection: TextDirection.ltr,
-          );
-          return controller.create(size: const Size(100.0, 100.0));
-        },
-        throwsA(isA<PlatformException>()),
-      );
+      await expectLater(() {
+        final AndroidViewController controller = PlatformViewsService.initAndroidView(
+          id: 0,
+          viewType: 'web',
+          layoutDirection: TextDirection.ltr,
+        );
+        return controller.create(size: const Size(100.0, 100.0));
+      }, throwsA(isA<PlatformException>()));
     });
 
     test('dispose Android view', () async {
@@ -173,18 +238,24 @@ void main() {
       await viewController.create(size: const Size(200.0, 300.0));
       await viewController.dispose();
 
-      final AndroidViewController surfaceViewController = PlatformViewsService.initSurfaceAndroidView(
-        id: 1,
-        viewType: 'webview',
-        layoutDirection: TextDirection.ltr,
-      );
+      final AndroidViewController surfaceViewController =
+          PlatformViewsService.initSurfaceAndroidView(
+            id: 1,
+            viewType: 'webview',
+            layoutDirection: TextDirection.ltr,
+          );
       await surfaceViewController.create(size: const Size(200.0, 300.0));
       await surfaceViewController.dispose();
 
       expect(
         viewsController.views,
         unorderedEquals(<FakeAndroidPlatformView>[
-          const FakeAndroidPlatformView(0, 'webview', Size(100.0, 100.0), AndroidViewController.kAndroidLayoutDirectionLtr),
+          const FakeAndroidPlatformView(
+            0,
+            'webview',
+            Size(100.0, 100.0),
+            AndroidViewController.kAndroidLayoutDirectionLtr,
+          ),
         ]),
       );
     });
@@ -208,13 +279,20 @@ void main() {
         id: 0,
         viewType: 'webview',
         layoutDirection: TextDirection.ltr,
-        onFocus: () { didFocus = true; },
+        onFocus: () {
+          didFocus = true;
+        },
       );
       await viewController.create(size: const Size(100.0, 100.0));
       await viewController.dispose();
-      final ByteData message =
-          SystemChannels.platform_views.codec.encodeMethodCall(const MethodCall('viewFocused', 0));
-      await binding.defaultBinaryMessenger.handlePlatformMessage(SystemChannels.platform_views.name, message, (_) { });
+      final ByteData message = SystemChannels.platform_views.codec.encodeMethodCall(
+        const MethodCall('viewFocused', 0),
+      );
+      await binding.defaultBinaryMessenger.handlePlatformMessage(
+        SystemChannels.platform_views.name,
+        message,
+        (_) {},
+      );
       expect(didFocus, isFalse);
     });
 
@@ -237,8 +315,18 @@ void main() {
       expect(
         viewsController.views,
         unorderedEquals(<FakeAndroidPlatformView>[
-          const FakeAndroidPlatformView(0, 'webview', Size(100.0, 100.0), AndroidViewController.kAndroidLayoutDirectionLtr),
-          const FakeAndroidPlatformView(1, 'webview', Size(500.0, 500.0), AndroidViewController.kAndroidLayoutDirectionLtr),
+          const FakeAndroidPlatformView(
+            0,
+            'webview',
+            Size(100.0, 100.0),
+            AndroidViewController.kAndroidLayoutDirectionLtr,
+          ),
+          const FakeAndroidPlatformView(
+            1,
+            'webview',
+            Size(500.0, 500.0),
+            AndroidViewController.kAndroidLayoutDirectionLtr,
+          ),
         ]),
       );
     });
@@ -246,7 +334,9 @@ void main() {
     test('OnPlatformViewCreated callback', () async {
       viewsController.registerViewType('webview');
       final List<int> createdViews = <int>[];
-      void callback(int id) { createdViews.add(id); }
+      void callback(int id) {
+        createdViews.add(id);
+      }
 
       final AndroidViewController controller1 = PlatformViewsService.initAndroidView(
         id: 0,
@@ -295,7 +385,12 @@ void main() {
       expect(
         viewsController.views,
         unorderedEquals(<FakeAndroidPlatformView>[
-          const FakeAndroidPlatformView(0, 'webview', Size(100.0, 100.0), AndroidViewController.kAndroidLayoutDirectionLtr),
+          const FakeAndroidPlatformView(
+            0,
+            'webview',
+            Size(100.0, 100.0),
+            AndroidViewController.kAndroidLayoutDirectionLtr,
+          ),
         ]),
       );
     });
@@ -312,7 +407,12 @@ void main() {
       expect(
         viewsController.views,
         unorderedEquals(<FakeAndroidPlatformView>[
-          const FakeAndroidPlatformView(0, 'webview', Size(100.0, 100.0), AndroidViewController.kAndroidLayoutDirectionRtl),
+          const FakeAndroidPlatformView(
+            0,
+            'webview',
+            Size(100.0, 100.0),
+            AndroidViewController.kAndroidLayoutDirectionRtl,
+          ),
         ]),
       );
     });
@@ -326,12 +426,7 @@ void main() {
       );
       await viewController.create(size: const Size(100.0, 100.0));
       await viewController.setOffset(const Offset(10, 20));
-      expect(
-        viewsController.offsets,
-        equals(<int, Offset>{
-          7: const Offset(10, 20),
-        }),
-      );
+      expect(viewsController.offsets, equals(<int, Offset>{7: const Offset(10, 20)}));
     });
 
     test("doesn't set Android view's offset if view isn't created", () async {
@@ -353,22 +448,27 @@ void main() {
     });
 
     test('create iOS view of unregistered type', () async {
-      expect(
-        () {
-          return PlatformViewsService.initUiKitView(
-            id: 0,
-            viewType: 'web',
-            layoutDirection: TextDirection.ltr,
-          );
-        },
-        throwsA(isA<PlatformException>()),
-      );
+      expect(() {
+        return PlatformViewsService.initUiKitView(
+          id: 0,
+          viewType: 'web',
+          layoutDirection: TextDirection.ltr,
+        );
+      }, throwsA(isA<PlatformException>()));
     });
 
     test('create iOS views', () async {
       viewsController.registerViewType('webview');
-      await PlatformViewsService.initUiKitView(id: 0, viewType: 'webview', layoutDirection: TextDirection.ltr);
-      await PlatformViewsService.initUiKitView(id: 1, viewType: 'webview', layoutDirection: TextDirection.rtl);
+      await PlatformViewsService.initUiKitView(
+        id: 0,
+        viewType: 'webview',
+        layoutDirection: TextDirection.ltr,
+      );
+      await PlatformViewsService.initUiKitView(
+        id: 1,
+        viewType: 'webview',
+        layoutDirection: TextDirection.rtl,
+      );
       expect(
         viewsController.views,
         unorderedEquals(<FakeUiKitView>[
@@ -386,14 +486,22 @@ void main() {
         layoutDirection: TextDirection.ltr,
       );
       expect(
-        () => PlatformViewsService.initUiKitView(id: 0, viewType: 'web', layoutDirection: TextDirection.ltr),
+        () => PlatformViewsService.initUiKitView(
+          id: 0,
+          viewType: 'web',
+          layoutDirection: TextDirection.ltr,
+        ),
         throwsA(isA<PlatformException>()),
       );
     });
 
     test('dispose iOS view', () async {
       viewsController.registerViewType('webview');
-      await PlatformViewsService.initUiKitView(id: 0, viewType: 'webview', layoutDirection: TextDirection.ltr);
+      await PlatformViewsService.initUiKitView(
+        id: 0,
+        viewType: 'webview',
+        layoutDirection: TextDirection.ltr,
+      );
       final UiKitViewController viewController = await PlatformViewsService.initUiKitView(
         id: 1,
         viewType: 'webview',
@@ -403,32 +511,34 @@ void main() {
       viewController.dispose();
       expect(
         viewsController.views,
-        unorderedEquals(<FakeUiKitView>[
-          const FakeUiKitView(0, 'webview'),
-        ]),
+        unorderedEquals(<FakeUiKitView>[const FakeUiKitView(0, 'webview')]),
       );
     });
 
     test('dispose inexisting iOS view', () async {
       viewsController.registerViewType('webview');
-      await PlatformViewsService.initUiKitView(id: 0, viewType: 'webview', layoutDirection: TextDirection.ltr);
+      await PlatformViewsService.initUiKitView(
+        id: 0,
+        viewType: 'webview',
+        layoutDirection: TextDirection.ltr,
+      );
       final UiKitViewController viewController = await PlatformViewsService.initUiKitView(
         id: 1,
         viewType: 'webview',
         layoutDirection: TextDirection.ltr,
       );
       await viewController.dispose();
-      expect(
-        () async {
-          await viewController.dispose();
-        },
-        throwsA(isA<PlatformException>()),
-      );
+      expect(() async {
+        await viewController.dispose();
+      }, throwsA(isA<PlatformException>()));
     });
   });
 
   test('toString works as intended', () async {
-    const AndroidPointerProperties androidPointerProperties = AndroidPointerProperties(id: 0, toolType: 0);
+    const AndroidPointerProperties androidPointerProperties = AndroidPointerProperties(
+      id: 0,
+      toolType: 0,
+    );
     expect(androidPointerProperties.toString(), 'AndroidPointerProperties(id: 0, toolType: 0)');
 
     const double zero = 0.0;
@@ -441,9 +551,11 @@ void main() {
       touchMajor: zero,
       touchMinor: zero,
       x: zero,
-      y: zero
+      y: zero,
     );
-    expect(androidPointerCoords.toString(), 'AndroidPointerCoords(orientation: $zero, '
+    expect(
+      androidPointerCoords.toString(),
+      'AndroidPointerCoords(orientation: $zero, '
       'pressure: $zero, '
       'size: $zero, '
       'toolMajor: $zero, '
@@ -469,9 +581,11 @@ void main() {
       edgeFlags: 0,
       source: 0,
       flags: 0,
-      motionEventId: 0
+      motionEventId: 0,
     );
-    expect(androidMotionEvent.toString(), 'AndroidPointerEvent(downTime: 0, '
+    expect(
+      androidMotionEvent.toString(),
+      'AndroidPointerEvent(downTime: 0, '
       'eventTime: 0, '
       'action: 0, '
       'pointerCount: 0, '
