@@ -10,10 +10,112 @@ library;
 import 'dart:ui';
 
 import 'package:flutter/material.dart';
+import 'package:flutter/rendering.dart';
 import 'package:flutter_test/flutter_test.dart';
 
 void main() {
-  testWidgets("Material2 - BackdropFilter's cull rect does not shrink", (WidgetTester tester) async {
+  testWidgets('Backdrop key is passed to backdrop Layer', (WidgetTester tester) async {
+    final BackdropKey backdropKey = BackdropKey();
+
+    Widget build({required bool enableKeys}) {
+      return MaterialApp(
+        home: Scaffold(
+          body: ListView(
+            children: <Widget>[
+              ClipRect(
+                child: BackdropFilter(
+                  filter: ImageFilter.blur(sigmaX: 40, sigmaY: 40),
+                  backdropGroupKey: enableKeys ? backdropKey : null,
+                  child: Container(
+                    color: Colors.black.withAlpha(40),
+                    height: 200,
+                    child: const Text('Item 1'),
+                  ),
+                ),
+              ),
+              ClipRect(
+                child: BackdropFilter(
+                  filter: ImageFilter.blur(sigmaX: 40, sigmaY: 40),
+                  backdropGroupKey: enableKeys ? backdropKey : null,
+                  child: Container(
+                    color: Colors.black.withAlpha(40),
+                    height: 200,
+                    child: const Text('Item 1'),
+                  ),
+                ),
+              ),
+            ],
+          ),
+        ),
+      );
+    }
+
+    await tester.pumpWidget(build(enableKeys: true));
+
+    List<BackdropFilterLayer> layers = tester.layers.whereType<BackdropFilterLayer>().toList();
+
+    expect(layers.length, 2);
+    expect(layers[0].backdropKey, backdropKey);
+    expect(layers[1].backdropKey, backdropKey);
+
+    await tester.pumpWidget(build(enableKeys: false));
+
+    layers = tester.layers.whereType<BackdropFilterLayer>().toList();
+
+    expect(layers.length, 2);
+    expect(layers[0].backdropKey, null);
+    expect(layers[1].backdropKey, null);
+  });
+
+  testWidgets('Backdrop key is passed to backdrop Layer via backdrop group', (
+    WidgetTester tester,
+  ) async {
+    Widget build() {
+      return MaterialApp(
+        home: Scaffold(
+          body: BackdropGroup(
+            child: ListView(
+              children: <Widget>[
+                ClipRect(
+                  child: BackdropFilter.grouped(
+                    filter: ImageFilter.blur(sigmaX: 40, sigmaY: 40),
+                    child: Container(
+                      color: Colors.black.withAlpha(40),
+                      height: 200,
+                      child: const Text('Item 1'),
+                    ),
+                  ),
+                ),
+                ClipRect(
+                  child: BackdropFilter.grouped(
+                    filter: ImageFilter.blur(sigmaX: 40, sigmaY: 40),
+                    child: Container(
+                      color: Colors.black.withAlpha(40),
+                      height: 200,
+                      child: const Text('Item 1'),
+                    ),
+                  ),
+                ),
+              ],
+            ),
+          ),
+        ),
+      );
+    }
+
+    await tester.pumpWidget(build());
+
+    final List<BackdropFilterLayer> layers = tester.layers
+        .whereType<BackdropFilterLayer>()
+        .toList();
+
+    expect(layers.length, 2);
+    expect(layers[0].backdropKey, layers[1].backdropKey);
+  });
+
+  testWidgets("Material2 - BackdropFilter's cull rect does not shrink", (
+    WidgetTester tester,
+  ) async {
     await tester.pumpWidget(
       MaterialApp(
         theme: ThemeData(useMaterial3: false),
@@ -27,10 +129,7 @@ void main() {
                 // whole screen.
                 child: ClipRect(
                   child: BackdropFilter(
-                    filter: ImageFilter.blur(
-                      sigmaX: 5.0,
-                      sigmaY: 5.0,
-                    ),
+                    filter: ImageFilter.blur(sigmaX: 5.0, sigmaY: 5.0),
                     child: Container(
                       alignment: Alignment.center,
                       width: 200.0,
@@ -51,10 +150,11 @@ void main() {
     );
   });
 
-  testWidgets("Material3 - BackdropFilter's cull rect does not shrink", (WidgetTester tester) async {
+  testWidgets("Material3 - BackdropFilter's cull rect does not shrink", (
+    WidgetTester tester,
+  ) async {
     await tester.pumpWidget(
       MaterialApp(
-        theme: ThemeData(useMaterial3: true),
         home: Scaffold(
           body: Stack(
             fit: StackFit.expand,
@@ -65,10 +165,7 @@ void main() {
                 // whole screen.
                 child: ClipRect(
                   child: BackdropFilter(
-                    filter: ImageFilter.blur(
-                      sigmaX: 5.0,
-                      sigmaY: 5.0,
-                    ),
+                    filter: ImageFilter.blur(sigmaX: 5.0, sigmaY: 5.0),
                     child: Container(
                       alignment: Alignment.center,
                       width: 200.0,
@@ -107,10 +204,7 @@ void main() {
                   children: <Widget>[
                     ClipRect(
                       child: BackdropFilter(
-                        filter: ImageFilter.blur(
-                          sigmaX: 5.0,
-                          sigmaY: 5.0,
-                        ),
+                        filter: ImageFilter.blur(sigmaX: 5.0, sigmaY: 5.0),
                         child: Container(
                           alignment: Alignment.center,
                           width: 200.0,
@@ -121,10 +215,7 @@ void main() {
                     ),
                     ClipRect(
                       child: BackdropFilter(
-                        filter: ImageFilter.blur(
-                          sigmaX: 5.0,
-                          sigmaY: 5.0,
-                        ),
+                        filter: ImageFilter.blur(sigmaX: 5.0, sigmaY: 5.0),
                         blendMode: BlendMode.src,
                         child: Container(
                           alignment: Alignment.center,
@@ -151,7 +242,6 @@ void main() {
   testWidgets('Material3 - BackdropFilter blendMode on saveLayer', (WidgetTester tester) async {
     await tester.pumpWidget(
       MaterialApp(
-        theme: ThemeData(useMaterial3: true),
         home: Scaffold(
           body: Opacity(
             opacity: 0.9,
@@ -166,10 +256,7 @@ void main() {
                   children: <Widget>[
                     ClipRect(
                       child: BackdropFilter(
-                        filter: ImageFilter.blur(
-                          sigmaX: 5.0,
-                          sigmaY: 5.0,
-                        ),
+                        filter: ImageFilter.blur(sigmaX: 5.0, sigmaY: 5.0),
                         child: Container(
                           alignment: Alignment.center,
                           width: 200.0,
@@ -180,10 +267,7 @@ void main() {
                     ),
                     ClipRect(
                       child: BackdropFilter(
-                        filter: ImageFilter.blur(
-                          sigmaX: 5.0,
-                          sigmaY: 5.0,
-                        ),
+                        filter: ImageFilter.blur(sigmaX: 5.0, sigmaY: 5.0),
                         blendMode: BlendMode.src,
                         child: Container(
                           alignment: Alignment.center,
