@@ -25,21 +25,17 @@ void main() {
             stateSetter = setState;
             return GridView.builder(
               itemCount: itemCount,
-              itemBuilder: (BuildContext _, int index) => Container(
-                key: Key('$index'),
-                height: 2000.0,
-              ),
+              itemBuilder: (BuildContext _, int index) =>
+                  Container(key: Key('$index'), height: 2000.0),
               findChildIndexCallback: (Key key) {
                 finderCalled = true;
                 return null;
               },
-              gridDelegate: const SliverGridDelegateWithFixedCrossAxisCount(
-                crossAxisCount: 4,
-              ),
+              gridDelegate: const SliverGridDelegateWithFixedCrossAxisCount(crossAxisCount: 4),
             );
           },
         ),
-      )
+      ),
     );
     expect(finderCalled, false);
 
@@ -54,10 +50,7 @@ void main() {
     await tester.pumpWidget(
       Directionality(
         textDirection: TextDirection.ltr,
-        child: GridView.count(
-          dragStartBehavior: DragStartBehavior.down,
-          crossAxisCount: 4,
-        ),
+        child: GridView.count(dragStartBehavior: DragStartBehavior.down, crossAxisCount: 4),
       ),
     );
   });
@@ -77,10 +70,7 @@ void main() {
               onTap: () {
                 log.add(state);
               },
-              child: ColoredBox(
-                color: const Color(0xFF0000FF),
-                child: Text(state),
-              ),
+              child: ColoredBox(color: const Color(0xFF0000FF), child: Text(state)),
             );
           }).toList(),
         ),
@@ -150,10 +140,7 @@ void main() {
               onTap: () {
                 log.add(state);
               },
-              child: ColoredBox(
-                color: const Color(0xFF0000FF),
-                child: Text(state),
-              ),
+              child: ColoredBox(color: const Color(0xFF0000FF), child: Text(state)),
             );
           }).toList(),
         ),
@@ -206,12 +193,15 @@ void main() {
 
     expect(tester.getSize(find.text('4')), equals(const Size(200.0 / 0.75, 200.0)));
 
-    expect(log, equals(<int>[
-      0, 1, 2, // col 0
-      3, 4, 5, // col 1
-      6, 7, 8, // col 2
-      9, 10, 11, // col 3 (in cached area)
-    ]));
+    expect(
+      log,
+      equals(<int>[
+        0, 1, 2, // col 0
+        3, 4, 5, // col 1
+        6, 7, 8, // col 2
+        9, 10, 11, // col 3 (in cached area)
+      ]),
+    );
     log.clear();
 
     for (int i = 0; i < 9; i++) {
@@ -228,14 +218,17 @@ void main() {
     expect(log, isEmpty);
     await tester.pump();
 
-    expect(log, equals(<int>[
-      30, 31, 32, // col 10 (in cached area)
-      33, 34, 35, // col 11
-      36, 37, 38, // col 12
-      39, 40, 41, // col 13
-      42, 43, 44, // col 14
-      45, 46, 47, // col 15 (in cached area)
-    ]));
+    expect(
+      log,
+      equals(<int>[
+        30, 31, 32, // col 10 (in cached area)
+        33, 34, 35, // col 11
+        36, 37, 38, // col 12
+        39, 40, 41, // col 13
+        42, 43, 44, // col 14
+        45, 46, 47, // col 15 (in cached area)
+      ]),
+    );
     log.clear();
 
     for (int i = 0; i < 33; i++) {
@@ -253,14 +246,17 @@ void main() {
     expect(log, isEmpty);
     await tester.pump();
 
-    expect(log, equals(<int>[
-      6, 7, 8, // col2 (in cached area)
-      9, 10, 11, // col 3
-      12, 13, 14, // col 4
-      15, 16, 17, // col 5
-      18, 19, 20, // col 6
-      21, 22, 23, // col 7 (in cached area)
-    ]));
+    expect(
+      log,
+      equals(<int>[
+        6, 7, 8, // col2 (in cached area)
+        9, 10, 11, // col 3
+        12, 13, 14, // col 4
+        15, 16, 17, // col 5
+        18, 19, 20, // col 6
+        21, 22, 23, // col 7 (in cached area)
+      ]),
+    );
     log.clear();
 
     for (int i = 0; i < 9; i++) {
@@ -281,9 +277,7 @@ void main() {
       Directionality(
         textDirection: TextDirection.ltr,
         child: GridView(
-          gridDelegate: const SliverGridDelegateWithFixedCrossAxisCount(
-            crossAxisCount: 4,
-          ),
+          gridDelegate: const SliverGridDelegateWithFixedCrossAxisCount(crossAxisCount: 4),
           children: List<Widget>.generate(40, (int i) {
             return Builder(
               builder: (BuildContext context) {
@@ -298,13 +292,16 @@ void main() {
 
     expect(tester.getSize(find.text('4')), equals(const Size(200.0, 200.0)));
 
-    expect(log, equals(<int>[
-      0, 1, 2, 3, // row 0
-      4, 5, 6, 7, // row 1
-      8, 9, 10, 11, // row 2
-      12, 13, 14, 15, // row 3 (in cached area)
-      16, 17, 18, 19, // row 4 (in cached area)
-    ]));
+    expect(
+      log,
+      equals(<int>[
+        0, 1, 2, 3, // row 0
+        4, 5, 6, 7, // row 1
+        8, 9, 10, 11, // row 2
+        12, 13, 14, 15, // row 3 (in cached area)
+        16, 17, 18, 19, // row 4 (in cached area)
+      ]),
+    );
     for (int i = 0; i < 12; i++) {
       expect(find.text('$i'), findsOneWidget);
     }
@@ -317,9 +314,7 @@ void main() {
       Directionality(
         textDirection: TextDirection.ltr,
         child: GridView(
-          gridDelegate: const SliverGridDelegateWithFixedCrossAxisCount(
-            crossAxisCount: 2,
-          ),
+          gridDelegate: const SliverGridDelegateWithFixedCrossAxisCount(crossAxisCount: 2),
           children: List<Widget>.generate(40, (int i) {
             return Builder(
               builder: (BuildContext context) {
@@ -332,24 +327,30 @@ void main() {
       ),
     );
 
-    expect(log, equals(<int>[
-      0, 1, 2, 3, // row 0
-      4, 5, 6, 7, // row 1
-      8, 9, 10, 11, // row 2
-      12, 13, 14, 15, // row 3 (in cached area)
-      16, 17, 18, 19, // row 4 (in cached area)
-    ]));
+    expect(
+      log,
+      equals(<int>[
+        0, 1, 2, 3, // row 0
+        4, 5, 6, 7, // row 1
+        8, 9, 10, 11, // row 2
+        12, 13, 14, 15, // row 3 (in cached area)
+        16, 17, 18, 19, // row 4 (in cached area)
+      ]),
+    );
     log.clear();
 
     expect(tester.getSize(find.text('3')), equals(const Size(400.0, 400.0)));
     expect(find.text('4'), findsNothing);
   });
 
-  testWidgets('SliverGridRegularTileLayout - can handle close to zero mainAxisStride', (WidgetTester tester) async {
-    const SliverGridDelegateWithMaxCrossAxisExtent delegate = SliverGridDelegateWithMaxCrossAxisExtent(
-      childAspectRatio: 1e300,
-      maxCrossAxisExtent: 500.0,
-    );
+  testWidgets('SliverGridRegularTileLayout - can handle close to zero mainAxisStride', (
+    WidgetTester tester,
+  ) async {
+    const SliverGridDelegateWithMaxCrossAxisExtent delegate =
+        SliverGridDelegateWithMaxCrossAxisExtent(
+          childAspectRatio: 1e300,
+          maxCrossAxisExtent: 500.0,
+        );
     final SliverGridLayout layout = delegate.getLayout(
       const SliverConstraints(
         axisDirection: AxisDirection.down,
@@ -376,9 +377,7 @@ void main() {
       Directionality(
         textDirection: TextDirection.ltr,
         child: GridView(
-          gridDelegate: const SliverGridDelegateWithMaxCrossAxisExtent(
-            maxCrossAxisExtent: 200.0,
-          ),
+          gridDelegate: const SliverGridDelegateWithMaxCrossAxisExtent(maxCrossAxisExtent: 200.0),
           children: List<Widget>.generate(40, (int i) {
             return Builder(
               builder: (BuildContext context) {
@@ -393,13 +392,16 @@ void main() {
 
     expect(tester.getSize(find.text('4')), equals(const Size(200.0, 200.0)));
 
-    expect(log, equals(<int>[
-      0, 1, 2, 3, // row 0
-      4, 5, 6, 7, // row 1
-      8, 9, 10, 11, // row 2
-      12, 13, 14, 15, // row 3 (in cached area)
-      16, 17, 18, 19, // row 4 (in cached area)
-    ]));
+    expect(
+      log,
+      equals(<int>[
+        0, 1, 2, 3, // row 0
+        4, 5, 6, 7, // row 1
+        8, 9, 10, 11, // row 2
+        12, 13, 14, 15, // row 3 (in cached area)
+        16, 17, 18, 19, // row 4 (in cached area)
+      ]),
+    );
     for (int i = 0; i < 12; i++) {
       expect(find.text('$i'), findsOneWidget);
     }
@@ -412,9 +414,7 @@ void main() {
       Directionality(
         textDirection: TextDirection.ltr,
         child: GridView(
-          gridDelegate: const SliverGridDelegateWithMaxCrossAxisExtent(
-            maxCrossAxisExtent: 400.0,
-          ),
+          gridDelegate: const SliverGridDelegateWithMaxCrossAxisExtent(maxCrossAxisExtent: 400.0),
           children: List<Widget>.generate(40, (int i) {
             return Builder(
               builder: (BuildContext context) {
@@ -427,13 +427,16 @@ void main() {
       ),
     );
 
-    expect(log, equals(<int>[
-      0, 1, 2, 3, // row 0
-      4, 5, 6, 7, // row 1
-      8, 9, 10, 11, // row 2
-      12, 13, 14, 15, // row 3 (in cached area)
-      16, 17, 18, 19, // row 4 (in cached area)
-    ]));
+    expect(
+      log,
+      equals(<int>[
+        0, 1, 2, 3, // row 0
+        4, 5, 6, 7, // row 1
+        8, 9, 10, 11, // row 2
+        12, 13, 14, 15, // row 3 (in cached area)
+        16, 17, 18, 19, // row 4 (in cached area)
+      ]),
+    );
     log.clear();
 
     expect(tester.getSize(find.text('3')), equals(const Size(400.0, 400.0)));
@@ -443,11 +446,7 @@ void main() {
   testWidgets('One-line GridView paints', (WidgetTester tester) async {
     const Color green = Color(0xFF00FF00);
 
-    final Container container = Container(
-      decoration: const BoxDecoration(
-        color: green,
-      ),
-    );
+    final Container container = Container(decoration: const BoxDecoration(color: green));
 
     await tester.pumpWidget(
       Directionality(
@@ -458,15 +457,28 @@ void main() {
             child: GridView.count(
               cacheExtent: 0.0,
               crossAxisCount: 2,
-              children: <Widget>[ container, container, container, container ],
+              children: <Widget>[container, container, container, container],
             ),
           ),
         ),
       ),
     );
 
-    expect(find.byType(GridView), paints..rect(color: green)..rect(color: green));
-    expect(find.byType(GridView), isNot(paints..rect(color: green)..rect(color: green)..rect(color: green)));
+    expect(
+      find.byType(GridView),
+      paints
+        ..rect(color: green)
+        ..rect(color: green),
+    );
+    expect(
+      find.byType(GridView),
+      isNot(
+        paints
+          ..rect(color: green)
+          ..rect(color: green)
+          ..rect(color: green),
+      ),
+    );
   });
 
   testWidgets('GridView in zero context', (WidgetTester tester) async {
@@ -515,9 +527,7 @@ void main() {
       Directionality(
         textDirection: TextDirection.ltr,
         child: GridView.builder(
-          gridDelegate: const SliverGridDelegateWithFixedCrossAxisCount(
-            crossAxisCount: 4,
-          ),
+          gridDelegate: const SliverGridDelegateWithFixedCrossAxisCount(crossAxisCount: 4),
           shrinkWrap: true,
           itemCount: 20,
           itemBuilder: (BuildContext context, int index) {
@@ -536,9 +546,7 @@ void main() {
       Directionality(
         textDirection: TextDirection.ltr,
         child: GridView.builder(
-          gridDelegate: const SliverGridDelegateWithFixedCrossAxisCount(
-            crossAxisCount: 4,
-          ),
+          gridDelegate: const SliverGridDelegateWithFixedCrossAxisCount(crossAxisCount: 4),
           shrinkWrap: true,
           itemBuilder: (BuildContext context, int index) {
             return Text('$index');
@@ -559,12 +567,7 @@ void main() {
     Widget build(TextDirection textDirection) {
       return Directionality(
         textDirection: textDirection,
-        child: GridView.count(
-          crossAxisCount: 4,
-          children: <Widget>[
-            Container(key: target),
-          ],
-        ),
+        child: GridView.count(crossAxisCount: 4, children: <Widget>[Container(key: target)]),
       );
     }
 
@@ -589,9 +592,7 @@ void main() {
         child: GridView.count(
           crossAxisCount: 4,
           crossAxisSpacing: 8.0,
-          children: <Widget>[
-            Container(key: target),
-          ],
+          children: <Widget>[Container(key: target)],
         ),
       );
     }
@@ -610,21 +611,19 @@ void main() {
   testWidgets('GridView does not cache itemBuilder calls', (WidgetTester tester) async {
     final Map<int, int> counters = <int, int>{};
 
-    await tester.pumpWidget(Directionality(
-      textDirection: TextDirection.ltr,
-      child: GridView.builder(
-        itemCount: 1000,
-        gridDelegate: const SliverGridDelegateWithFixedCrossAxisCount(crossAxisCount: 3),
-        itemBuilder: (BuildContext context, int index) {
-          counters[index] = (counters[index] ?? 0) + 1;
-          return SizedBox(
-            key: ValueKey<int>(index),
-            width: 200,
-            height: 200,
-          );
-        },
+    await tester.pumpWidget(
+      Directionality(
+        textDirection: TextDirection.ltr,
+        child: GridView.builder(
+          itemCount: 1000,
+          gridDelegate: const SliverGridDelegateWithFixedCrossAxisCount(crossAxisCount: 3),
+          itemBuilder: (BuildContext context, int index) {
+            counters[index] = (counters[index] ?? 0) + 1;
+            return SizedBox(key: ValueKey<int>(index), width: 200, height: 200);
+          },
+        ),
       ),
-    ));
+    );
 
     expect(find.byKey(const ValueKey<int>(4)), findsOneWidget);
     expect(counters[4], 1);
@@ -642,15 +641,15 @@ void main() {
     expect(counters[4], 2);
   });
 
-  testWidgets('GridView does not report visual overflow unnecessarily', (WidgetTester tester) async {
+  testWidgets('GridView does not report visual overflow unnecessarily', (
+    WidgetTester tester,
+  ) async {
     await tester.pumpWidget(
       Directionality(
         textDirection: TextDirection.ltr,
         child: GridView(
           gridDelegate: const SliverGridDelegateWithFixedCrossAxisCount(crossAxisCount: 3),
-          children: <Widget>[
-            Container(height: 200.0),
-          ],
+          children: <Widget>[Container(height: 200.0)],
         ),
       ),
     );
@@ -740,7 +739,7 @@ void main() {
         child: GridView.builder(
           gridDelegate: const SliverGridDelegateWithFixedCrossAxisCount(crossAxisCount: 3),
           itemCount: 10,
-          itemBuilder: (BuildContext _, int __) => Container(height: 2000.0),
+          itemBuilder: (BuildContext _, int _) => Container(height: 2000.0),
           clipBehavior: Clip.antiAlias,
         ),
       ),
@@ -756,7 +755,7 @@ void main() {
         child: GridView.custom(
           gridDelegate: const SliverGridDelegateWithFixedCrossAxisCount(crossAxisCount: 3),
           childrenDelegate: SliverChildBuilderDelegate(
-                (BuildContext context, int index) => Container(height: 2000.0),
+            (BuildContext context, int index) => Container(height: 2000.0),
             childCount: 1,
           ),
           clipBehavior: Clip.antiAlias,
@@ -797,7 +796,9 @@ void main() {
     expect(renderObject.clipBehavior, equals(Clip.antiAlias));
   });
 
-  testWidgets('SliverGridDelegateWithFixedCrossAxisCount mainAxisExtent works as expected', (WidgetTester tester) async {
+  testWidgets('SliverGridDelegateWithFixedCrossAxisCount mainAxisExtent works as expected', (
+    WidgetTester tester,
+  ) async {
     const int crossAxisCount = 4;
     const double mainAxisExtent = 100.0;
 
@@ -823,7 +824,9 @@ void main() {
     expect(tester.getSize(find.text('4')), equals(const Size(200.0, mainAxisExtent)));
   });
 
-  testWidgets('SliverGridDelegateWithMaxCrossAxisExtent mainAxisExtent works as expected', (WidgetTester tester) async {
+  testWidgets('SliverGridDelegateWithMaxCrossAxisExtent mainAxisExtent works as expected', (
+    WidgetTester tester,
+  ) async {
     const double maxCrossAxisExtent = 200.0;
     const double mainAxisExtent = 100.0;
 
@@ -849,44 +852,52 @@ void main() {
     expect(tester.getSize(find.text('4')), equals(const Size(200.0, mainAxisExtent)));
   });
 
-  testWidgets('SliverGridDelegateWithMaxCrossAxisExtent throws assertion error when maxCrossAxisExtent is 0', (WidgetTester tester) async {
-    const double maxCrossAxisExtent = 0;
+  testWidgets(
+    'SliverGridDelegateWithMaxCrossAxisExtent throws assertion error when maxCrossAxisExtent is 0',
+    (WidgetTester tester) async {
+      const double maxCrossAxisExtent = 0;
 
-    expect(() => Directionality(
-      textDirection: TextDirection.ltr,
-      child: GridView.extent(
-        maxCrossAxisExtent: maxCrossAxisExtent,
-      ),
-    ), throwsAssertionError);
-  });
+      expect(
+        () => Directionality(
+          textDirection: TextDirection.ltr,
+          child: GridView.extent(maxCrossAxisExtent: maxCrossAxisExtent),
+        ),
+        throwsAssertionError,
+      );
+    },
+  );
 
-  testWidgets('SliverGrid sets correct extent for null returning builder delegate', (WidgetTester tester) async {
+  testWidgets('SliverGrid sets correct extent for null returning builder delegate', (
+    WidgetTester tester,
+  ) async {
     // Regression test for https://github.com/flutter/flutter/issues/130685
     final ScrollController controller = ScrollController();
     addTearDown(controller.dispose);
-    await tester.pumpWidget(Directionality(
-      textDirection: TextDirection.ltr,
-      child: GridView.builder(
-        controller: controller,
-        gridDelegate: const SliverGridDelegateWithFixedCrossAxisCount(
-          crossAxisCount: 3,
-          crossAxisSpacing: 16,
-          mainAxisSpacing: 16,
+    await tester.pumpWidget(
+      Directionality(
+        textDirection: TextDirection.ltr,
+        child: GridView.builder(
+          controller: controller,
+          gridDelegate: const SliverGridDelegateWithFixedCrossAxisCount(
+            crossAxisCount: 3,
+            crossAxisSpacing: 16,
+            mainAxisSpacing: 16,
+          ),
+          itemBuilder: (BuildContext context, int index) {
+            if (index == 12) {
+              return null;
+            }
+            return Container(
+              height: 100,
+              width: 100,
+              color: const Color(0xFFFF8A80),
+              alignment: Alignment.center,
+              child: Text('item ${index + 1}'),
+            );
+          },
         ),
-        itemBuilder: (BuildContext context, int index) {
-          if (index == 12) {
-            return null;
-          }
-          return Container(
-            height: 100,
-            width: 100,
-            color: const Color(0xFFFF8A80),
-            alignment: Alignment.center,
-            child: Text('item ${index+1}'),
-          );
-        },
       ),
-    ));
+    );
     await tester.pumpAndSettle();
 
     expect(controller.position.maxScrollExtent, double.infinity);
@@ -906,11 +917,7 @@ void main() {
         child: GridView.builder(
           gridDelegate: delegate,
           itemBuilder: (BuildContext context, int index) {
-            return Container(
-              height: 50,
-              alignment: Alignment.center,
-              child: Text('$index'),
-            );
+            return Container(height: 50, alignment: Alignment.center, child: Text('$index'));
           },
           itemCount: 50,
         ),
@@ -918,14 +925,16 @@ void main() {
     }
 
     await expectLater(
-      () => tester.pumpWidget(buildGridView(
-        SliverGridDelegateWithFixedCrossAxisCount(
-          crossAxisCount: 3,
-          mainAxisSpacing: 8,
-          crossAxisSpacing: 8,
-          mainAxisExtent: -100,
+      () => tester.pumpWidget(
+        buildGridView(
+          SliverGridDelegateWithFixedCrossAxisCount(
+            crossAxisCount: 3,
+            mainAxisSpacing: 8,
+            crossAxisSpacing: 8,
+            mainAxisExtent: -100,
+          ),
         ),
-      )),
+      ),
       throwsA(
         isAssertionError.having(
           (AssertionError e) => e.toString(),
