@@ -6,17 +6,17 @@
 library;
 
 import 'dart:async';
+import 'dart:ui' show PointerDeviceKind;
 import 'dart:ui_web' as ui_web;
 
-import 'package:collection/collection.dart';
+import 'package:flutter/material.dart';
 import 'package:flutter/rendering.dart';
 import 'package:flutter/services.dart';
-import 'package:flutter/src/widgets/_html_element_view_web.dart'
-    show debugOverridePlatformViewRegistry;
-import 'package:flutter/widgets.dart';
 import 'package:flutter_test/flutter_test.dart';
 import 'package:web/web.dart' as web;
 
+import 'web_platform_view_registry_utils.dart';
+
 final Object _mockHtmlElement = Object();
 Object _mockViewFactory(int id, {Object? params}) {
   return _mockHtmlElement;
@@ -28,16 +28,33 @@ void main() {
   setUp(() {
     fakePlatformViewRegistry = FakePlatformViewRegistry();
 
-    // Simulate the engine registering default factores.
-    fakePlatformViewRegistry.registerViewFactory(ui_web.PlatformViewRegistry.defaultVisibleViewType, (int viewId, {Object? params}) {
-      params!;
-      params as Map<Object?, Object?>;
-      return web.document.createElement(params['tagName']! as String);
-    });
-    fakePlatformViewRegistry.registerViewFactory(ui_web.PlatformViewRegistry.defaultInvisibleViewType, (int viewId, {Object? params}) {
-      params!;
-      params as Map<Object?, Object?>;
-      return web.document.createElement(params['tagName']! as String);
+    // Simulate the engine registering default factories.
+    fakePlatformViewRegistry.registerViewFactory(
+      ui_web.PlatformViewRegistry.defaultVisibleViewType,
+      (int viewId, {Object? params}) {
+        params!;
+        params as Map<Object?, Object?>;
+        return web.document.createElement(params['tagName']! as String);
+      },
+    );
+    fakePlatformViewRegistry.registerViewFactory(
+      ui_web.PlatformViewRegistry.defaultInvisibleViewType,
+      (int viewId, {Object? params}) {
+        params!;
+        params as Map<Object?, Object?>;
+        return web.document.createElement(params['tagName']! as String);
+      },
+    );
+    fakePlatformViewRegistry.registerViewFactory('Browser__WebContextMenuViewType__', (
+      int viewId, {
+      Object? params,
+    }) {
+      final web.HTMLElement htmlElement = web.document.createElement('div') as web.HTMLElement;
+      htmlElement
+        ..style.width = '100%'
+        ..style.height = '100%'
+        ..classList.add('web-selectable-region-context-menu');
+      return htmlElement;
     });
   });
 
@@ -48,11 +65,7 @@ void main() {
 
       await tester.pumpWidget(
         const Center(
-          child: SizedBox(
-            width: 200.0,
-            height: 100.0,
-            child: HtmlElementView(viewType: 'webview'),
-          ),
+          child: SizedBox(width: 200.0, height: 100.0, child: HtmlElementView(viewType: 'webview')),
         ),
       );
 
@@ -106,18 +119,12 @@ void main() {
             SizedBox(
               width: 200.0,
               height: 100.0,
-              child: HtmlElementView(
-                viewType: 'webview',
-                creationParams: 'foobar',
-              ),
+              child: HtmlElementView(viewType: 'webview', creationParams: 'foobar'),
             ),
             SizedBox(
               width: 200.0,
               height: 100.0,
-              child: HtmlElementView(
-                viewType: 'webview',
-                creationParams: 123,
-              ),
+              child: HtmlElementView(viewType: 'webview', creationParams: 123),
             ),
           ],
         ),
@@ -126,7 +133,12 @@ void main() {
       expect(
         fakePlatformViewRegistry.views,
         unorderedEquals(<FakePlatformView>[
-          (id: currentViewId + 1, viewType: 'webview', params: 'foobar', htmlElement: _mockHtmlElement),
+          (
+            id: currentViewId + 1,
+            viewType: 'webview',
+            params: 'foobar',
+            htmlElement: _mockHtmlElement,
+          ),
           (id: currentViewId + 2, viewType: 'webview', params: 123, htmlElement: _mockHtmlElement),
         ]),
       );
@@ -137,11 +149,7 @@ void main() {
       fakePlatformViewRegistry.registerViewFactory('webview', _mockViewFactory);
       await tester.pumpWidget(
         const Center(
-          child: SizedBox(
-            width: 200.0,
-            height: 100.0,
-            child: HtmlElementView(viewType: 'webview'),
-          ),
+          child: SizedBox(width: 200.0, height: 100.0, child: HtmlElementView(viewType: 'webview')),
         ),
       );
 
@@ -149,11 +157,7 @@ void main() {
 
       await tester.pumpWidget(
         const Center(
-          child: SizedBox(
-            width: 100.0,
-            height: 50.0,
-            child: HtmlElementView(viewType: 'webview'),
-          ),
+          child: SizedBox(width: 100.0, height: 50.0, child: HtmlElementView(viewType: 'webview')),
         ),
       );
 
@@ -174,21 +178,13 @@ void main() {
       fakePlatformViewRegistry.registerViewFactory('maps', _mockViewFactory);
       await tester.pumpWidget(
         const Center(
-          child: SizedBox(
-            width: 200.0,
-            height: 100.0,
-            child: HtmlElementView(viewType: 'webview'),
-          ),
+          child: SizedBox(width: 200.0, height: 100.0, child: HtmlElementView(viewType: 'webview')),
         ),
       );
 
       await tester.pumpWidget(
         const Center(
-          child: SizedBox(
-            width: 200.0,
-            height: 100.0,
-            child: HtmlElementView(viewType: 'maps'),
-          ),
+          child: SizedBox(width: 200.0, height: 100.0, child: HtmlElementView(viewType: 'maps')),
         ),
       );
 
@@ -204,27 +200,13 @@ void main() {
       fakePlatformViewRegistry.registerViewFactory('webview', _mockViewFactory);
       await tester.pumpWidget(
         const Center(
-          child: SizedBox(
-            width: 200.0,
-            height: 100.0,
-            child: HtmlElementView(viewType: 'webview'),
-          ),
+          child: SizedBox(width: 200.0, height: 100.0, child: HtmlElementView(viewType: 'webview')),
         ),
       );
 
-      await tester.pumpWidget(
-        const Center(
-          child: SizedBox(
-            width: 200.0,
-            height: 100.0,
-          ),
-        ),
-      );
+      await tester.pumpWidget(const Center(child: SizedBox(width: 200.0, height: 100.0)));
 
-      expect(
-        fakePlatformViewRegistry.views,
-        isEmpty,
-      );
+      expect(fakePlatformViewRegistry.views, isEmpty);
     });
 
     testWidgets('HTML view survives widget tree change', (WidgetTester tester) async {
@@ -273,9 +255,7 @@ void main() {
             child: SizedBox(
               width: 200.0,
               height: 100.0,
-              child: HtmlElementView(
-                viewType: 'webview',
-              ),
+              child: HtmlElementView(viewType: 'webview'),
             ),
           ),
         ),
@@ -299,11 +279,11 @@ void main() {
 
   group('HtmlElementView.fromTagName', () {
     setUp(() {
-      debugOverridePlatformViewRegistry = fakePlatformViewRegistry;
+      ui_web.debugOverridePlatformViewRegistry(fakePlatformViewRegistry);
     });
 
     tearDown(() {
-      debugOverridePlatformViewRegistry = null;
+      ui_web.debugOverridePlatformViewRegistry(null);
     });
 
     testWidgets('Create platform view from tagName', (WidgetTester tester) async {
@@ -385,117 +365,145 @@ void main() {
 
       expect(createdElement, fakePlatformView.htmlElement);
     });
+
+    group('hitTestBehavior', () {
+      testWidgets('opaque by default', (WidgetTester tester) async {
+        final Key containerKey = UniqueKey();
+        int taps = 0;
+
+        await tester.pumpWidget(
+          GestureDetector(
+            onTap: () => taps++,
+            child: Container(
+              key: containerKey,
+              width: 200,
+              height: 200,
+              // Add a color to make it a visible container. This ensures that
+              // GestureDetector's default hit test behavior works.
+              color: const Color(0xFF00FF00),
+              child: HtmlElementView.fromTagName(tagName: 'div'),
+            ),
+          ),
+        );
+        await tester.pumpAndSettle();
+
+        expect(taps, isZero);
+
+        await tester.tap(find.byKey(containerKey), warnIfMissed: false);
+
+        // Taps are still zero on the container because the HtmlElementView is
+        // opaque and prevents widgets behind it from receiving pointer events.
+        expect(taps, isZero);
+      });
+
+      testWidgets('can be set to transparent', (WidgetTester tester) async {
+        final Key containerKey = UniqueKey();
+        int taps = 0;
+
+        await tester.pumpWidget(
+          GestureDetector(
+            onTap: () => taps++,
+            child: Container(
+              key: containerKey,
+              width: 200,
+              height: 200,
+              // Add a color to make it a visible container. This ensures that
+              // GestureDetector's default hit test behavior works.
+              color: const Color(0xFF00FF00),
+              child: HtmlElementView.fromTagName(
+                tagName: 'div',
+                hitTestBehavior: PlatformViewHitTestBehavior.transparent,
+              ),
+            ),
+          ),
+        );
+        await tester.pumpAndSettle();
+
+        expect(taps, isZero);
+
+        await tester.tap(find.byKey(containerKey), warnIfMissed: false);
+
+        // The container can receive taps because the HtmlElementView is
+        // transparent from a hit testing perspective.
+        expect(taps, 1);
+      });
+    });
+  });
+
+  // Regression test for https://github.com/flutter/flutter/issues/174246
+  // There is a control case for non-Web in selection_area_test.dart.
+  testWidgets('SelectionArea applies correct mouse cursors in its empty region on Web', (
+    WidgetTester tester,
+  ) async {
+    final GlobalKey innerRegion = GlobalKey();
+    await tester.pumpWidget(
+      MaterialApp(
+        debugShowCheckedModeBanner: false,
+        home: Scaffold(
+          // Region 1 (fullscreen)
+          body: MouseRegion(
+            cursor: SystemMouseCursors.grab,
+            child: Center(
+              child: Container(
+                decoration: BoxDecoration(border: Border.all()),
+                // Region 2 (SelectionArea)
+                child: SelectionArea(
+                  child: Padding(
+                    padding: const EdgeInsetsGeometry.all(40),
+                    // Region 3 (inner MouseRegion)
+                    child: MouseRegion(
+                      key: innerRegion,
+                      cursor: SystemMouseCursors.forbidden,
+                      onHover: (_) {},
+                      child: Container(color: const Color(0xFFAA9933), width: 200, height: 50),
+                    ),
+                  ),
+                ),
+              ),
+            ),
+          ),
+        ),
+      ),
+    );
+
+    // Initialize the HtmlElementView inside SelectionArea.
+    await tester.pump();
+
+    // Ensure that the HtmlElementView is initialized.
+    expect(
+      find.byWidgetPredicate(
+        (Widget widget) => widget.toString().contains('_PlatformViewPlaceHolder'),
+      ),
+      findsNothing,
+    );
+
+    const Offset region1 = Offset(10, 10);
+    final Offset region2 = tester.getTopLeft(find.byKey(innerRegion)) - const Offset(3, 3);
+    final Offset region3 = tester.getCenter(find.byKey(innerRegion));
+
+    final TestGesture gesture = await tester.startGesture(region1, kind: PointerDeviceKind.mouse);
+    addTearDown(gesture.removePointer);
+    expect(
+      RendererBinding.instance.mouseTracker.debugDeviceActiveCursor(1),
+      SystemMouseCursors.grab,
+    );
+
+    await gesture.moveTo(region2);
+    expect(
+      RendererBinding.instance.mouseTracker.debugDeviceActiveCursor(1),
+      SystemMouseCursors.grab,
+    );
+
+    await gesture.moveTo(region3);
+    expect(
+      RendererBinding.instance.mouseTracker.debugDeviceActiveCursor(1),
+      SystemMouseCursors.forbidden,
+    );
+
+    await gesture.moveTo(region2);
+    expect(
+      RendererBinding.instance.mouseTracker.debugDeviceActiveCursor(1),
+      SystemMouseCursors.grab,
+    );
   });
 }
-
-typedef FakeViewFactory = ({
-  String viewType,
-  bool isVisible,
-  Function viewFactory,
-});
-
-typedef FakePlatformView = ({
-  int id,
-  String viewType,
-  Object? params,
-  Object htmlElement,
-});
-
-class FakePlatformViewRegistry implements ui_web.PlatformViewRegistry {
-  FakePlatformViewRegistry() {
-    TestDefaultBinaryMessengerBinding.instance.defaultBinaryMessenger.setMockMethodCallHandler(SystemChannels.platform_views, _onMethodCall);
-  }
-
-  Set<FakePlatformView> get views => Set<FakePlatformView>.unmodifiable(_views);
-  final Set<FakePlatformView> _views = <FakePlatformView>{};
-
-  final Set<FakeViewFactory> _registeredViewTypes = <FakeViewFactory>{};
-
-  @override
-  bool registerViewFactory(String viewType, Function viewFactory, {bool isVisible = true}) {
-    if (_findRegisteredViewFactory(viewType) != null) {
-      return false;
-    }
-    _registeredViewTypes.add((
-      viewType: viewType,
-      isVisible: isVisible,
-      viewFactory: viewFactory,
-    ));
-    return true;
-  }
-
-  @override
-  Object getViewById(int viewId) {
-    return _findViewById(viewId)!.htmlElement;
-  }
-
-  FakeViewFactory? _findRegisteredViewFactory(String viewType) {
-    return _registeredViewTypes.singleWhereOrNull(
-      (FakeViewFactory registered) => registered.viewType == viewType,
-    );
-  }
-
-  FakePlatformView? _findViewById(int viewId) {
-    return _views.singleWhereOrNull(
-      (FakePlatformView view) => view.id == viewId,
-    );
-  }
-
-  Future<dynamic> _onMethodCall(MethodCall call) {
-    switch (call.method) {
-      case 'create':
-        return _create(call);
-      case 'dispose':
-        return _dispose(call);
-    }
-    return Future<dynamic>.sync(() => null);
-  }
-
-  Future<dynamic> _create(MethodCall call) async {
-    final Map<dynamic, dynamic> args = call.arguments as Map<dynamic, dynamic>;
-    final int id = args['id'] as int;
-    final String viewType = args['viewType'] as String;
-    final Object? params = args['params'];
-
-    if (_findViewById(id) != null) {
-      throw PlatformException(
-        code: 'error',
-        message: 'Trying to create an already created platform view, view id: $id',
-      );
-    }
-
-    final FakeViewFactory? registered = _findRegisteredViewFactory(viewType);
-    if (registered == null) {
-      throw PlatformException(
-        code: 'error',
-        message: 'Trying to create a platform view of unregistered type: $viewType',
-      );
-    }
-
-    final ui_web.ParameterizedPlatformViewFactory viewFactory =
-        registered.viewFactory as ui_web.ParameterizedPlatformViewFactory;
-
-    _views.add((
-      id: id,
-      viewType: viewType,
-      params: params,
-      htmlElement: viewFactory(id, params: params),
-    ));
-    return null;
-  }
-
-  Future<dynamic> _dispose(MethodCall call) async {
-    final int id = call.arguments as int;
-
-    final FakePlatformView? view = _findViewById(id);
-    if (view == null) {
-      throw PlatformException(
-        code: 'error',
-        message: 'Trying to dispose a platform view with unknown id: $id',
-      );
-    }
-
-    _views.remove(view);
-    return null;
-  }
-}
