@@ -20,9 +20,7 @@ void main() {
     await tester.pumpWidget(
       UnmanagedRestorationScope(
         bucket: root,
-        child: const _TestRestorableWidget(
-          restorationId: id,
-        ),
+        child: const _TestRestorableWidget(restorationId: id),
       ),
     );
     manager.doSerialization();
@@ -31,7 +29,12 @@ void main() {
     expect(state.bucket?.restorationId, id);
     expect((rawData[childrenMapKey] as Map<Object?, Object?>).containsKey(id), isTrue);
     expect(state.property.value, 10);
-    expect((((rawData[childrenMapKey] as Map<Object?, Object?>)[id]! as Map<String, dynamic>)[valuesMapKey] as Map<Object?, Object?>)['foo'], 10);
+    expect(
+      (((rawData[childrenMapKey] as Map<Object?, Object?>)[id]!
+              as Map<String, dynamic>)[valuesMapKey]
+          as Map<Object?, Object?>)['foo'],
+      10,
+    );
     expect(state.property.log, <String>['createDefaultValue', 'initWithValue', 'toPrimitives']);
     expect(state.toggleBucketLog, isEmpty);
     expect(state.restoreStateLog.single, isNull);
@@ -40,15 +43,16 @@ void main() {
   testWidgets('claimed bucket with data', (WidgetTester tester) async {
     final MockRestorationManager manager = MockRestorationManager();
     addTearDown(manager.dispose);
-    final RestorationBucket root = RestorationBucket.root(manager: manager, rawData: _createRawDataSet());
+    final RestorationBucket root = RestorationBucket.root(
+      manager: manager,
+      rawData: _createRawDataSet(),
+    );
     addTearDown(root.dispose);
 
     await tester.pumpWidget(
       UnmanagedRestorationScope(
         bucket: root,
-        child: const _TestRestorableWidget(
-          restorationId: 'child1',
-        ),
+        child: const _TestRestorableWidget(restorationId: 'child1'),
       ),
     );
     manager.doSerialization();
@@ -61,18 +65,21 @@ void main() {
     expect(state.restoreStateLog.single, isNull);
   });
 
-  testWidgets('renames existing bucket when new ID is provided via widget', (WidgetTester tester) async {
+  testWidgets('renames existing bucket when new ID is provided via widget', (
+    WidgetTester tester,
+  ) async {
     final MockRestorationManager manager = MockRestorationManager();
     addTearDown(manager.dispose);
-    final RestorationBucket root = RestorationBucket.root(manager: manager, rawData: _createRawDataSet());
+    final RestorationBucket root = RestorationBucket.root(
+      manager: manager,
+      rawData: _createRawDataSet(),
+    );
     addTearDown(root.dispose);
 
     await tester.pumpWidget(
       UnmanagedRestorationScope(
         bucket: root,
-        child: const _TestRestorableWidget(
-          restorationId: 'child1',
-        ),
+        child: const _TestRestorableWidget(restorationId: 'child1'),
       ),
     );
     manager.doSerialization();
@@ -90,9 +97,7 @@ void main() {
     await tester.pumpWidget(
       UnmanagedRestorationScope(
         bucket: root,
-        child: const _TestRestorableWidget(
-          restorationId: 'something else',
-        ),
+        child: const _TestRestorableWidget(restorationId: 'something else'),
       ),
     );
     manager.doSerialization();
@@ -105,18 +110,21 @@ void main() {
     expect(state.toggleBucketLog, isEmpty);
   });
 
-  testWidgets('renames existing bucket when didUpdateRestorationId is called', (WidgetTester tester) async {
+  testWidgets('renames existing bucket when didUpdateRestorationId is called', (
+    WidgetTester tester,
+  ) async {
     final MockRestorationManager manager = MockRestorationManager();
     addTearDown(manager.dispose);
-    final RestorationBucket root = RestorationBucket.root(manager: manager, rawData: _createRawDataSet());
+    final RestorationBucket root = RestorationBucket.root(
+      manager: manager,
+      rawData: _createRawDataSet(),
+    );
     addTearDown(root.dispose);
 
     await tester.pumpWidget(
       UnmanagedRestorationScope(
         bucket: root,
-        child: const _TestRestorableWidget(
-          restorationId: 'child1',
-        ),
+        child: const _TestRestorableWidget(restorationId: 'child1'),
       ),
     );
     manager.doSerialization();
@@ -153,20 +161,13 @@ void main() {
     await tester.pumpWidget(
       UnmanagedRestorationScope(
         bucket: root,
-        child: const _TestRestorableWidget(
-          restorationId: 'child1',
-        ),
+        child: const _TestRestorableWidget(restorationId: 'child1'),
       ),
     );
     manager.doSerialization();
     expect((rawData[childrenMapKey] as Map<String, dynamic>).containsKey('child1'), isTrue);
 
-    await tester.pumpWidget(
-      UnmanagedRestorationScope(
-        bucket: root,
-        child: Container(),
-      ),
-    );
+    await tester.pumpWidget(UnmanagedRestorationScope(bucket: root, child: Container()));
     manager.doSerialization();
 
     expect((rawData[childrenMapKey] as Map<String, dynamic>).containsKey('child1'), isFalse);
@@ -180,15 +181,17 @@ void main() {
     addTearDown(root.dispose);
 
     await tester.pumpWidget(
-      UnmanagedRestorationScope(
-        bucket: root,
-        child: const _TestRestorableWidget(),
-      ),
+      UnmanagedRestorationScope(bucket: root, child: const _TestRestorableWidget()),
     );
     final _TestRestorableWidgetState state = tester.state(find.byType(_TestRestorableWidget));
     expect(state.bucket, isNull);
     expect(state.property.value, 10); // Initialized to default.
-    expect((((rawData[childrenMapKey] as Map<String, dynamic>)['child1'] as Map<String, dynamic>)[valuesMapKey] as Map<String, dynamic>)['foo'], 22);
+    expect(
+      (((rawData[childrenMapKey] as Map<String, dynamic>)['child1']
+              as Map<String, dynamic>)[valuesMapKey]
+          as Map<String, dynamic>)['foo'],
+      22,
+    );
     expect(state.property.log, <String>['createDefaultValue', 'initWithValue']);
     state.property.log.clear();
     expect(state.restoreStateLog.single, isNull);
@@ -200,16 +203,19 @@ void main() {
     await tester.pumpWidget(
       UnmanagedRestorationScope(
         bucket: root,
-        child: const _TestRestorableWidget(
-          restorationId: 'child1',
-        ),
+        child: const _TestRestorableWidget(restorationId: 'child1'),
       ),
     );
     manager.doSerialization();
     expect(state.bucket, isNotNull);
     expect(state.bucket!.restorationId, 'child1');
     expect(state.property.value, 10);
-    expect((((rawData[childrenMapKey] as Map<String, dynamic>)['child1'] as Map<String, dynamic>)[valuesMapKey] as Map<String, dynamic>)['foo'], 10);
+    expect(
+      (((rawData[childrenMapKey] as Map<String, dynamic>)['child1']
+              as Map<String, dynamic>)[valuesMapKey]
+          as Map<String, dynamic>)['foo'],
+      10,
+    );
     expect(state.property.log, <String>['toPrimitives']);
     state.property.log.clear();
     expect(state.restoreStateLog, isEmpty);
@@ -221,10 +227,7 @@ void main() {
 
     // Change id back to null.
     await tester.pumpWidget(
-      UnmanagedRestorationScope(
-        bucket: root,
-        child: const _TestRestorableWidget(),
-      ),
+      UnmanagedRestorationScope(bucket: root, child: const _TestRestorableWidget()),
     );
     manager.doSerialization();
     expect(state.bucket, isNull);
@@ -242,16 +245,16 @@ void main() {
     final RestorationBucket root = RestorationBucket.root(manager: manager, rawData: rawData);
     addTearDown(root.dispose);
 
-    await tester.pumpWidget(
-      _TestRestorableWidget(
-        key: key,
-        restorationId: 'child1',
-      ),
-    );
+    await tester.pumpWidget(_TestRestorableWidget(key: key, restorationId: 'child1'));
     final _TestRestorableWidgetState state = tester.state(find.byType(_TestRestorableWidget));
     expect(state.bucket, isNull);
     expect(state.property.value, 10); // Initialized to default.
-    expect((((rawData[childrenMapKey] as Map<String, dynamic>)['child1'] as Map<String, dynamic>)[valuesMapKey] as Map<String, dynamic>)['foo'], 22);
+    expect(
+      (((rawData[childrenMapKey] as Map<String, dynamic>)['child1']
+              as Map<String, dynamic>)[valuesMapKey]
+          as Map<String, dynamic>)['foo'],
+      22,
+    );
     expect(state.property.log, <String>['createDefaultValue', 'initWithValue']);
     state.property.log.clear();
     expect(state.restoreStateLog.single, isNull);
@@ -263,17 +266,19 @@ void main() {
     await tester.pumpWidget(
       UnmanagedRestorationScope(
         bucket: root,
-        child: _TestRestorableWidget(
-          key: key,
-          restorationId: 'child1',
-        ),
+        child: _TestRestorableWidget(key: key, restorationId: 'child1'),
       ),
     );
     manager.doSerialization();
     expect(state.bucket, isNotNull);
     expect(state.bucket!.restorationId, 'child1');
     expect(state.property.value, 10);
-    expect((((rawData[childrenMapKey] as Map<String, dynamic>)['child1'] as Map<String, dynamic>)[valuesMapKey] as Map<String, dynamic>)['foo'], 10);
+    expect(
+      (((rawData[childrenMapKey] as Map<String, dynamic>)['child1']
+              as Map<String, dynamic>)[valuesMapKey]
+          as Map<String, dynamic>)['foo'],
+      10,
+    );
     expect(state.property.log, <String>['toPrimitives']);
     state.property.log.clear();
     expect(state.restoreStateLog, isEmpty);
@@ -284,12 +289,7 @@ void main() {
     final RestorationBucket bucket = state.bucket!;
 
     // Move out of scope again.
-    await tester.pumpWidget(
-      _TestRestorableWidget(
-        key: key,
-        restorationId: 'child1',
-      ),
-    );
+    await tester.pumpWidget(_TestRestorableWidget(key: key, restorationId: 'child1'));
     manager.doSerialization();
     expect(state.bucket, isNull);
     expect((rawData[childrenMapKey] as Map<String, dynamic>).containsKey('child1'), isFalse);
@@ -314,10 +314,7 @@ void main() {
           children: <Widget>[
             RestorationScope(
               restorationId: 'fixed',
-              child: _TestRestorableWidget(
-                key: key,
-                restorationId: 'moving-child',
-              ),
+              child: _TestRestorableWidget(key: key, restorationId: 'moving-child'),
             ),
           ],
         ),
@@ -326,7 +323,13 @@ void main() {
     manager.doSerialization();
     final _TestRestorableWidgetState state = tester.state(find.byType(_TestRestorableWidget));
     expect(state.bucket!.restorationId, 'moving-child');
-    expect((((rawData[childrenMapKey] as Map<Object?, Object?>)['fixed']! as Map<String, dynamic>)[childrenMapKey] as Map<Object?, Object?>).containsKey('moving-child'), isTrue);
+    expect(
+      (((rawData[childrenMapKey] as Map<Object?, Object?>)['fixed']!
+                  as Map<String, dynamic>)[childrenMapKey]
+              as Map<Object?, Object?>)
+          .containsKey('moving-child'),
+      isTrue,
+    );
     final RestorationBucket bucket = state.bucket!;
     state.property.log.clear();
     state.restoreStateLog.clear();
@@ -341,14 +344,8 @@ void main() {
         child: Row(
           textDirection: TextDirection.ltr,
           children: <Widget>[
-            RestorationScope(
-              restorationId: 'fixed',
-              child: Container(),
-            ),
-            _TestRestorableWidget(
-              key: key,
-              restorationId: 'moving-child',
-            ),
+            RestorationScope(restorationId: 'fixed', child: Container()),
+            _TestRestorableWidget(key: key, restorationId: 'moving-child'),
           ],
         ),
       ),
@@ -369,9 +366,7 @@ void main() {
     await tester.pumpWidget(
       const RootRestorationScope(
         restorationId: 'root-child',
-        child: _TestRestorableWidget(
-          restorationId: 'widget',
-        ),
+        child: _TestRestorableWidget(restorationId: 'widget'),
       ),
     );
 
@@ -408,9 +403,7 @@ void main() {
     await tester.pumpWidget(
       const RootRestorationScope(
         restorationId: 'root-child',
-        child: _TestRestorableWidget(
-          restorationId: 'widget',
-        ),
+        child: _TestRestorableWidget(restorationId: 'widget'),
       ),
     );
 
@@ -443,20 +436,24 @@ void main() {
     expect(state.toggleBucketLog, isEmpty);
   });
 
-  testWidgets('can register additional property outside of restoreState', (WidgetTester tester) async {
+  testWidgets('can register additional property outside of restoreState', (
+    WidgetTester tester,
+  ) async {
     await tester.pumpWidget(
       const RootRestorationScope(
         restorationId: 'root-child',
-        child: _TestRestorableWidget(
-          restorationId: 'widget',
-        ),
+        child: _TestRestorableWidget(restorationId: 'widget'),
       ),
     );
 
     final _TestRestorableWidgetState state = tester.state(find.byType(_TestRestorableWidget));
     state.registerAdditionalProperty();
     expect(state.additionalProperty!.value, 11);
-    expect(state.additionalProperty!.log, <String>['createDefaultValue', 'initWithValue', 'toPrimitives']);
+    expect(state.additionalProperty!.log, <String>[
+      'createDefaultValue',
+      'initWithValue',
+      'toPrimitives',
+    ]);
 
     state.setProperties(() {
       state.additionalProperty!.value = 33;
@@ -484,9 +481,7 @@ void main() {
     await tester.pumpWidget(
       const RootRestorationScope(
         restorationId: 'root-child',
-        child: _TestRestorableWidget(
-          restorationId: 'widget',
-        ),
+        child: _TestRestorableWidget(restorationId: 'widget'),
       ),
     );
 
@@ -500,9 +495,7 @@ void main() {
     await tester.pumpWidget(
       const RootRestorationScope(
         restorationId: 'root-child',
-        child: _TestRestorableWidget(
-          restorationId: 'widget',
-        ),
+        child: _TestRestorableWidget(restorationId: 'widget'),
       ),
     );
 
@@ -514,9 +507,7 @@ void main() {
     await tester.pumpWidget(
       const RootRestorationScope(
         restorationId: 'root-child',
-        child: _TestRestorableWidget(
-          restorationId: 'widget',
-        ),
+        child: _TestRestorableWidget(restorationId: 'widget'),
       ),
     );
     _TestRestorableWidgetState state = tester.state(find.byType(_TestRestorableWidget));
@@ -554,9 +545,7 @@ void main() {
     await tester.pumpWidget(
       const RootRestorationScope(
         restorationId: 'root-child',
-        child: _TestRestorableWidget(
-          restorationId: 'widget',
-        ),
+        child: _TestRestorableWidget(restorationId: 'widget'),
       ),
     );
     _TestRestorableWidgetState state = tester.state(find.byType(_TestRestorableWidget));
@@ -592,9 +581,7 @@ void main() {
     await tester.pumpWidget(
       const RootRestorationScope(
         restorationId: 'root-child',
-        child: _TestRestorableWidget(
-          restorationId: 'widget',
-        ),
+        child: _TestRestorableWidget(restorationId: 'widget'),
       ),
     );
     final _TestRestorableWidgetState state = tester.state(find.byType(_TestRestorableWidget));
@@ -618,9 +605,7 @@ void main() {
     await tester.pumpWidget(
       const RootRestorationScope(
         restorationId: 'root-child',
-        child: _TestRestorableWidget(
-          restorationId: 'widget',
-        ),
+        child: _TestRestorableWidget(restorationId: 'widget'),
       ),
     );
     final _TestRestorableWidgetState state = tester.state(find.byType(_TestRestorableWidget));
@@ -657,7 +642,6 @@ void _clearLogs(_TestRestorableWidgetState state) {
 }
 
 class _TestRestorableWidget extends StatefulWidget {
-
   const _TestRestorableWidget({super.key, this.restorationId});
 
   final String? restorationId;
@@ -669,7 +653,7 @@ class _TestRestorableWidget extends StatefulWidget {
 class _TestRestorableWidgetState extends State<_TestRestorableWidget> with RestorationMixin {
   final _TestRestorableProperty property = _TestRestorableProperty(10);
   _TestRestorableProperty? additionalProperty;
-  bool _rerigisterAdditionalProperty = false;
+  bool _reregisterAdditionalProperty = false;
 
   final List<RestorationBucket?> restoreStateLog = <RestorationBucket?>[];
   final List<RestorationBucket?> toggleBucketLog = <RestorationBucket?>[];
@@ -678,7 +662,7 @@ class _TestRestorableWidgetState extends State<_TestRestorableWidget> with Resto
   void restoreState(RestorationBucket? oldBucket, bool initialRestore) {
     restoreStateLog.add(oldBucket);
     registerForRestoration(property, 'foo');
-    if (_rerigisterAdditionalProperty && additionalProperty != null) {
+    if (_reregisterAdditionalProperty && additionalProperty != null) {
       registerForRestoration(additionalProperty!, 'additional');
     }
   }
@@ -712,7 +696,7 @@ class _TestRestorableWidgetState extends State<_TestRestorableWidget> with Resto
   void registerAdditionalProperty({bool reregister = true}) {
     additionalProperty ??= _TestRestorableProperty(11);
     registerForRestoration(additionalProperty!, 'additional');
-    _rerigisterAdditionalProperty = reregister;
+    _reregisterAdditionalProperty = reregister;
   }
 
   void unregisterAdditionalProperty() {
@@ -729,20 +713,13 @@ class _TestRestorableWidgetState extends State<_TestRestorableWidget> with Resto
 
 Map<String, dynamic> _createRawDataSet() {
   return <String, dynamic>{
-    valuesMapKey: <String, dynamic>{
-      'value1' : 10,
-      'value2' : 'Hello',
-    },
+    valuesMapKey: <String, dynamic>{'value1': 10, 'value2': 'Hello'},
     childrenMapKey: <String, dynamic>{
-      'child1' : <String, dynamic>{
-        valuesMapKey : <String, dynamic>{
-          'foo': 22,
-        },
+      'child1': <String, dynamic>{
+        valuesMapKey: <String, dynamic>{'foo': 22},
       },
-      'child2' : <String, dynamic>{
-        valuesMapKey : <String, dynamic>{
-          'bar': 33,
-        },
+      'child2': <String, dynamic>{
+        valuesMapKey: <String, dynamic>{'bar': 33},
       },
     },
   };
@@ -777,6 +754,7 @@ class _TestRestorableProperty extends RestorableProperty<Object?> {
     assert(isRegistered);
     return _value;
   }
+
   Object? _value;
   set value(Object? value) {
     _value = value;
