@@ -12,10 +12,7 @@ void main() {
       await tester.pumpWidget(
         const MediaQuery(
           data: MediaQueryData(padding: EdgeInsets.all(20.0)),
-          child: SafeArea(
-            left: false,
-            child: Placeholder(),
-          ),
+          child: SafeArea(left: false, child: Placeholder()),
         ),
       );
       expect(tester.getTopLeft(find.byType(Placeholder)), const Offset(0.0, 20.0));
@@ -41,13 +38,7 @@ void main() {
       await tester.pumpWidget(
         const MediaQuery(
           data: MediaQueryData(padding: EdgeInsets.all(20.0)),
-          child: SafeArea(
-            top: false,
-            child: SafeArea(
-              right: false,
-              child: Placeholder(),
-            ),
-          ),
+          child: SafeArea(top: false, child: SafeArea(right: false, child: Placeholder())),
         ),
       );
       expect(tester.getTopLeft(find.byType(Placeholder)), const Offset(20.0, 20.0));
@@ -57,11 +48,7 @@ void main() {
     testWidgets('SafeArea - changing', (WidgetTester tester) async {
       const Widget child = SafeArea(
         bottom: false,
-        child: SafeArea(
-          left: false,
-          bottom: false,
-          child: Placeholder(),
-        ),
+        child: SafeArea(left: false, bottom: false, child: Placeholder()),
       );
       await tester.pumpWidget(
         const MediaQuery(
@@ -73,11 +60,7 @@ void main() {
       expect(tester.getBottomRight(find.byType(Placeholder)), const Offset(780.0, 600.0));
       await tester.pumpWidget(
         const MediaQuery(
-          data: MediaQueryData(padding: EdgeInsets.only(
-            left: 100.0,
-            top: 30.0,
-            bottom: 40.0,
-          )),
+          data: MediaQueryData(padding: EdgeInsets.only(left: 100.0, top: 30.0, bottom: 40.0)),
           child: child,
         ),
       );
@@ -86,18 +69,34 @@ void main() {
     });
 
     testWidgets('SafeArea - properties', (WidgetTester tester) async {
-      final SafeArea child = SafeArea(
-        right: false,
-        bottom: false,
-        child: Container(),
-      );
+      final SafeArea child = SafeArea(right: false, bottom: false, child: Container());
       final DiagnosticPropertiesBuilder properties = DiagnosticPropertiesBuilder();
       child.debugFillProperties(properties);
 
-      expect(properties.properties.any((DiagnosticsNode n) => n is FlagProperty && n.toString() == 'avoid left padding'), true);
-      expect(properties.properties.any((DiagnosticsNode n) => n is FlagProperty && n.toString() == 'avoid right padding'), false);
-      expect(properties.properties.any((DiagnosticsNode n) => n is FlagProperty && n.toString() == 'avoid top padding'), true);
-      expect(properties.properties.any((DiagnosticsNode n) => n is FlagProperty && n.toString() == 'avoid bottom padding'), false);
+      expect(
+        properties.properties.any(
+          (DiagnosticsNode n) => n is FlagProperty && n.toString() == 'avoid left padding',
+        ),
+        true,
+      );
+      expect(
+        properties.properties.any(
+          (DiagnosticsNode n) => n is FlagProperty && n.toString() == 'avoid right padding',
+        ),
+        false,
+      );
+      expect(
+        properties.properties.any(
+          (DiagnosticsNode n) => n is FlagProperty && n.toString() == 'avoid top padding',
+        ),
+        true,
+      );
+      expect(
+        properties.properties.any(
+          (DiagnosticsNode n) => n is FlagProperty && n.toString() == 'avoid bottom padding',
+        ),
+        false,
+      );
     });
 
     group('SafeArea maintains bottom viewPadding when specified for consumed bottom padding', () {
@@ -113,14 +112,12 @@ void main() {
       }
 
       testWidgets('SafeArea alone.', (WidgetTester tester) async {
-        final Widget child = boilerplate(const SafeArea(
-          maintainBottomViewPadding: true,
-          child: Column(
-            children: <Widget>[
-              Expanded(child: Placeholder()),
-            ],
+        final Widget child = boilerplate(
+          const SafeArea(
+            maintainBottomViewPadding: true,
+            child: Column(children: <Widget>[Expanded(child: Placeholder())]),
           ),
-        ));
+        );
 
         await tester.pumpWidget(
           MediaQuery(
@@ -147,21 +144,19 @@ void main() {
         expect(initialPoint, finalPoint);
       });
 
-      testWidgets('SafeArea alone - partial ViewInsets consume Padding', (WidgetTester tester) async {
-        final Widget child = boilerplate(const SafeArea(
-          maintainBottomViewPadding: true,
-          child: Column(
-            children: <Widget>[
-              Expanded(child: Placeholder()),
-            ],
+      testWidgets('SafeArea alone - partial ViewInsets consume Padding', (
+        WidgetTester tester,
+      ) async {
+        final Widget child = boilerplate(
+          const SafeArea(
+            maintainBottomViewPadding: true,
+            child: Column(children: <Widget>[Expanded(child: Placeholder())]),
           ),
-        ));
+        );
 
         await tester.pumpWidget(
           MediaQuery(
-            data: const MediaQueryData(
-              viewPadding: EdgeInsets.only(bottom: 20.0),
-            ),
+            data: const MediaQueryData(viewPadding: EdgeInsets.only(bottom: 20.0)),
             child: child,
           ),
         );
@@ -181,17 +176,15 @@ void main() {
       });
 
       testWidgets('SafeArea with nested Scaffold', (WidgetTester tester) async {
-        final Widget child = boilerplate(const SafeArea(
-          maintainBottomViewPadding: true,
-          child: Scaffold(
-            resizeToAvoidBottomInset: false,
-            body: Column(
-              children: <Widget>[
-                Expanded(child: Placeholder()),
-              ],
+        final Widget child = boilerplate(
+          const SafeArea(
+            maintainBottomViewPadding: true,
+            child: Scaffold(
+              resizeToAvoidBottomInset: false,
+              body: Column(children: <Widget>[Expanded(child: Placeholder())]),
             ),
           ),
-        ));
+        );
 
         await tester.pumpWidget(
           MediaQuery(
@@ -218,24 +211,22 @@ void main() {
         expect(initialPoint, finalPoint);
       });
 
-      testWidgets('SafeArea with nested Scaffold  - partial ViewInsets consume Padding', (WidgetTester tester) async {
-        final Widget child = boilerplate(const SafeArea(
-          maintainBottomViewPadding: true,
-          child: Scaffold(
-            resizeToAvoidBottomInset: false,
-            body: Column(
-              children: <Widget>[
-                Expanded(child: Placeholder()),
-              ],
+      testWidgets('SafeArea with nested Scaffold  - partial ViewInsets consume Padding', (
+        WidgetTester tester,
+      ) async {
+        final Widget child = boilerplate(
+          const SafeArea(
+            maintainBottomViewPadding: true,
+            child: Scaffold(
+              resizeToAvoidBottomInset: false,
+              body: Column(children: <Widget>[Expanded(child: Placeholder())]),
             ),
           ),
-        ));
+        );
 
         await tester.pumpWidget(
           MediaQuery(
-            data: const MediaQueryData(
-              viewPadding: EdgeInsets.only(bottom: 20.0),
-            ),
+            data: const MediaQueryData(viewPadding: EdgeInsets.only(bottom: 20.0)),
             child: child,
           ),
         );
@@ -268,9 +259,13 @@ void main() {
           child: Viewport(
             offset: offset = ViewportOffset.fixed(0.0),
             slivers: <Widget>[
-              const SliverToBoxAdapter(child: SizedBox(width: 800.0, height: 100.0, child: Text('before'))),
+              const SliverToBoxAdapter(
+                child: SizedBox(width: 800.0, height: 100.0, child: Text('before')),
+              ),
               sliver,
-              const SliverToBoxAdapter(child: SizedBox(width: 800.0, height: 100.0, child: Text('after'))),
+              const SliverToBoxAdapter(
+                child: SizedBox(width: 800.0, height: 100.0, child: Text('after')),
+              ),
             ],
           ),
         ),
@@ -278,13 +273,14 @@ void main() {
     }
 
     void verify(WidgetTester tester, List<Rect> expectedRects) {
-      final List<Rect> testAnswers = tester.renderObjectList<RenderBox>(find.byType(SizedBox)).map<Rect>(
-        (RenderBox target) {
-          final Offset topLeft = target.localToGlobal(Offset.zero);
-          final Offset bottomRight = target.localToGlobal(target.size.bottomRight(Offset.zero));
-          return Rect.fromPoints(topLeft, bottomRight);
-        },
-      ).toList();
+      final List<Rect> testAnswers = tester
+          .renderObjectList<RenderBox>(find.byType(SizedBox))
+          .map<Rect>((RenderBox target) {
+            final Offset topLeft = target.localToGlobal(Offset.zero);
+            final Offset bottomRight = target.localToGlobal(target.size.bottomRight(Offset.zero));
+            return Rect.fromPoints(topLeft, bottomRight);
+          })
+          .toList();
       expect(testAnswers, equals(expectedRects));
     }
 
@@ -294,7 +290,9 @@ void main() {
           const EdgeInsets.all(20.0),
           const SliverSafeArea(
             left: false,
-            sliver: SliverToBoxAdapter(child: SizedBox(width: 800.0, height: 100.0, child: Text('padded'))),
+            sliver: SliverToBoxAdapter(
+              child: SizedBox(width: 800.0, height: 100.0, child: Text('padded')),
+            ),
           ),
         ),
       );
@@ -312,7 +310,9 @@ void main() {
           const SliverSafeArea(
             top: false,
             minimum: EdgeInsets.fromLTRB(0.0, 10.0, 20.0, 30.0),
-            sliver: SliverToBoxAdapter(child: SizedBox(width: 800.0, height: 100.0, child: Text('padded'))),
+            sliver: SliverToBoxAdapter(
+              child: SizedBox(width: 800.0, height: 100.0, child: Text('padded')),
+            ),
           ),
         ),
       );
@@ -331,7 +331,9 @@ void main() {
             top: false,
             sliver: SliverSafeArea(
               right: false,
-              sliver: SliverToBoxAdapter(child: SizedBox(width: 800.0, height: 100.0, child: Text('padded'))),
+              sliver: SliverToBoxAdapter(
+                child: SizedBox(width: 800.0, height: 100.0, child: Text('padded')),
+              ),
             ),
           ),
         ),
@@ -349,15 +351,12 @@ void main() {
         sliver: SliverSafeArea(
           left: false,
           bottom: false,
-          sliver: SliverToBoxAdapter(child: SizedBox(width: 800.0, height: 100.0, child: Text('padded'))),
-        ),
-      );
-      await tester.pumpWidget(
-        buildWidget(
-          const EdgeInsets.all(20.0),
-          sliver,
+          sliver: SliverToBoxAdapter(
+            child: SizedBox(width: 800.0, height: 100.0, child: Text('padded')),
+          ),
         ),
       );
+      await tester.pumpWidget(buildWidget(const EdgeInsets.all(20.0), sliver));
       verify(tester, <Rect>[
         const Rect.fromLTWH(0.0, 0.0, 800.0, 100.0),
         const Rect.fromLTWH(20.0, 120.0, 760.0, 100.0),
@@ -365,14 +364,7 @@ void main() {
       ]);
 
       await tester.pumpWidget(
-        buildWidget(
-          const EdgeInsets.only(
-            left: 100.0,
-            top: 30.0,
-            bottom: 40.0,
-          ),
-          sliver,
-        ),
+        buildWidget(const EdgeInsets.only(left: 100.0, top: 30.0, bottom: 40.0), sliver),
       );
       verify(tester, <Rect>[
         const Rect.fromLTWH(0.0, 0.0, 800.0, 100.0),
@@ -386,14 +378,36 @@ void main() {
     const SliverSafeArea child = SliverSafeArea(
       right: false,
       bottom: false,
-      sliver: SliverToBoxAdapter(child: SizedBox(width: 800.0, height: 100.0, child: Text('padded'))),
+      sliver: SliverToBoxAdapter(
+        child: SizedBox(width: 800.0, height: 100.0, child: Text('padded')),
+      ),
     );
     final DiagnosticPropertiesBuilder properties = DiagnosticPropertiesBuilder();
     child.debugFillProperties(properties);
 
-    expect(properties.properties.any((DiagnosticsNode n) => n is FlagProperty && n.toString() == 'avoid left padding'), true);
-    expect(properties.properties.any((DiagnosticsNode n) => n is FlagProperty && n.toString() == 'avoid right padding'), false);
-    expect(properties.properties.any((DiagnosticsNode n) => n is FlagProperty && n.toString() == 'avoid top padding'), true);
-    expect(properties.properties.any((DiagnosticsNode n) => n is FlagProperty && n.toString() == 'avoid bottom padding'), false);
+    expect(
+      properties.properties.any(
+        (DiagnosticsNode n) => n is FlagProperty && n.toString() == 'avoid left padding',
+      ),
+      true,
+    );
+    expect(
+      properties.properties.any(
+        (DiagnosticsNode n) => n is FlagProperty && n.toString() == 'avoid right padding',
+      ),
+      false,
+    );
+    expect(
+      properties.properties.any(
+        (DiagnosticsNode n) => n is FlagProperty && n.toString() == 'avoid top padding',
+      ),
+      true,
+    );
+    expect(
+      properties.properties.any(
+        (DiagnosticsNode n) => n is FlagProperty && n.toString() == 'avoid bottom padding',
+      ),
+      false,
+    );
   });
 }
