@@ -8,10 +8,10 @@ import 'base/file_system.dart';
 
 /// Processes dependencies into a string representing the NOTICES file.
 ///
-/// Reads the NOTICES or LICENSE file from each package in the .packages file,
-/// splitting each one into each component license so that it can be de-duped
-/// if possible. If the NOTICES file exists, it is preferred over the LICENSE
-/// file.
+/// Reads the NOTICES or LICENSE file from each package in the
+/// package_config.json file, splitting each one into each component license so
+/// that it can be de-duped if possible. If the NOTICES file exists, it is
+/// preferred over the LICENSE file.
 ///
 /// Individual licenses inside each LICENSE file should be separated by 80
 /// hyphens on their own on a line.
@@ -24,14 +24,12 @@ import 'base/file_system.dart';
 /// example, a package might itself contain code from multiple third-party
 /// sources, and might need to include a license for each one.
 class LicenseCollector {
-  LicenseCollector({
-    required FileSystem fileSystem
-  }) : _fileSystem = fileSystem;
+  LicenseCollector({required FileSystem fileSystem}) : _fileSystem = fileSystem;
 
   final FileSystem _fileSystem;
 
   /// The expected separator for multiple licenses.
-  static final String licenseSeparator = '\n${'-' * 80}\n';
+  static final licenseSeparator = '\n${'-' * 80}\n';
 
   /// Obtain licenses from the `packageMap` into a single result.
   ///
@@ -41,9 +39,9 @@ class LicenseCollector {
     PackageConfig packageConfig,
     Map<String, List<File>> additionalLicenses,
   ) {
-    final Map<String, Set<String>> packageLicenses = <String, Set<String>>{};
-    final Set<String> allPackages = <String>{};
-    final List<File> dependencies = <File>[];
+    final packageLicenses = <String, Set<String>>{};
+    final allPackages = <String>{};
+    final dependencies = <File>[];
 
     for (final Package package in packageConfig.packages) {
       final Uri packageUri = package.packageUriRoot;
@@ -60,11 +58,9 @@ class LicenseCollector {
       }
 
       dependencies.add(file);
-      final List<String> rawLicenses = file
-        .readAsStringSync()
-        .split(licenseSeparator);
-      for (final String rawLicense in rawLicenses) {
-        List<String> packageNames = <String>[];
+      final List<String> rawLicenses = file.readAsStringSync().split(licenseSeparator);
+      for (final rawLicense in rawLicenses) {
+        var packageNames = <String>[];
         String? licenseText;
         if (rawLicenses.length > 1) {
           final int split = rawLicense.indexOf('\n\n');
@@ -82,22 +78,23 @@ class LicenseCollector {
       }
     }
 
-    final List<String> combinedLicensesList = packageLicenses.entries
-      .map<String>((MapEntry<String, Set<String>> entry) {
-        final List<String> packageNames = entry.value.toList()..sort();
-        return '${packageNames.join('\n')}\n\n${entry.key}';
-      }).toList();
+    final List<String> combinedLicensesList = packageLicenses.entries.map<String>((
+      MapEntry<String, Set<String>> entry,
+    ) {
+      final List<String> packageNames = entry.value.toList()..sort();
+      return '${packageNames.join('\n')}\n\n${entry.key}';
+    }).toList();
     combinedLicensesList.sort();
 
     /// Append additional LICENSE files as specified in the pubspec.yaml.
-    final List<String> additionalLicenseText = <String>[];
-    final List<String> errorMessages = <String>[];
+    final additionalLicenseText = <String>[];
+    final errorMessages = <String>[];
     for (final String package in additionalLicenses.keys) {
       for (final File license in additionalLicenses[package]!) {
         if (!license.existsSync()) {
           errorMessages.add(
             'package $package specified an additional license at ${license.path}, but this file '
-            'does not exist.'
+            'does not exist.',
           );
           continue;
         }
@@ -108,13 +105,13 @@ class LicenseCollector {
           // File has an invalid encoding.
           errorMessages.add(
             'package $package specified an additional license at ${license.path}, but this file '
-            'could not be read:\n$err'
+            'could not be read:\n$err',
           );
         } on FileSystemException catch (err) {
           // File cannot be parsed.
           errorMessages.add(
             'package $package specified an additional license at ${license.path}, but this file '
-            'could not be read:\n$err'
+            'could not be read:\n$err',
           );
         }
       }
@@ -128,8 +125,8 @@ class LicenseCollector {
     }
 
     final String combinedLicenses = combinedLicensesList
-      .followedBy(additionalLicenseText)
-      .join(licenseSeparator);
+        .followedBy(additionalLicenseText)
+        .join(licenseSeparator);
 
     return LicenseResult(
       combinedLicenses: combinedLicenses,
