@@ -4,36 +4,37 @@
 
 import 'dart:async';
 
+import 'package:collection/collection.dart';
 import 'package:meta/meta.dart';
 import 'package:process/process.dart';
-import 'package:webkit_inspection_protocol/webkit_inspection_protocol.dart';
+import 'package:webkit_inspection_protocol/webkit_inspection_protocol.dart' hide StackTrace;
 
+import '../base/async_guard.dart';
 import '../base/common.dart';
 import '../base/file_system.dart';
 import '../base/io.dart';
 import '../base/logger.dart';
 import '../base/os.dart';
 import '../base/platform.dart';
-import '../convert.dart';
+import '../base/utils.dart';
 
 /// An environment variable used to override the location of Google Chrome.
-const String kChromeEnvironment = 'CHROME_EXECUTABLE';
+const kChromeEnvironment = 'CHROME_EXECUTABLE';
 
 /// An environment variable used to override the location of Microsoft Edge.
-const String kEdgeEnvironment = 'EDGE_ENVIRONMENT';
+const kEdgeEnvironment = 'EDGE_ENVIRONMENT';
 
 /// The expected executable name on linux.
-const String kLinuxExecutable = 'google-chrome';
+const kLinuxExecutable = 'google-chrome';
 
 /// The expected executable name on macOS.
-const String kMacOSExecutable =
-    '/Applications/Google Chrome.app/Contents/MacOS/Google Chrome';
+const kMacOSExecutable = '/Applications/Google Chrome.app/Contents/MacOS/Google Chrome';
 
 /// The expected Chrome executable name on Windows.
-const String kWindowsExecutable = r'Google\Chrome\Application\chrome.exe';
+const kWindowsExecutable = r'Google\Chrome\Application\chrome.exe';
 
 /// The expected Edge executable name on Windows.
-const String kWindowsEdgeExecutable = r'Microsoft\Edge\Application\msedge.exe';
+const kWindowsEdgeExecutable = r'Microsoft\Edge\Application\msedge.exe';
 
 /// Used by [ChromiumLauncher] to detect a glibc bug and retry launching the
 /// browser.
@@ -45,7 +46,7 @@ const String kWindowsEdgeExecutable = r'Microsoft\Edge\Application\msedge.exe';
 /// When this happens Chrome spits out something like the following then exits with code 127:
 ///
 ///     Inconsistency detected by ld.so: ../elf/dl-tls.c: 493: _dl_allocate_tls_init: Assertion `listp->slotinfo[cnt].gen <= GL(dl_tls_generation)' failed!
-const String _kGlibcError = 'Inconsistency detected by ld.so';
+const _kGlibcError = 'Inconsistency detected by ld.so';
 
 typedef BrowserFinder = String Function(Platform, FileSystem);
 
@@ -64,11 +65,9 @@ String findChromeExecutable(Platform platform, FileSystem fileSystem) {
   }
   if (platform.isWindows) {
     /// The possible locations where the chrome executable can be located on windows.
-    final List<String> kWindowsPrefixes = <String>[
-      if (platform.environment.containsKey('LOCALAPPDATA'))
-        platform.environment['LOCALAPPDATA']!,
-      if (platform.environment.containsKey('PROGRAMFILES'))
-        platform.environment['PROGRAMFILES']!,
+    final kWindowsPrefixes = <String>[
+      if (platform.environment.containsKey('LOCALAPPDATA')) platform.environment['LOCALAPPDATA']!,
+      if (platform.environment.containsKey('PROGRAMFILES')) platform.environment['PROGRAMFILES']!,
       if (platform.environment.containsKey('PROGRAMFILES(X86)'))
         platform.environment['PROGRAMFILES(X86)']!,
     ];
@@ -90,11 +89,9 @@ String findEdgeExecutable(Platform platform, FileSystem fileSystem) {
   }
   if (platform.isWindows) {
     /// The possible locations where the Edge executable can be located on windows.
-    final List<String> kWindowsPrefixes = <String>[
-      if (platform.environment.containsKey('LOCALAPPDATA'))
-        platform.environment['LOCALAPPDATA']!,
-      if (platform.environment.containsKey('PROGRAMFILES'))
-        platform.environment['PROGRAMFILES']!,
+    final kWindowsPrefixes = <String>[
+      if (platform.environment.containsKey('LOCALAPPDATA')) platform.environment['LOCALAPPDATA']!,
+      if (platform.environment.containsKey('PROGRAMFILES')) platform.environment['PROGRAMFILES']!,
       if (platform.environment.containsKey('PROGRAMFILES(X86)'))
         platform.environment['PROGRAMFILES(X86)']!,
     ];
@@ -134,7 +131,7 @@ class ChromiumLauncher {
   bool get hasChromeInstance => currentCompleter.isCompleted;
 
   @visibleForTesting
-  Completer<Chromium> currentCompleter = Completer<Chromium>();
+  var currentCompleter = Completer<Chromium>();
 
   /// Whether we can locate the chrome executable.
   bool canFindExecutable() {
@@ -147,7 +144,32 @@ class ChromiumLauncher {
   }
 
   /// The executable this launcher will use.
-  String findExecutable() =>  _browserFinder(_platform, _fileSystem);
+  String findExecutable() => _browserFinder(_platform, _fileSystem);
+
+  /// Creates a user data directory for Chrome based on provided flags or creates a temporary one.
+  ///
+  /// This method handles the creation of Chrome's user data directory in two ways:
+  /// 1. If webBrowserFlags contains a --user-data-dir flag, it uses that directory
+  /// 2. Otherwise, it creates a temporary directory in the system's temp location
+  ///
+  /// The user data directory is where Chrome stores user preferences, cookies,
+  /// and other session data. Using a temporary directory ensures a clean state
+  /// for each launch, while allowing custom directories through flags for
+  /// persistent configurations.
+  Directory _createUserDataDirectory(List<String> webBrowserFlags) {
+    if (webBrowserFlags.isNotEmpty) {
+      final String? userDataDirFlag = webBrowserFlags.firstWhereOrNull(
+        (String flag) => flag.startsWith('--user-data-dir='),
+      );
+
+      if (userDataDirFlag != null) {
+        final Directory userDataDir = _fileSystem.directory(userDataDirFlag.split('=')[1]);
+        webBrowserFlags.remove(userDataDirFlag);
+        return userDataDir;
+      }
+    }
+    return _fileSystem.systemTempDirectory.createTempSync('flutter_tools_chrome_device.');
+  }
 
   /// Launch a Chromium browser to a particular `host` page.
   ///
@@ -160,7 +182,8 @@ class ChromiumLauncher {
   /// [skipCheck] does not attempt to make a devtools connection before returning.
   ///
   /// [webBrowserFlags] add arbitrary browser flags.
-  Future<Chromium> launch(String url, {
+  Future<Chromium> launch(
+    String url, {
     bool headless = false,
     int? debugPort,
     bool skipCheck = false,
@@ -172,7 +195,9 @@ class ChromiumLauncher {
     }
 
     if (_logger.isVerbose) {
-      _logger.printTrace('Launching Chromium (url = $url, headless = $headless, skipCheck = $skipCheck, debugPort = $debugPort)');
+      _logger.printTrace(
+        'Launching Chromium (url = $url, headless = $headless, skipCheck = $skipCheck, debugPort = $debugPort)',
+      );
     }
 
     final String chromeExecutable = _browserFinder(_platform, _fileSystem);
@@ -182,14 +207,15 @@ class ChromiumLauncher {
 
       if (!_platform.isWindows) {
         // The "--version" argument is not supported on Windows.
-        final ProcessResult versionResult = await _processManager.run(<String>[chromeExecutable, '--version']);
+        final ProcessResult versionResult = await _processManager.run(<String>[
+          chromeExecutable,
+          '--version',
+        ]);
         _logger.printTrace('Using ${versionResult.stdout}');
       }
     }
 
-
-    final Directory userDataDir = _fileSystem.systemTempDirectory
-      .createTempSync('flutter_tools_chrome_device.');
+    final Directory userDataDir = _createUserDataDirectory(webBrowserFlags);
 
     if (cacheDir != null) {
       // Seed data dir with previous state.
@@ -197,7 +223,7 @@ class ChromiumLauncher {
     }
 
     final int port = debugPort ?? await _operatingSystemUtils.findFreePort();
-    final List<String> args = <String>[
+    final args = <String>[
       chromeExecutable,
       // Using a tmp directory ensures that a new instance of chrome launches
       // allowing for the remote debug port to be enabled.
@@ -214,13 +240,14 @@ class ChromiumLauncher {
       '--no-default-browser-check',
       '--disable-default-apps',
       '--disable-translate',
-      if (headless)
-        ...<String>[
-          '--headless',
-          '--disable-gpu',
-          '--no-sandbox',
-          '--window-size=2400,1800',
-        ],
+
+      // Remove the search engine choice screen. It's irrelevant for app
+      // debugging purposes.
+      // See: https://github.com/flutter/flutter/issues/153928
+      '--disable-search-engine-choice-screen',
+      '--no-sandbox',
+
+      if (headless) ...<String>['--headless', '--disable-gpu', '--window-size=2400,1800'],
       ...webBrowserFlags,
       url,
     ];
@@ -229,24 +256,29 @@ class ChromiumLauncher {
 
     // When the process exits, copy the user settings back to the provided data-dir.
     if (cacheDir != null) {
-      unawaited(process.exitCode.whenComplete(() {
-        _cacheUserSessionInformation(userDataDir, cacheDir);
-        // cleanup temp dir
-        try {
-          userDataDir.deleteSync(recursive: true);
-        } on FileSystemException {
-          // ignore
-        }
-      }));
+      unawaited(
+        process.exitCode.whenComplete(() {
+          _cacheUserSessionInformation(userDataDir, cacheDir);
+          // cleanup temp dir
+          try {
+            userDataDir.deleteSync(recursive: true);
+          } on FileSystemException {
+            // ignore
+          }
+        }),
+      );
     }
-    return connect(Chromium(
-      port,
-      ChromeConnection('localhost', port),
-      url: url,
-      process: process,
-      chromiumLauncher: this,
-      logger: _logger,
-    ), skipCheck);
+    return connect(
+      Chromium(
+        port,
+        ChromeConnection('localhost', port),
+        url: url,
+        process: process,
+        chromiumLauncher: this,
+        logger: _logger,
+      ),
+      skipCheck,
+    );
   }
 
   Future<Process> _spawnChromiumProcess(List<String> args, String chromeExecutable) async {
@@ -255,7 +287,9 @@ class ChromiumLauncher {
       // Check if ARM Chrome is installed.
       // Mach-O 64-bit executable arm64
       if ((result.stdout as String).contains('arm64')) {
-        _logger.printTrace('Found ARM Chrome installation at $chromeExecutable, forcing native launch.');
+        _logger.printTrace(
+          'Found ARM Chrome installation at $chromeExecutable, forcing native launch.',
+        );
         // If so, force Chrome to launch natively.
         args.insertAll(0, <String>['/usr/bin/arch', '-arm64']);
       }
@@ -264,56 +298,57 @@ class ChromiumLauncher {
     // Keep attempting to launch the browser until one of:
     // - Chrome launched successfully, in which case we just return from the loop.
     // - The tool reached the maximum retry count, in which case we throw ToolExit.
-    const int kMaxRetries = 3;
-    int retry = 0;
+    const kMaxRetries = 3;
+    var retry = 0;
     while (true) {
       final Process process = await _processManager.start(args);
 
-      process.stdout
-        .transform(utf8.decoder)
-        .transform(const LineSplitter())
-        .listen((String line) {
-          _logger.printTrace('[CHROME]: $line');
-        });
+      process.stdout.transform(utf8LineDecoder).listen((String line) {
+        _logger.printTrace('[CHROME]: $line');
+      });
 
       // Wait until the DevTools are listening before trying to connect. This is
       // only required for flutter_test --platform=chrome and not flutter run.
-      bool hitGlibcBug = false;
-      bool shouldRetry = false;
-      final List<String> errors = <String>[];
+      var hitGlibcBug = false;
+      var shouldRetry = false;
+      final errors = <String>[];
       await process.stderr
-        .transform(utf8.decoder)
-        .transform(const LineSplitter())
-        .map((String line) {
-          _logger.printTrace('[CHROME]: $line');
-          errors.add('[CHROME]:$line');
-          if (line.contains(_kGlibcError)) {
-            hitGlibcBug = true;
-            shouldRetry = true;
-          }
-          return line;
-        })
-        .firstWhere((String line) => line.startsWith('DevTools listening'), orElse: () {
-          if (hitGlibcBug) {
-            _logger.printTrace(
-              'Encountered glibc bug https://sourceware.org/bugzilla/show_bug.cgi?id=19329. '
-              'Will try launching browser again.',
-            );
-            // Return value unused.
-            return '';
-          }
-          if (retry >= kMaxRetries) {
-            errors.forEach(_logger.printError);
-            _logger.printError('Failed to launch browser after $kMaxRetries tries. Command used to launch it: ${args.join(' ')}');
-            throw ToolExit(
-              'Failed to launch browser. Make sure you are using an up-to-date '
-              'Chrome or Edge. Otherwise, consider using -d web-server instead '
-              'and filing an issue at https://github.com/flutter/flutter/issues.',
-            );
-          }
-          shouldRetry = true;
-          return '';
-        });
+          .transform(utf8LineDecoder)
+          .map((String line) {
+            _logger.printTrace('[CHROME]: $line');
+            errors.add('[CHROME]:$line');
+            if (line.contains(_kGlibcError)) {
+              hitGlibcBug = true;
+              shouldRetry = true;
+            }
+            return line;
+          })
+          .firstWhere(
+            (String line) => line.startsWith('DevTools listening'),
+            orElse: () {
+              if (hitGlibcBug) {
+                _logger.printTrace(
+                  'Encountered glibc bug https://sourceware.org/bugzilla/show_bug.cgi?id=19329. '
+                  'Will try launching browser again.',
+                );
+                // Return value unused.
+                return '';
+              }
+              if (retry >= kMaxRetries) {
+                errors.forEach(_logger.printError);
+                _logger.printError(
+                  'Failed to launch browser after $kMaxRetries tries. Command used to launch it: ${args.join(' ')}',
+                );
+                throwToolExit(
+                  'Failed to launch browser. Make sure you are using an up-to-date '
+                  'Chrome or Edge. Otherwise, consider using -d web-server instead '
+                  'and filing an issue at https://github.com/flutter/flutter/issues.',
+                );
+              }
+              shouldRetry = true;
+              return '';
+            },
+          );
 
       if (!hitGlibcBug && !shouldRetry) {
         return process;
@@ -323,11 +358,16 @@ class ChromiumLauncher {
       // A precaution that avoids accumulating browser processes, in case the
       // glibc bug doesn't cause the browser to quit and we keep looping and
       // launching more processes.
-      unawaited(process.exitCode.timeout(const Duration(seconds: 1), onTimeout: () {
-        process.kill();
-        // sigterm
-        return 15;
-      }));
+      unawaited(
+        process.exitCode.timeout(
+          const Duration(seconds: 1),
+          onTimeout: () {
+            process.kill();
+            // sigterm
+            return 15;
+          },
+        ),
+      );
     }
   }
 
@@ -352,15 +392,19 @@ class ChromiumLauncher {
   /// dart debug extension with a user controlled browser profile will lead to a
   /// better experience.
   void _cacheUserSessionInformation(Directory userDataDir, Directory cacheDir) {
-    final Directory targetChromeDefault = _fileSystem.directory(_fileSystem.path.join(cacheDir.path, _chromeDefaultPath));
-    final Directory sourceChromeDefault = _fileSystem.directory(_fileSystem.path.join(userDataDir.path, _chromeDefaultPath));
+    final Directory targetChromeDefault = _fileSystem.directory(
+      _fileSystem.path.join(cacheDir.path, _chromeDefaultPath),
+    );
+    final Directory sourceChromeDefault = _fileSystem.directory(
+      _fileSystem.path.join(userDataDir.path, _chromeDefaultPath),
+    );
     if (sourceChromeDefault.existsSync()) {
       targetChromeDefault.createSync(recursive: true);
       try {
         copyDirectory(
           sourceChromeDefault,
           targetChromeDefault,
-          shouldCopyDirectory: _isNotCacheDirectory
+          shouldCopyDirectory: _isNotCacheDirectory,
         );
       } on FileSystemException catch (err) {
         // This is a best-effort update. Display the message in case the failure is relevant.
@@ -369,23 +413,32 @@ class ChromiumLauncher {
       }
     }
 
-    final File targetPreferencesFile = _fileSystem.file(_fileSystem.path.join(cacheDir.path, _preferencesPath));
-    final File sourcePreferencesFile = _fileSystem.file(_fileSystem.path.join(userDataDir.path, _preferencesPath));
+    final File targetPreferencesFile = _fileSystem.file(
+      _fileSystem.path.join(cacheDir.path, _preferencesPath),
+    );
+    final File sourcePreferencesFile = _fileSystem.file(
+      _fileSystem.path.join(userDataDir.path, _preferencesPath),
+    );
 
     if (sourcePreferencesFile.existsSync()) {
-       targetPreferencesFile.parent.createSync(recursive: true);
-       // If the file contains a crash string, remove it to hide the popup on next run.
-       final String contents = sourcePreferencesFile.readAsStringSync();
-       targetPreferencesFile.writeAsStringSync(contents
-           .replaceFirst('"exit_type":"Crashed"', '"exit_type":"Normal"'));
+      targetPreferencesFile.parent.createSync(recursive: true);
+      // If the file contains a crash string, remove it to hide the popup on next run.
+      final String contents = sourcePreferencesFile.readAsStringSync();
+      targetPreferencesFile.writeAsStringSync(
+        contents.replaceFirst('"exit_type":"Crashed"', '"exit_type":"Normal"'),
+      );
     }
   }
 
   /// Restore Chrome user information from a per-project cache into Chrome's
   /// user data directory.
   void _restoreUserSessionInformation(Directory cacheDir, Directory userDataDir) {
-    final Directory sourceChromeDefault = _fileSystem.directory(_fileSystem.path.join(cacheDir.path, _chromeDefaultPath));
-    final Directory targetChromeDefault = _fileSystem.directory(_fileSystem.path.join(userDataDir.path, _chromeDefaultPath));
+    final Directory sourceChromeDefault = _fileSystem.directory(
+      _fileSystem.path.join(cacheDir.path, _chromeDefaultPath),
+    );
+    final Directory targetChromeDefault = _fileSystem.directory(
+      _fileSystem.path.join(userDataDir.path, _chromeDefaultPath),
+    );
     try {
       if (sourceChromeDefault.existsSync()) {
         targetChromeDefault.createSync(recursive: true);
@@ -403,8 +456,8 @@ class ChromiumLauncher {
   // Cache, Code Cache, and GPUCache are nearly 1GB of data
   bool _isNotCacheDirectory(Directory directory) {
     return !directory.path.endsWith('Cache') &&
-           !directory.path.endsWith('Code Cache') &&
-           !directory.path.endsWith('GPUCache');
+        !directory.path.endsWith('Code Cache') &&
+        !directory.path.endsWith('GPUCache');
   }
 
   /// Connect to the [chrome] instance, testing the connection if
@@ -419,8 +472,7 @@ class ChromiumLauncher {
       } on Exception catch (error, stackTrace) {
         _logger.printError('$error', stackTrace: stackTrace);
         await chrome.close();
-        throwToolExit(
-            'Unable to connect to Chrome debug port: ${chrome.debugPort}\n $error');
+        throwToolExit('Unable to connect to Chrome debug port: ${chrome.debugPort}\n $error');
       }
     }
     currentCompleter.complete(chrome);
@@ -439,9 +491,9 @@ class Chromium {
     required Process process,
     required ChromiumLauncher chromiumLauncher,
     required Logger logger,
-  })  : _process = process,
-        _chromiumLauncher = chromiumLauncher,
-        _logger = logger;
+  }) : _process = process,
+       _chromiumLauncher = chromiumLauncher,
+       _logger = logger;
 
   final String? url;
   final int debugPort;
@@ -449,7 +501,7 @@ class Chromium {
   final ChromeConnection chromeConnection;
   final ChromiumLauncher _chromiumLauncher;
   final Logger _logger;
-  bool _hasValidChromeConnection = false;
+  var _hasValidChromeConnection = false;
 
   /// Resolves to browser's main process' exit code, when the browser exits.
   Future<int> get onExit async => _process.exitCode;
@@ -460,7 +512,7 @@ class Chromium {
   @visibleForTesting
   Process get process => _process;
 
-  /// Gets the first [chrome] tab in order to verify that the connection to
+  /// Gets the first Chrome tab in order to verify that the connection to
   /// the Chrome debug protocol is working properly.
   ///
   /// Retries getting tabs from Chrome for a few seconds and retries finding
@@ -471,13 +523,12 @@ class Chromium {
   // (We should just keep waiting forever, and print a warning when it's
   // taking too long.)
   Future<void> _validateChromeConnection() async {
-    const Duration retryFor = Duration(seconds: 2);
-    const int attempts = 5;
+    const retryFor = Duration(seconds: 2);
+    const attempts = 5;
 
-    for (int i = 1; i <= attempts; i++) {
+    for (var i = 1; i <= attempts; i++) {
       try {
-        final List<ChromeTab> tabs =
-          await chromeConnection.getTabs(retryFor: retryFor);
+        final List<ChromeTab> tabs = await chromeConnection.getTabs(retryFor: retryFor);
 
         if (tabs.isNotEmpty) {
           _hasValidChromeConnection = true;
@@ -490,6 +541,10 @@ class Chromium {
         if (i == attempts) {
           rethrow;
         }
+      } on IOException {
+        if (i == attempts) {
+          rethrow;
+        }
       }
       await Future<void>.delayed(const Duration(milliseconds: 25));
     }
@@ -507,48 +562,88 @@ class Chromium {
     // Send a command to shut down the browser cleanly.
     Duration sigtermDelay = Duration.zero;
     if (_hasValidChromeConnection) {
-      ChromeTab? tab;
       try {
-        tab = await chromeConnection.getTab(
-            (_) => true, retryFor: const Duration(seconds: 1));
-      } on SocketException {
+        final ChromeTab? tab = await getChromeTabGuarded(
+          chromeConnection,
+          (_) => true,
+          retryFor: const Duration(seconds: 1),
+        );
+        if (tab != null) {
+          final WipConnection wipConnection = await tab.connect();
+          await wipConnection.sendCommand('Browser.close');
+          await wipConnection.close();
+          sigtermDelay = const Duration(seconds: 1);
+        }
+      } on IOException {
         // Chrome is not responding to the debug protocol and probably has
         // already been closed.
       }
-      if (tab != null) {
-        final WipConnection wipConnection = await tab.connect();
-        await wipConnection.sendCommand('Browser.close');
-        await wipConnection.close();
-        sigtermDelay = const Duration(seconds: 1);
-      }
     }
     chromeConnection.close();
     _hasValidChromeConnection = false;
 
     // If the browser close command did not shut down the process, then try to
     // exit Chromium using SIGTERM.
-    await _process.exitCode.timeout(sigtermDelay, onTimeout: () {
-      ProcessSignal.sigterm.kill(_process);
-      return 0;
-    });
+    await _process.exitCode.timeout(
+      sigtermDelay,
+      onTimeout: () {
+        ProcessSignal.sigterm.kill(_process);
+        return 0;
+      },
+    );
     // If the process still has not ended, then use SIGKILL. Wait up to 5
     // seconds for Chromium to exit before falling back to SIGKILL and then to
     // a warning message.
-    await _process.exitCode.timeout(const Duration(seconds: 5), onTimeout: () {
-      _logger.printWarning(
-        'Failed to exit Chromium (pid: ${_process.pid}) using SIGTERM. Will try '
-        'sending SIGKILL instead.'
-      );
-      ProcessSignal.sigkill.kill(_process);
-      return _process.exitCode.timeout(const Duration(seconds: 5), onTimeout: () async {
+    await _process.exitCode.timeout(
+      const Duration(seconds: 5),
+      onTimeout: () {
         _logger.printWarning(
-          'Failed to exit Chromium (pid: ${_process.pid}) using SIGKILL. Giving '
-          'up. Will continue, assuming Chromium has exited successfully, but '
-          'it is possible that this left a dangling Chromium process running '
-          'on the system.'
+          'Failed to exit Chromium (pid: ${_process.pid}) using SIGTERM. Will try '
+          'sending SIGKILL instead.',
         );
-        return 0;
-      });
-    });
+        ProcessSignal.sigkill.kill(_process);
+        return _process.exitCode.timeout(
+          const Duration(seconds: 5),
+          onTimeout: () async {
+            _logger.printWarning(
+              'Failed to exit Chromium (pid: ${_process.pid}) using SIGKILL. Giving '
+              'up. Will continue, assuming Chromium has exited successfully, but '
+              'it is possible that this left a dangling Chromium process running '
+              'on the system.',
+            );
+            return 0;
+          },
+        );
+      },
+    );
+  }
+}
+
+/// Wrapper for [ChromeConnection.getTab] that will catch any [IOException] or
+/// [StateError], delegate it to the [onIoError] callback, and return null.
+///
+/// This is useful for callers who are want to retrieve a [ChromeTab], but
+/// are okay with the operation failing (e.g. due to an network IO issue or
+/// the Chrome process no longer existing).
+Future<ChromeTab?> getChromeTabGuarded(
+  ChromeConnection chromeConnection,
+  bool Function(ChromeTab tab) accept, {
+  Duration? retryFor,
+  void Function(Object error, StackTrace stackTrace)? onIoError,
+}) async {
+  try {
+    return await asyncGuard(() => chromeConnection.getTab(accept, retryFor: retryFor));
+  } on IOException catch (error, stackTrace) {
+    if (onIoError != null) {
+      onIoError(error, stackTrace);
+    }
+    return null;
+    // The underlying HttpClient will throw a StateError when it tries to
+    // perform a request despite the connection already being closed.
+  } on StateError catch (error, stackTrace) {
+    if (onIoError != null) {
+      onIoError(error, stackTrace);
+    }
+    return null;
   }
 }
