@@ -25,8 +25,8 @@ import '../../src/android_common.dart';
 import '../../src/common.dart';
 import '../../src/context.dart';
 import '../../src/fake_process_manager.dart';
-import '../../src/fake_pub_deps.dart';
 import '../../src/fakes.dart' hide FakeFlutterProjectFactory;
+import '../../src/test_build_system.dart';
 import '../../src/test_flutter_command_runner.dart';
 
 void main() {
@@ -45,7 +45,7 @@ void main() {
     AndroidSdk? androidSdk = const _FakeAndroidSdk(),
     List<String>? arguments,
   }) async {
-    final BuildAarCommand command = BuildAarCommand(
+    final command = BuildAarCommand(
       androidSdk: androidSdk,
       fileSystem: globals.fs,
       logger: BufferLogger.test(),
@@ -56,11 +56,6 @@ void main() {
     return command;
   }
 
-  // TODO(matanlurey): Remove after `explicit-package-dependencies` is enabled by default.
-  FeatureFlags enableExplicitPackageDependencies() {
-    return TestFeatureFlags(isExplicitPackageDependenciesEnabled: true);
-  }
-
   group('Usage', () {
     late Directory tempDir;
     late FakeAnalytics analytics;
@@ -154,8 +149,7 @@ void main() {
       overrides: <Type, Generator>{
         AndroidBuilder: () => _CapturingFakeAndroidBuilder(),
         Analytics: () => analytics,
-        FeatureFlags: enableExplicitPackageDependencies,
-        Pub: () => FakePubWithPrimedDeps(allowGet: true),
+        Pub: FakePub.new,
       },
     );
 
@@ -215,8 +209,8 @@ void main() {
       final Invocation buildAarCall = fakeAndroidBuilder.capturedBuildAarCalls.single;
       expect(buildAarCall.namedArguments[#buildNumber], '1.0');
 
-      final List<BuildMode> buildModes = <BuildMode>[];
-      for (final AndroidBuildInfo androidBuildInfo
+      final buildModes = <BuildMode>[];
+      for (final androidBuildInfo
           in buildAarCall.namedArguments[#androidBuildInfo] as Set<AndroidBuildInfo>) {
         final BuildInfo buildInfo = androidBuildInfo.buildInfo;
         buildModes.add(buildInfo.mode);
@@ -255,7 +249,7 @@ void main() {
           '--no-debug',
           '--no-profile',
           '--target-platform',
-          'android-x86',
+          'android-x64',
           '--tree-shake-icons',
           '--flavor',
           'free',
@@ -278,7 +272,7 @@ void main() {
 
       final AndroidBuildInfo androidBuildInfo =
           (buildAarCall.namedArguments[#androidBuildInfo] as Set<AndroidBuildInfo>).single;
-      expect(androidBuildInfo.targetArchs, <AndroidArch>[AndroidArch.x86]);
+      expect(androidBuildInfo.targetArchs, <AndroidArch>[AndroidArch.x86_64]);
 
       final BuildInfo buildInfo = androidBuildInfo.buildInfo;
       expect(buildInfo.mode, BuildMode.release);
@@ -381,7 +375,14 @@ void main() {
               '-PbuildNumber=1.0',
               '-q',
               '-Ptarget=${globals.fs.path.join('lib', 'main.dart')}',
-              '-Pdart-defines=RkxVVFRFUl9WRVJTSU9OPTAuMC4w,RkxVVFRFUl9DSEFOTkVMPW1hc3Rlcg==,RkxVVFRFUl9HSVRfVVJMPWh0dHBzOi8vZ2l0aHViLmNvbS9mbHV0dGVyL2ZsdXR0ZXIuZ2l0,RkxVVFRFUl9GUkFNRVdPUktfUkVWSVNJT049MTExMTE=,RkxVVFRFUl9FTkdJTkVfUkVWSVNJT049YWJjZGU=,RkxVVFRFUl9EQVJUX1ZFUlNJT049MTI=',
+              '-Pdart-defines=${encodeDartDefinesMap(<String, String>{
+                'FLUTTER_VERSION': '0.0.0', //
+                'FLUTTER_CHANNEL': 'master',
+                'FLUTTER_GIT_URL': 'https://github.com/flutter/flutter.git',
+                'FLUTTER_FRAMEWORK_REVISION': '11111',
+                'FLUTTER_ENGINE_REVISION': 'abcde',
+                'FLUTTER_DART_VERSION': '12',
+              })}',
               '-Pdart-obfuscation=false',
               '-Pextra-front-end-options=foo,bar',
               '-Ptrack-widget-creation=true',
@@ -548,7 +549,7 @@ void main() {
 ///
 /// Calls to [buildAar] are stored as [capturedBuildAarCalls], other calls are rejected.
 final class _CapturingFakeAndroidBuilder extends Fake implements AndroidBuilder {
-  final List<Invocation> capturedBuildAarCalls = <Invocation>[];
+  final capturedBuildAarCalls = <Invocation>[];
 
   @override
   Object? noSuchMethod(Invocation invocation) {
@@ -568,3 +569,18 @@ final class _FakeAndroidStudio extends Fake implements AndroidStudio {
   @override
   String get javaPath => 'java';
 }
+
+class FakePub extends Fake implements Pub {
+  @override
+  Future<void> get({
+    PubContext? context,
+    required FlutterProject project,
+    bool upgrade = false,
+    bool offline = false,
+    String? flutterRootOverride,
+    bool checkUpToDate = false,
+    bool shouldSkipThirdPartyGenerator = true,
+    bool enforceLockfile = false,
+    PubOutputMode outputMode = PubOutputMode.all,
+  }) async {}
+}
