@@ -157,25 +157,26 @@ void main() {
           completer: completer,
           environment: const <String, String>{
             'FLUTTER_ENGINE_SWITCH_1': 'enable-dart-profiling=true',
-            'FLUTTER_ENGINE_SWITCH_2': 'trace-startup=true',
-            'FLUTTER_ENGINE_SWITCH_3': 'enable-software-rendering=true',
-            'FLUTTER_ENGINE_SWITCH_4': 'skia-deterministic-rendering=true',
-            'FLUTTER_ENGINE_SWITCH_5': 'trace-skia=true',
-            'FLUTTER_ENGINE_SWITCH_6': 'trace-allowlist=foo,bar',
-            'FLUTTER_ENGINE_SWITCH_7': 'trace-skia-allowlist=skia.a,skia.b',
-            'FLUTTER_ENGINE_SWITCH_8': 'trace-systrace=true',
-            'FLUTTER_ENGINE_SWITCH_9': 'trace-to-file=path/to/trace.binpb',
-            'FLUTTER_ENGINE_SWITCH_10': 'endless-trace-buffer=true',
-            'FLUTTER_ENGINE_SWITCH_11': 'profile-microtasks=true',
-            'FLUTTER_ENGINE_SWITCH_12': 'purge-persistent-cache=true',
-            'FLUTTER_ENGINE_SWITCH_13': 'enable-impeller=false',
-            'FLUTTER_ENGINE_SWITCH_14': 'enable-checked-mode=true',
-            'FLUTTER_ENGINE_SWITCH_15': 'verify-entry-points=true',
-            'FLUTTER_ENGINE_SWITCH_16': 'start-paused=true',
-            'FLUTTER_ENGINE_SWITCH_17': 'disable-service-auth-codes=true',
-            'FLUTTER_ENGINE_SWITCH_18': 'use-test-fonts=true',
-            'FLUTTER_ENGINE_SWITCH_19': 'verbose-logging=true',
-            'FLUTTER_ENGINE_SWITCHES': '19',
+            'FLUTTER_ENGINE_SWITCH_2': 'profile-startup=true',
+            'FLUTTER_ENGINE_SWITCH_3': 'trace-startup=true',
+            'FLUTTER_ENGINE_SWITCH_4': 'enable-software-rendering=true',
+            'FLUTTER_ENGINE_SWITCH_5': 'skia-deterministic-rendering=true',
+            'FLUTTER_ENGINE_SWITCH_6': 'trace-skia=true',
+            'FLUTTER_ENGINE_SWITCH_7': 'trace-allowlist=foo,bar',
+            'FLUTTER_ENGINE_SWITCH_8': 'trace-skia-allowlist=skia.a,skia.b',
+            'FLUTTER_ENGINE_SWITCH_9': 'trace-systrace=true',
+            'FLUTTER_ENGINE_SWITCH_10': 'trace-to-file=path/to/trace.binpb',
+            'FLUTTER_ENGINE_SWITCH_11': 'endless-trace-buffer=true',
+            'FLUTTER_ENGINE_SWITCH_12': 'profile-microtasks=true',
+            'FLUTTER_ENGINE_SWITCH_13': 'purge-persistent-cache=true',
+            'FLUTTER_ENGINE_SWITCH_14': 'enable-impeller=false',
+            'FLUTTER_ENGINE_SWITCH_15': 'enable-checked-mode=true',
+            'FLUTTER_ENGINE_SWITCH_16': 'verify-entry-points=true',
+            'FLUTTER_ENGINE_SWITCH_17': 'start-paused=true',
+            'FLUTTER_ENGINE_SWITCH_18': 'disable-service-auth-codes=true',
+            'FLUTTER_ENGINE_SWITCH_19': 'use-test-fonts=true',
+            'FLUTTER_ENGINE_SWITCH_20': 'verbose-logging=true',
+            'FLUTTER_ENGINE_SWITCHES': '20',
           },
         ),
       ]);
@@ -198,6 +199,7 @@ void main() {
           traceToFile: 'path/to/trace.binpb',
           endlessTraceBuffer: true,
           profileMicrotasks: true,
+          profileStartup: true,
           purgePersistentCache: true,
           useTestFonts: true,
           verboseSystemLogs: true,
