@@ -7,6 +7,7 @@ import 'package:file/memory.dart';
 import 'package:flutter_tools/src/base/deferred_component.dart';
 import 'package:flutter_tools/src/base/file_system.dart';
 import 'package:flutter_tools/src/base/logger.dart';
+import 'package:flutter_tools/src/base/yaml.dart';
 import 'package:flutter_tools/src/cache.dart';
 import 'package:flutter_tools/src/flutter_manifest.dart';
 
@@ -24,10 +25,7 @@ void main() {
   });
 
   testWithoutContext('FlutterManifest is empty when the pubspec.yaml file is empty', () async {
-    final FlutterManifest flutterManifest = FlutterManifest.createFromString(
-      '',
-      logger: logger,
-    )!;
+    final FlutterManifest flutterManifest = FlutterManifest.createFromString('', logger: logger)!;
 
     expect(flutterManifest.isEmpty, true);
     expect(flutterManifest.appName, '');
@@ -40,37 +38,37 @@ void main() {
   });
 
   testWithoutContext('FlutterManifest is null when the pubspec.yaml file is not a map', () async {
-    expect(FlutterManifest.createFromString(
-      'Not a map',
-      logger: logger,
-    ), isNull);
+    expect(FlutterManifest.createFromString('Not a map', logger: logger), isNull);
 
     expect(logger.errorText, contains('Expected YAML map'));
   });
 
-  testWithoutContext('FlutterManifest has no fonts or assets when the "flutter" section is empty', () async {
-    const String manifest = '''
+  testWithoutContext(
+    'FlutterManifest has no fonts or assets when the "flutter" section is empty',
+    () async {
+      const manifest = '''
 name: test
 dependencies:
   flutter:
     sdk: flutter
 ''';
-    final FlutterManifest flutterManifest = FlutterManifest.createFromString(
-      manifest,
-      logger: logger,
-    )!;
+      final FlutterManifest flutterManifest = FlutterManifest.createFromString(
+        manifest,
+        logger: logger,
+      )!;
 
-    expect(flutterManifest, isNotNull);
-    expect(flutterManifest.isEmpty, false);
-    expect(flutterManifest.appName, 'test');
-    expect(flutterManifest.usesMaterialDesign, false);
-    expect(flutterManifest.fontsDescriptor, isEmpty);
-    expect(flutterManifest.fonts, isEmpty);
-    expect(flutterManifest.assets, isEmpty);
-  });
+      expect(flutterManifest, isNotNull);
+      expect(flutterManifest.isEmpty, false);
+      expect(flutterManifest.appName, 'test');
+      expect(flutterManifest.usesMaterialDesign, false);
+      expect(flutterManifest.fontsDescriptor, isEmpty);
+      expect(flutterManifest.fonts, isEmpty);
+      expect(flutterManifest.assets, isEmpty);
+    },
+  );
 
   testWithoutContext('FlutterManifest knows if Material Design is used', () async {
-    const String manifest = '''
+    const manifest = '''
 name: test
 dependencies:
   flutter:
@@ -87,7 +85,7 @@ flutter:
   });
 
   testWithoutContext('FlutterManifest knows if generate is provided', () async {
-    const String manifest = '''
+    const manifest = '''
 name: test
 dependencies:
   flutter:
@@ -100,11 +98,11 @@ flutter:
       logger: logger,
     )!;
 
-    expect(flutterManifest.generateSyntheticPackage, true);
+    expect(flutterManifest.generateLocalizations, true);
   });
 
   testWithoutContext('FlutterManifest can parse invalid generate key', () async {
-    const String manifest = '''
+    const manifest = '''
 name: test
 dependencies:
   flutter:
@@ -117,11 +115,11 @@ flutter:
       logger: logger,
     )!;
 
-    expect(flutterManifest.generateSyntheticPackage, false);
+    expect(flutterManifest.generateLocalizations, false);
   });
 
   testWithoutContext('FlutterManifest knows if generate is disabled', () async {
-    const String manifest = '''
+    const manifest = '''
 name: test
 dependencies:
   flutter:
@@ -134,11 +132,11 @@ flutter:
       logger: logger,
     )!;
 
-    expect(flutterManifest.generateSyntheticPackage, false);
+    expect(flutterManifest.generateLocalizations, false);
   });
 
   testWithoutContext('FlutterManifest has one font family with one asset', () async {
-    const String manifest = '''
+    const manifest = '''
 name: test
 dependencies:
   flutter:
@@ -157,23 +155,24 @@ flutter:
     )!;
 
     expect(flutterManifest.fonts, hasLength(1));
-    expect(flutterManifest.fonts.single, matchesFont(
-      familyName: 'foo',
-      descriptor: <String, Object>{
-        'family': 'foo',
-        'fonts': <Object>[
-          <String, Object>{'asset': 'a/bar'},
-        ],
-      },
-      fontAssets: <Matcher>[
-        matchesFontAsset(assetUri: Uri.parse('a/bar')),
-      ],
-    ));
+    expect(
+      flutterManifest.fonts.single,
+      matchesFont(
+        familyName: 'foo',
+        descriptor: <String, Object>{
+          'family': 'foo',
+          'fonts': <Object>[
+            <String, Object>{'asset': 'a/bar'},
+          ],
+        },
+        fontAssets: <Matcher>[matchesFontAsset(assetUri: Uri.parse('a/bar'))],
+      ),
+    );
   });
 
   testWithoutContext('FlutterManifest has one font family with a simple asset '
-    'and one with weight', () async {
-      const String manifest = '''
+      'and one with weight', () async {
+    const manifest = '''
 name: test
 dependencies:
   flutter:
@@ -194,25 +193,28 @@ flutter:
     )!;
 
     expect(flutterManifest.fonts, hasLength(1));
-    expect(flutterManifest.fonts.single, matchesFont(
-      familyName: 'foo',
-      descriptor: <String, Object>{
-        'family': 'foo',
-        'fonts': <Object>[
-          <String, Object>{'asset': 'a/bar'},
-          <String, Object>{'weight': 400, 'asset': 'a/bar'},
+    expect(
+      flutterManifest.fonts.single,
+      matchesFont(
+        familyName: 'foo',
+        descriptor: <String, Object>{
+          'family': 'foo',
+          'fonts': <Object>[
+            <String, Object>{'asset': 'a/bar'},
+            <String, Object>{'weight': 400, 'asset': 'a/bar'},
+          ],
+        },
+        fontAssets: <Matcher>[
+          matchesFontAsset(assetUri: Uri.parse('a/bar')),
+          matchesFontAsset(assetUri: Uri.parse('a/bar'), weight: 400),
         ],
-      },
-      fontAssets: <Matcher>[
-        matchesFontAsset(assetUri: Uri.parse('a/bar')),
-        matchesFontAsset(assetUri: Uri.parse('a/bar'), weight: 400),
-      ])
+      ),
     );
   });
 
   testWithoutContext('FlutterManifest has one font family with a simple asset '
-    'and one with weight and style', () {
-    const String manifest = '''
+      'and one with weight and style', () {
+    const manifest = '''
 name: test
 dependencies:
   flutter:
@@ -234,25 +236,28 @@ flutter:
     )!;
 
     expect(flutterManifest.fonts, hasLength(1));
-    expect(flutterManifest.fonts.single, matchesFont(
-      familyName: 'foo',
-      descriptor: <String, Object>{
-        'family': 'foo',
-        'fonts': <Object>[
-          <String, Object>{'asset': 'a/bar'},
-          <String, Object>{'weight': 400, 'style': 'italic', 'asset': 'a/bar'},
+    expect(
+      flutterManifest.fonts.single,
+      matchesFont(
+        familyName: 'foo',
+        descriptor: <String, Object>{
+          'family': 'foo',
+          'fonts': <Object>[
+            <String, Object>{'asset': 'a/bar'},
+            <String, Object>{'weight': 400, 'style': 'italic', 'asset': 'a/bar'},
+          ],
+        },
+        fontAssets: <Matcher>[
+          matchesFontAsset(assetUri: Uri.parse('a/bar')),
+          matchesFontAsset(assetUri: Uri.parse('a/bar'), weight: 400, style: 'italic'),
         ],
-      },
-      fontAssets: <Matcher>[
-        matchesFontAsset(assetUri: Uri.parse('a/bar')),
-        matchesFontAsset(assetUri: Uri.parse('a/bar'), weight: 400, style: 'italic'),
-      ],
-    ));
+      ),
+    );
   });
 
   testWithoutContext('FlutterManifest has two font families, each with one '
-    'simple asset and one with weight and style', () {
-    const String manifest = '''
+      'simple asset and one with weight and style', () {
+    const manifest = '''
 name: test
 dependencies:
   flutter:
@@ -280,41 +285,44 @@ flutter:
     )!;
 
     expect(flutterManifest.fonts, hasLength(2));
-    expect(flutterManifest.fonts, containsAll(<Matcher>[
-      matchesFont(
-        familyName: 'foo',
-        descriptor:  <String, Object>{
-          'family': 'foo',
-          'fonts': <Object>[
-            <String, Object>{'asset': 'a/bar'},
-            <String, Object>{'weight': 400, 'style': 'italic', 'asset': 'a/bar'},
+    expect(
+      flutterManifest.fonts,
+      containsAll(<Matcher>[
+        matchesFont(
+          familyName: 'foo',
+          descriptor: <String, Object>{
+            'family': 'foo',
+            'fonts': <Object>[
+              <String, Object>{'asset': 'a/bar'},
+              <String, Object>{'weight': 400, 'style': 'italic', 'asset': 'a/bar'},
+            ],
+          },
+          fontAssets: <Matcher>[
+            matchesFontAsset(assetUri: Uri.parse('a/bar')),
+            matchesFontAsset(assetUri: Uri.parse('a/bar'), weight: 400, style: 'italic'),
           ],
-        },
-        fontAssets: <Matcher>[
-          matchesFontAsset(assetUri: Uri.parse('a/bar')),
-          matchesFontAsset(assetUri: Uri.parse('a/bar'), weight: 400, style: 'italic'),
-        ],
-      ),
-      matchesFont(
-        familyName: 'bar',
-        descriptor: <String, Object>{
-          'family': 'bar',
-          'fonts': <Object>[
-            <String, Object>{'asset': 'a/baz'},
-            <String, Object>{'weight': 400, 'style': 'italic', 'asset': 'a/baz'},
+        ),
+        matchesFont(
+          familyName: 'bar',
+          descriptor: <String, Object>{
+            'family': 'bar',
+            'fonts': <Object>[
+              <String, Object>{'asset': 'a/baz'},
+              <String, Object>{'weight': 400, 'style': 'italic', 'asset': 'a/baz'},
+            ],
+          },
+          fontAssets: <Matcher>[
+            matchesFontAsset(assetUri: Uri.parse('a/baz')),
+            matchesFontAsset(assetUri: Uri.parse('a/baz'), weight: 400, style: 'italic'),
           ],
-        },
-        fontAssets: <Matcher>[
-          matchesFontAsset(assetUri: Uri.parse('a/baz')),
-          matchesFontAsset(assetUri: Uri.parse('a/baz'), weight: 400, style: 'italic'),
-        ],
-      ),
-    ]));
+        ),
+      ]),
+    );
   });
 
   testWithoutContext('FlutterManifest.fontsDescriptor combines descriptors from '
-    'individual fonts', () {
-    const String manifest = '''
+      'individual fonts', () {
+    const manifest = '''
 name: test
 dependencies:
   flutter:
@@ -360,8 +368,8 @@ flutter:
   });
 
   testWithoutContext('FlutterManifest has only one of two font families when '
-    'one declaration is missing the "family" option', () async {
-    const String manifest = '''
+      'one declaration is missing the "family" option', () async {
+    const manifest = '''
 name: test
 dependencies:
   flutter:
@@ -388,27 +396,30 @@ flutter:
     )!;
 
     expect(flutterManifest.fonts, hasLength(1));
-    expect(flutterManifest.fonts, containsAll(<Matcher>[
-      matchesFont(
-        familyName: 'foo',
-        descriptor:  <String, Object>{
-          'family': 'foo',
-          'fonts': <Object>[
-            <String, Object>{'asset': 'a/bar'},
-            <String, Object>{'weight': 400, 'style': 'italic', 'asset': 'a/bar'},
+    expect(
+      flutterManifest.fonts,
+      containsAll(<Matcher>[
+        matchesFont(
+          familyName: 'foo',
+          descriptor: <String, Object>{
+            'family': 'foo',
+            'fonts': <Object>[
+              <String, Object>{'asset': 'a/bar'},
+              <String, Object>{'weight': 400, 'style': 'italic', 'asset': 'a/bar'},
+            ],
+          },
+          fontAssets: <Matcher>[
+            matchesFontAsset(assetUri: Uri.parse('a/bar')),
+            matchesFontAsset(assetUri: Uri.parse('a/bar'), weight: 400, style: 'italic'),
           ],
-        },
-        fontAssets: <Matcher>[
-          matchesFontAsset(assetUri: Uri.parse('a/bar')),
-          matchesFontAsset(assetUri: Uri.parse('a/bar'), weight: 400, style: 'italic'),
-        ],
-      ),
-    ]));
+        ),
+      ]),
+    );
   });
 
   testWithoutContext('FlutterManifest has only one of two font families when '
-    'one declaration is missing the "fonts" option', () async {
-    const String manifest = '''
+      'one declaration is missing the "fonts" option', () async {
+    const manifest = '''
 name: test
 dependencies:
   flutter:
@@ -431,27 +442,30 @@ flutter:
     )!;
 
     expect(flutterManifest.fonts, hasLength(1));
-    expect(flutterManifest.fonts, containsAll(<Matcher>[
-      matchesFont(
-        familyName: 'foo',
-        descriptor:  <String, Object>{
-          'family': 'foo',
-          'fonts': <Object>[
-            <String, Object>{'asset': 'a/bar'},
-            <String, Object>{'weight': 400, 'style': 'italic', 'asset': 'a/bar'},
+    expect(
+      flutterManifest.fonts,
+      containsAll(<Matcher>[
+        matchesFont(
+          familyName: 'foo',
+          descriptor: <String, Object>{
+            'family': 'foo',
+            'fonts': <Object>[
+              <String, Object>{'asset': 'a/bar'},
+              <String, Object>{'weight': 400, 'style': 'italic', 'asset': 'a/bar'},
+            ],
+          },
+          fontAssets: <Matcher>[
+            matchesFontAsset(assetUri: Uri.parse('a/bar')),
+            matchesFontAsset(assetUri: Uri.parse('a/bar'), weight: 400, style: 'italic'),
           ],
-        },
-        fontAssets: <Matcher>[
-          matchesFontAsset(assetUri: Uri.parse('a/bar')),
-          matchesFontAsset(assetUri: Uri.parse('a/bar'), weight: 400, style: 'italic'),
-        ],
-      ),
-    ]));
+        ),
+      ]),
+    );
   });
 
   testWithoutContext('FlutterManifest has no font family when declaration is '
-    'missing the "asset" option', () async {
-    const String manifest = '''
+      'missing the "asset" option', () async {
+    const manifest = '''
 name: test
 dependencies:
   flutter:
@@ -474,7 +488,7 @@ flutter:
   });
 
   testWithoutContext('FlutterManifest allows a blank flutter section', () {
-    const String manifest = '''
+    const manifest = '''
 name: test
 dependencies:
   flutter:
@@ -495,7 +509,7 @@ flutter:
   });
 
   testWithoutContext('FlutterManifest allows a module declaration', () {
-    const String manifest = '''
+    const manifest = '''
 name: test
 flutter:
   module:
@@ -514,7 +528,7 @@ flutter:
   });
 
   testWithoutContext('FlutterManifest allows a legacy plugin declaration', () {
-    const String manifest = '''
+    const manifest = '''
 name: test
 flutter:
   plugin:
@@ -531,8 +545,8 @@ flutter:
   });
 
   testWithoutContext('FlutterManifest allows a multi-plat plugin declaration '
-    'with android only', () {
-    const String manifest = '''
+      'with android only', () {
+    const manifest = '''
 name: test
 flutter:
     plugin:
@@ -552,8 +566,8 @@ flutter:
   });
 
   testWithoutContext('FlutterManifest allows a multi-plat plugin declaration '
-    'with ios only', () {
-    const String manifest = '''
+      'with ios only', () {
+    const manifest = '''
 name: test
 flutter:
     plugin:
@@ -572,7 +586,7 @@ flutter:
   });
 
   testWithoutContext('FlutterManifest handles an invalid plugin declaration', () {
-    const String manifest = '''
+    const manifest = '''
 name: test
 flutter:
     plugin:
@@ -584,12 +598,11 @@ flutter:
     );
 
     expect(flutterManifest, null);
-    expect(logger.errorText,
-      contains('Expected "plugin" to be an object, but got null'));
+    expect(logger.errorText, contains('Expected "plugin" to be an object, but got null'));
   });
 
   testWithoutContext('FlutterManifest parses major.minor.patch+build version clause 1', () {
-    const String manifest = '''
+    const manifest = '''
 name: test
 version: 1.0.0+2
 dependencies:
@@ -603,15 +616,14 @@ flutter:
       logger: logger,
     );
 
-    expect(flutterManifest, matchesManifest(
-      appVersion: '1.0.0+2',
-      buildName: '1.0.0',
-      buildNumber: '2',
-    ));
+    expect(
+      flutterManifest,
+      matchesManifest(appVersion: '1.0.0+2', buildName: '1.0.0', buildNumber: '2'),
+    );
   });
 
   testWithoutContext('FlutterManifest parses major.minor.patch with no build version', () {
-    const String manifest = '''
+    const manifest = '''
 name: test
 version: 0.0.1
 dependencies:
@@ -625,14 +637,11 @@ flutter:
       logger: logger,
     );
 
-    expect(flutterManifest, matchesManifest(
-      appVersion:  '0.0.1',
-      buildName: '0.0.1',
-    ));
+    expect(flutterManifest, matchesManifest(appVersion: '0.0.1', buildName: '0.0.1'));
   });
 
   testWithoutContext('FlutterManifest parses major.minor.patch+build version clause 2', () {
-    const String manifest = '''
+    const manifest = '''
 name: test
 version: 1.0.0-beta+exp.sha.5114f85
 dependencies:
@@ -646,15 +655,18 @@ flutter:
       logger: logger,
     );
 
-    expect(flutterManifest, matchesManifest(
-      appVersion: '1.0.0-beta+exp.sha.5114f85',
-      buildName: '1.0.0-beta',
-      buildNumber: 'exp.sha.5114f85',
-    ));
+    expect(
+      flutterManifest,
+      matchesManifest(
+        appVersion: '1.0.0-beta+exp.sha.5114f85',
+        buildName: '1.0.0-beta',
+        buildNumber: 'exp.sha.5114f85',
+      ),
+    );
   });
 
   testWithoutContext('FlutterManifest parses major.minor+build version clause', () {
-    const String manifest = '''
+    const manifest = '''
 name: test
 version: 1.0.0+2
 dependencies:
@@ -668,15 +680,14 @@ flutter:
       logger: logger,
     );
 
-    expect(flutterManifest, matchesManifest(
-      appVersion: '1.0.0+2',
-      buildName: '1.0.0',
-      buildNumber: '2',
-    ));
+    expect(
+      flutterManifest,
+      matchesManifest(appVersion: '1.0.0+2', buildName: '1.0.0', buildNumber: '2'),
+    );
   });
 
   testWithoutContext('FlutterManifest parses empty version clause', () {
-    const String manifest = '''
+    const manifest = '''
 name: test
 version:
 dependencies:
@@ -694,7 +705,7 @@ flutter:
   });
 
   testWithoutContext('FlutterManifest parses no version clause', () {
-    const String manifest = '''
+    const manifest = '''
 name: test
 dependencies:
   flutter:
@@ -710,9 +721,9 @@ flutter:
     expect(flutterManifest, matchesManifest());
   });
 
-    // Regression test for https://github.com/flutter/flutter/issues/31764
+  // Regression test for https://github.com/flutter/flutter/issues/31764
   testWithoutContext('FlutterManifest returns proper error when font detail is malformed', () {
-    const String manifest = '''
+    const manifest = '''
 name: test
 dependencies:
   flutter:
@@ -730,12 +741,11 @@ flutter:
     );
 
     expect(flutterManifest, null);
-    expect(logger.errorText,
-      contains('Expected "fonts" to either be null or a list.'));
+    expect(logger.errorText, contains('Expected "fonts" to either be null or a list.'));
   });
 
   testWithoutContext('FlutterManifest ignores empty list of fonts', () {
-    const String manifest = '''
+    const manifest = '''
 name: test
 dependencies:
   flutter:
@@ -754,8 +764,8 @@ flutter:
   });
 
   testWithoutContext('FlutterManifest returns proper error when font detail is '
-    'not a list of maps', () {
-    const String manifest = '''
+      'not a list of maps', () {
+    const manifest = '''
 name: test
 dependencies:
   flutter:
@@ -773,13 +783,12 @@ flutter:
     );
 
     expect(flutterManifest, null);
-    expect(logger.errorText,
-      contains('Expected "fonts" to be a list of maps.'));
+    expect(logger.errorText, contains('Expected "fonts" to be a list of maps.'));
   });
 
   testWithoutContext('FlutterManifest returns proper error when font is a map '
-    'instead of a list', () {
-    const String manifest = '''
+      'instead of a list', () {
+    const manifest = '''
 name: test
 dependencies:
   flutter:
@@ -801,8 +810,8 @@ flutter:
   });
 
   testWithoutContext('FlutterManifest returns proper error when second font '
-    'family is invalid', () {
-    const String manifest = '''
+      'family is invalid', () {
+    const manifest = '''
 name: test
 dependencies:
   flutter:
@@ -826,8 +835,8 @@ flutter:
   });
 
   testWithoutContext('FlutterManifest returns proper error when flutter is a '
-    'list instead of a map', () {
-    const String manifest = '''
+      'list instead of a map', () {
+    const manifest = '''
 name: test
 dependencies:
   flutter:
@@ -842,7 +851,8 @@ flutter:
     );
 
     expect(flutterManifest, null);
-    expect(logger.errorText,
+    expect(
+      logger.errorText,
       contains(
         'Expected "flutter" section to be an object or null, but got '
         '[{uses-material-design: true}].',
@@ -851,7 +861,7 @@ flutter:
   });
 
   testWithoutContext('FlutterManifest can parse manifest on posix filesystem', () {
-    const String manifest = '''
+    const manifest = '''
 name: test
 dependencies:
   flutter:
@@ -862,7 +872,7 @@ flutter:
     fileSystem.file('pubspec.yaml').writeAsStringSync(manifest);
 
     final FlutterManifest flutterManifest = FlutterManifest.createFromPath(
-       'pubspec.yaml',
+      'pubspec.yaml',
       fileSystem: fileSystem,
       logger: logger,
     )!;
@@ -871,7 +881,7 @@ flutter:
   });
 
   testWithoutContext('FlutterManifest can parse manifest on windows filesystem', () {
-    const String manifest = '''
+    const manifest = '''
 name: test
 dependencies:
   flutter:
@@ -891,25 +901,30 @@ flutter:
     expect(flutterManifest.isEmpty, false);
   });
 
-  testWithoutContext('FlutterManifest getSupportedPlatforms return null if runs on legacy format', () {
-    const String manifest = '''
+  testWithoutContext(
+    'FlutterManifest getSupportedPlatforms return null if runs on legacy format',
+    () {
+      const manifest = '''
 name: test
 flutter:
   plugin:
     androidPackage: com.example
 ''';
 
-    final FlutterManifest flutterManifest = FlutterManifest.createFromString(
-      manifest,
-      logger: logger,
-    )!;
+      final FlutterManifest flutterManifest = FlutterManifest.createFromString(
+        manifest,
+        logger: logger,
+      )!;
 
-    expect(flutterManifest.isPlugin, true);
-    expect(flutterManifest.supportedPlatforms, null);
-  });
+      expect(flutterManifest.isPlugin, true);
+      expect(flutterManifest.supportedPlatforms, null);
+    },
+  );
 
-  testWithoutContext('FlutterManifest validSupportedPlatforms return null if the platform keys are not valid', () {
-    const String manifest = '''
+  testWithoutContext(
+    'FlutterManifest validSupportedPlatforms return null if the platform keys are not valid',
+    () {
+      const manifest = '''
 name: test
 flutter:
   plugin:
@@ -918,17 +933,18 @@ flutter:
         pluginClass: SomeClass
 ''';
 
-    final FlutterManifest flutterManifest = FlutterManifest.createFromString(
-      manifest,
-      logger: logger,
-    )!;
+      final FlutterManifest flutterManifest = FlutterManifest.createFromString(
+        manifest,
+        logger: logger,
+      )!;
 
-    expect(flutterManifest.isPlugin, true);
-    expect(flutterManifest.validSupportedPlatforms, null);
-  });
+      expect(flutterManifest.isPlugin, true);
+      expect(flutterManifest.validSupportedPlatforms, null);
+    },
+  );
 
   testWithoutContext('FlutterManifest validSupportedPlatforms only returns valid platforms', () {
-    const String manifest = '''
+    const manifest = '''
 name: test
 flutter:
   plugin:
@@ -946,14 +962,12 @@ flutter:
 
     expect(flutterManifest.isPlugin, true);
     final Map<String, dynamic> validSupportedPlatforms = flutterManifest.validSupportedPlatforms!;
-    expect(validSupportedPlatforms['ios'],
-                              <String, dynamic>{'pluginClass': 'SomeClass'});
-    expect(validSupportedPlatforms['some_platform'],
-                              isNull);
+    expect(validSupportedPlatforms['ios'], <String, dynamic>{'pluginClass': 'SomeClass'});
+    expect(validSupportedPlatforms['some_platform'], isNull);
   });
 
   testWithoutContext('FlutterManifest getSupportedPlatforms returns valid platforms.', () {
-    const String manifest = '''
+    const manifest = '''
 name: test
 flutter:
   plugin:
@@ -980,8 +994,8 @@ flutter:
   });
 
   testWithoutContext('FlutterManifest validates a platform section that is a list '
-    'instead of a map', () {
-    const String manifest = '''
+      'instead of a map', () {
+    const manifest = '''
 name: test
 flutter:
     plugin:
@@ -995,12 +1009,14 @@ flutter:
     );
 
     expect(flutterManifest, null);
-    expect(logger.errorText,
-      contains('flutter.plugin.platforms should be a map with the platform name as the key'));
+    expect(
+      logger.errorText,
+      contains('flutter.plugin.platforms should be a map with the platform name as the key'),
+    );
   });
 
-    testWithoutContext('FlutterManifest validates plugin format not support.', () {
-    const String manifest = '''
+  testWithoutContext('FlutterManifest validates plugin format not support.', () {
+    const manifest = '''
 name: test
 flutter:
   plugin:
@@ -1017,12 +1033,14 @@ flutter:
     );
 
     expect(flutterManifest, null);
-    expect(logger.errorText,
-      contains('Cannot find the `flutter.plugin.platforms` key in the `pubspec.yaml` file. '));
+    expect(
+      logger.errorText,
+      contains('Cannot find the `flutter.plugin.platforms` key in the `pubspec.yaml` file. '),
+    );
   });
 
   testWithoutContext('FlutterManifest handles empty licenses list', () async {
-    const String manifest = '''
+    const manifest = '''
 name: test
 dependencies:
   flutter:
@@ -1041,7 +1059,7 @@ flutter:
   });
 
   testWithoutContext('FlutterManifest can specify additional LICENSE files', () async {
-    const String manifest = '''
+    const manifest = '''
 name: test
 dependencies:
   flutter:
@@ -1060,7 +1078,7 @@ flutter:
   });
 
   testWithoutContext('FlutterManifest can validate incorrect licenses key', () async {
-    const String manifest = '''
+    const manifest = '''
 name: test
 dependencies:
   flutter:
@@ -1075,11 +1093,14 @@ flutter:
     );
 
     expect(flutterManifest, null);
-    expect(logger.errorText, 'Expected "licenses" to be a list of files, but got foo.txt (String).\n');
+    expect(
+      logger.errorText,
+      'Expected "licenses" to be a list of files, but got foo.txt (String).\n',
+    );
   });
 
   testWithoutContext('FlutterManifest validates individual list items', () async {
-    const String manifest = '''
+    const manifest = '''
 name: test
 dependencies:
   flutter:
@@ -1096,12 +1117,15 @@ flutter:
     );
 
     expect(flutterManifest, null);
-    expect(logger.errorText, 'Expected "licenses" to be a list of files, but '
-      'element at index 1 was a YamlMap.\n');
+    expect(
+      logger.errorText,
+      'Expected "licenses" to be a list of files, but '
+      'element at index 1 was a YamlMap.\n',
+    );
   });
 
   testWithoutContext('FlutterManifest parses single deferred components', () async {
-    const String manifest = '''
+    const manifest = '''
 name: test
 dependencies:
   flutter:
@@ -1131,7 +1155,7 @@ flutter:
   });
 
   testWithoutContext('FlutterManifest parses multiple deferred components', () async {
-    const String manifest = '''
+    const manifest = '''
 name: test
 dependencies:
   flutter:
@@ -1174,7 +1198,7 @@ flutter:
   });
 
   testWithoutContext('FlutterManifest parses empty deferred components', () async {
-    const String manifest = '''
+    const manifest = '''
 name: test
 dependencies:
   flutter:
@@ -1193,7 +1217,7 @@ flutter:
   });
 
   testWithoutContext('FlutterManifest deferred component requires name', () async {
-    const String manifest = '''
+    const manifest = '''
 name: test
 dependencies:
   flutter:
@@ -1210,11 +1234,14 @@ flutter:
     );
 
     expect(flutterManifest, null);
-    expect(logger.errorText, 'Expected the 0 element in "deferred-components" to have required key "name" of type String\n');
+    expect(
+      logger.errorText,
+      'Expected the 0 element in "deferred-components" to have required key "name" of type String\n',
+    );
   });
 
   testWithoutContext('FlutterManifest deferred component is list', () async {
-    const String manifest = '''
+    const manifest = '''
 name: test
 dependencies:
   flutter:
@@ -1229,11 +1256,14 @@ flutter:
     );
 
     expect(flutterManifest, null);
-    expect(logger.errorText, 'Expected "deferred-components" to be a list, but got blah (String).\n');
+    expect(
+      logger.errorText,
+      'Expected "deferred-components" to be a list, but got blah (String).\n',
+    );
   });
 
   testWithoutContext('FlutterManifest deferred component libraries is list', () async {
-    const String manifest = '''
+    const manifest = '''
 name: test
 dependencies:
   flutter:
@@ -1250,13 +1280,16 @@ flutter:
     );
 
     expect(flutterManifest, null);
-    expect(logger.errorText, 'Expected "libraries" key in the element at '
+    expect(
+      logger.errorText,
+      'Expected "libraries" key in the element at '
       'index 0 of "deferred-components" to be a list of String, but '
-      'got blah (String).\n');
+      'got blah (String).\n',
+    );
   });
 
   testWithoutContext('FlutterManifest deferred component libraries is string', () async {
-    const String manifest = '''
+    const manifest = '''
 name: test
 dependencies:
   flutter:
@@ -1274,13 +1307,16 @@ flutter:
     );
 
     expect(flutterManifest, null);
-    expect(logger.errorText, 'Expected "libraries" key in the element at '
+    expect(
+      logger.errorText,
+      'Expected "libraries" key in the element at '
       'index 0 of "deferred-components" to be a list of String, but '
-      'element at index 0 was a YamlMap.\n');
+      'element at index 0 was a YamlMap.\n',
+    );
   });
 
   testWithoutContext('FlutterManifest deferred component assets is string', () async {
-    const String manifest = '''
+    const manifest = '''
 name: test
 dependencies:
   flutter:
@@ -1298,11 +1334,14 @@ flutter:
     );
 
     expect(flutterManifest, null);
-    expect(logger.errorText, 'Asset manifest entry is malformed. Expected asset entry to be either a string or a map containing a "path" entry. Got Null instead.\n');
+    expect(
+      logger.errorText,
+      'Asset manifest entry is malformed. Expected asset entry to be either a string or a map containing a "path" entry. Got Null instead.\n',
+    );
   });
 
   testWithoutContext('FlutterManifest deferred component multiple assets is string', () async {
-    const String manifest = '''
+    const manifest = '''
 name: test
 dependencies:
   flutter:
@@ -1322,11 +1361,14 @@ flutter:
     );
 
     expect(flutterManifest, null);
-    expect(logger.errorText, 'Asset manifest entry is malformed. Expected asset entry to be either a string or a map containing a "path" entry. Got Null instead.\n');
+    expect(
+      logger.errorText,
+      'Asset manifest entry is malformed. Expected asset entry to be either a string or a map containing a "path" entry. Got Null instead.\n',
+    );
   });
 
   testWithoutContext('FlutterManifest multiple deferred components assets is string', () async {
-    const String manifest = '''
+    const manifest = '''
 name: test
 dependencies:
   flutter:
@@ -1349,11 +1391,14 @@ flutter:
     );
 
     expect(flutterManifest, null);
-    expect(logger.errorText, 'Asset manifest entry is malformed. Expected asset entry to be either a string or a map containing a "path" entry. Got Null instead.\n');
+    expect(
+      logger.errorText,
+      'Asset manifest entry is malformed. Expected asset entry to be either a string or a map containing a "path" entry. Got Null instead.\n',
+    );
   });
 
   testWithoutContext('FlutterManifest deferred component assets is list', () async {
-    const String manifest = '''
+    const manifest = '''
 name: test
 dependencies:
   flutter:
@@ -1374,7 +1419,7 @@ flutter:
   });
 
   testWithoutContext('FlutterManifest parses asset-only deferred components', () async {
-    const String manifest = '''
+    const manifest = '''
 name: test
 dependencies:
   flutter:
@@ -1405,7 +1450,7 @@ flutter:
   });
 
   testWithoutContext('FlutterManifest can parse empty dependencies', () async {
-    const String manifest = '''
+    const manifest = '''
 name: test
 ''';
     final FlutterManifest? flutterManifest = FlutterManifest.createFromString(
@@ -1417,8 +1462,10 @@ name: test
     expect(flutterManifest!.dependencies, isEmpty);
   });
 
-  testWithoutContext('FlutterManifest knows if Swift Package Manager is disabled', () async {
-    const String manifest = '''
+  testWithoutContext(
+    'FlutterManifest provides a guided error to migrate disable-swift-package-manager',
+    () async {
+      const manifest = '''
 name: test
 dependencies:
   flutter:
@@ -1426,32 +1473,20 @@ dependencies:
 flutter:
   disable-swift-package-manager: true
 ''';
-    final FlutterManifest flutterManifest = FlutterManifest.createFromString(
-      manifest,
-      logger: logger,
-    )!;
-
-    expect(flutterManifest.disabledSwiftPackageManager, true);
-  });
-
-  testWithoutContext('FlutterManifest does not disable Swift Package Manager if missing', () async {
-    const String manifest = '''
-name: test
-dependencies:
-  flutter:
-    sdk: flutter
-flutter:
-''';
-    final FlutterManifest flutterManifest = FlutterManifest.createFromString(
-      manifest,
-      logger: logger,
-    )!;
-
-    expect(flutterManifest.disabledSwiftPackageManager, false);
-  });
+      final FlutterManifest? flutterManifest = FlutterManifest.createFromString(
+        manifest,
+        logger: logger,
+      );
+      expect(flutterManifest, isNull);
+      expect(
+        logger.errorText,
+        contains('The "disable-swift-package-manager" configuration has moved'),
+      );
+    },
+  );
 
   testWithoutContext('FlutterManifest can parse default flavor', () async {
-    const String manifest = '''
+    const manifest = '''
 name: test
 flutter:
     default-flavor: prod
@@ -1466,7 +1501,7 @@ flutter:
   });
 
   testWithoutContext('FlutterManifest fails on invalid default flavor', () async {
-    const String manifest = '''
+    const manifest = '''
 name: test
 flutter:
     default-flavor: 3
@@ -1480,28 +1515,137 @@ flutter:
     expect(flutterManifest, null);
     expect(logger.errorText, 'Expected "default-flavor" to be a string, but got 3 (int).\n');
   });
+
+  testWithoutContext('FlutterManifest.copyWith generates a valid manifest', () async {
+    const manifest = '''
+name: test
+dependencies:
+  flutter:
+    sdk: flutter
+flutter:
+  uses-material-design: true
+''';
+    final FlutterManifest flutterManifest = FlutterManifest.createFromString(
+      manifest,
+      logger: logger,
+    )!;
+
+    final FlutterManifest updatedManifest = flutterManifest.copyWith(
+      logger: logger,
+      assets: <AssetsEntry>[
+        AssetsEntry(
+          uri: Uri(path: 'foo'),
+          flavors: const <String>{'flavor'},
+          transformers: const <AssetTransformerEntry>[
+            AssetTransformerEntry(package: 'package:foo', args: <String>['arg']),
+          ],
+        ),
+      ],
+      fonts: <Font>[
+        Font('fontFamily', <FontAsset>[
+          FontAsset(Uri(path: 'assetUri'), weight: 100, style: 'normal'),
+        ]),
+      ],
+      shaders: <Uri>[Uri(path: 'shaderUri')],
+      deferredComponents: <DeferredComponent>[
+        DeferredComponent(
+          name: 'deferredComponent',
+          libraries: const <String>['deferredComponentLibrary'],
+          assets: <AssetsEntry>[
+            AssetsEntry(
+              uri: Uri(path: 'deferredComponentUri'),
+              flavors: const <String>{'deferredComponentFlavor'},
+              transformers: const <AssetTransformerEntry>[
+                AssetTransformerEntry(
+                  package: 'package:deferredComponent',
+                  args: <String>['deferredComponentArg'],
+                ),
+              ],
+            ),
+          ],
+        ),
+      ],
+    );
+
+    expect(encodeYamlAsString(updatedManifest.toYaml()), '''
+name: test
+dependencies:
+  flutter:
+    sdk: flutter
+flutter:
+  uses-material-design: true
+  assets:
+    - path: foo
+      flavors:
+        - flavor
+      transformers:
+        - package: package:foo
+          args:
+            - arg
+  fonts:
+    - family: fontFamily
+      fonts:
+        - weight: 100
+          style: normal
+          asset: assetUri
+  shaders:
+    - shaderUri
+  deferred-components:
+    - name: deferredComponent
+      libraries:
+        - deferredComponentLibrary
+      assets:
+        - path: deferredComponentUri
+          flavors:
+            - deferredComponentFlavor
+          transformers:
+            - package: package:deferredComponent
+              args:
+                - deferredComponentArg''');
+  });
+
+  testWithoutContext('FlutterManifest can parse workspace', () async {
+    const manifest = '''
+name: test
+workspace:
+- pkgs/bar
+- pkgs/foo
+''';
+    final FlutterManifest? flutterManifest = FlutterManifest.createFromString(
+      manifest,
+      logger: BufferLogger.test(),
+    );
+
+    expect(flutterManifest, isNotNull);
+    expect(flutterManifest!.workspace, <String>['pkgs/bar', 'pkgs/foo']);
+  });
+
+  testWithoutContext('FlutterManifest can parse empty workspace', () async {
+    const manifest = '''
+name: test
+''';
+    final FlutterManifest? flutterManifest = FlutterManifest.createFromString(
+      manifest,
+      logger: BufferLogger.test(),
+    );
+
+    expect(flutterManifest, isNotNull);
+    expect(flutterManifest!.workspace, isEmpty);
+  });
 }
 
-Matcher matchesManifest({
-  String? appVersion,
-  String? buildName,
-  String? buildNumber,
-}) {
+Matcher matchesManifest({String? appVersion, String? buildName, String? buildNumber}) {
   return isA<FlutterManifest>()
-    .having((FlutterManifest manifest) => manifest.appVersion, 'appVersion', appVersion)
-    .having((FlutterManifest manifest) => manifest.buildName, 'buildName', buildName)
-    .having((FlutterManifest manifest) => manifest.buildNumber, 'buildNumber', buildNumber);
+      .having((FlutterManifest manifest) => manifest.appVersion, 'appVersion', appVersion)
+      .having((FlutterManifest manifest) => manifest.buildName, 'buildName', buildName)
+      .having((FlutterManifest manifest) => manifest.buildNumber, 'buildNumber', buildNumber);
 }
 
-Matcher matchesFontAsset({
-  required Uri assetUri,
-  int? weight,
-  String? style,
-}) {
+Matcher matchesFontAsset({required Uri assetUri, int? weight, String? style}) {
   return isA<FontAsset>()
-    .having((FontAsset fontAsset) => fontAsset.assetUri, 'assetUri', assetUri)
-    .having((FontAsset fontAsset) => fontAsset.weight, 'weight', weight)
-    .having((FontAsset fontAsset) => fontAsset.style, 'style', style);
+      .having((FontAsset fontAsset) => fontAsset.assetUri, 'assetUri', assetUri)
+      .having((FontAsset fontAsset) => fontAsset.weight, 'weight', weight)
+      .having((FontAsset fontAsset) => fontAsset.style, 'style', style);
 }
 
 Matcher matchesFont({
@@ -1510,7 +1654,7 @@ Matcher matchesFont({
   required List<Matcher> fontAssets,
 }) {
   return isA<Font>()
-    .having((Font font) => font.descriptor, 'descriptor', descriptor)
-    .having((Font font) => font.familyName, 'familyName', familyName)
-    .having((Font font) => font.fontAssets, 'fontAssets', containsAll(fontAssets));
+      .having((Font font) => font.descriptor, 'descriptor', descriptor)
+      .having((Font font) => font.familyName, 'familyName', familyName)
+      .having((Font font) => font.fontAssets, 'fontAssets', containsAll(fontAssets));
 }
