@@ -320,7 +320,6 @@ void main() {
       'hotReload': true,
       'hotRestart': true,
       'screenshot': false,
-      'fastStart': false,
       'flutterExit': true,
       'hardwareRendering': true,
       'startPaused': true,
@@ -339,7 +338,6 @@ void main() {
       'hotReload': true,
       'hotRestart': true,
       'screenshot': false,
-      'fastStart': false,
       'flutterExit': true,
       'hardwareRendering': true,
       'startPaused': true,
@@ -663,6 +661,7 @@ void main() {
         'deviceId': 'test_id',
         'vmServiceUri': 'http://127.0.0.1:200/fake',
         'disableServiceAuthCodes': true,
+        'enableDevTools': false,
       });
 
       serverDaemonConnection.sendResponse(startMessage.data['id']!, const <String, Object?>{
@@ -722,6 +721,7 @@ void main() {
           'deviceId': 'test_id',
           'vmServiceUri': 'http://127.0.0.1:200/fake',
           'disableServiceAuthCodes': true,
+          'enableDevTools': false,
         });
 
         serverDaemonConnection.sendResponse(startMessage.data['id']!, <String, Object?>{
@@ -824,6 +824,7 @@ void main() {
           'deviceId': 'test_id',
           'vmServiceUri': 'http://127.0.0.1:200/fake',
           'disableServiceAuthCodes': true,
+          'enableDevTools': false,
         });
 
         serverDaemonConnection.sendErrorResponse(
@@ -1245,6 +1246,9 @@ class FakeDartDevelopmentService extends Fake implements DartDevelopmentService
 
   @override
   Future<void> shutdown() async => shutdownCalled = true;
+
+  @override
+  Future<void> invokeServiceExtensions(FlutterDevice? device) async {}
 }
 
 class FakePrebuiltApplicationPackage extends Fake implements PrebuiltApplicationPackage {
