@@ -10,6 +10,7 @@
   'windows': Skip('https://github.com/dart-lang/webdev/issues/711'),
   'linux': Skip('https://github.com/dart-lang/webdev/issues/2114'),
 })
+library;
 
 import 'package:dwds/src/connections/debug_connection.dart';
 import 'package:dwds/src/handlers/injector.dart';
@@ -37,7 +38,7 @@ void main() async {
   final provider = TestSdkConfigurationProvider();
   tearDownAll(provider.dispose);
 
-  final context = TestContext(TestProject.testWithSoundNullSafety, provider);
+  final context = TestContext(TestProject.test, provider);
 
   Future<void> waitForDartDevToolsWithRetry({
     int retryCount = 6,
@@ -56,15 +57,14 @@ void main() async {
     );
   }
 
-  for (var useSse in [true, false]) {
+  for (final useSse in [true, false]) {
     group(useSse ? 'SSE' : 'WebSockets', () {
       group('Without encoding', () {
         setUp(() async {
           await context.setUp(
-            debugSettings: TestDebugSettings.withDevTools(context).copyWith(
-              enableDebugExtension: true,
-              useSse: useSse,
-            ),
+            debugSettings: TestDebugSettings.withDevToolsLaunch(
+              context,
+            ).copyWith(enableDebugExtension: true, useSse: useSse),
           );
           await context.extensionConnection.sendCommand('Runtime.evaluate', {
             'expression': 'fakeClick()',
@@ -88,7 +88,7 @@ void main() async {
         });
 
         test('can close DevTools and relaunch', () async {
-          for (var window in await context.webDriver.windows.toList()) {
+          for (final window in await context.webDriver.windows.toList()) {
             await context.webDriver.driver.switchTo.window(window);
             if (await context.webDriver.title == 'Dart DevTools') {
               await window.close();
@@ -125,13 +125,13 @@ void main() async {
       group('With a sharded Dart app', () {
         setUp(() async {
           await context.setUp(
-            debugSettings: TestDebugSettings.withDevTools(context).copyWith(
-              enableDebugExtension: true,
-              useSse: useSse,
-            ),
+            debugSettings: TestDebugSettings.withDevToolsLaunch(
+              context,
+            ).copyWith(enableDebugExtension: true, useSse: useSse),
+          );
+          final htmlTag = await context.webDriver.findElement(
+            const By.tagName('html'),
           );
-          final htmlTag =
-              await context.webDriver.findElement(const By.tagName('html'));
 
           await context.webDriver.execute(
             "arguments[0].setAttribute('data-multiple-dart-apps', 'true');",
@@ -148,8 +148,9 @@ void main() async {
             'expression': 'fakeClick()',
           });
           // Wait for the alert to open.
-          final alert =
-              await retryFn<Alert>(() => context.webDriver.switchTo.alert);
+          final alert = await retryFn<Alert>(
+            () => context.webDriver.switchTo.alert,
+          );
           expect(alert, isNotNull);
         });
       });
@@ -160,13 +161,13 @@ void main() async {
       group('With an internal Dart app', () {
         setUp(() async {
           await context.setUp(
-            debugSettings: TestDebugSettings.withDevTools(context).copyWith(
-              enableDebugExtension: true,
-              useSse: false,
-            ),
+            debugSettings: TestDebugSettings.withDevToolsLaunch(
+              context,
+            ).copyWith(enableDebugExtension: true, useSse: false),
+          );
+          final htmlTag = await context.webDriver.findElement(
+            const By.tagName('html'),
           );
-          final htmlTag =
-              await context.webDriver.findElement(const By.tagName('html'));
 
           await context.webDriver.execute(
             "arguments[0].setAttribute('data-ddr-dart-app', 'true');",
@@ -191,7 +192,7 @@ void main() async {
         });
 
         test('can close DevTools and relaunch', () async {
-          for (var window in await context.webDriver.windows.toList()) {
+          for (final window in await context.webDriver.windows.toList()) {
             await context.webDriver.driver.switchTo.window(window);
             if (await context.webDriver.title == 'Dart DevTools') {
               await window.close();
@@ -230,10 +231,13 @@ void main() async {
   group('With encoding', () {
     setUp(() async {
       await context.setUp(
-        debugSettings: TestDebugSettings.noDevTools().copyWith(
+        debugSettings: TestDebugSettings.noDevToolsLaunch().copyWith(
           enableDebugExtension: true,
-          urlEncoder: (url) async =>
-              url.endsWith(r'/$debug') ? 'http://some-encoded-url:8081/' : url,
+          urlEncoder:
+              (url) async =>
+                  url.endsWith(r'/$debug')
+                      ? 'http://some-encoded-url:8081/'
+                      : url,
         ),
       );
     });
@@ -259,8 +263,9 @@ void main() async {
     setUp(() async {
       await context.setUp(
         appMetadata: TestAppMetadata.externalApp().copyWith(hostname: 'any'),
-        debugSettings:
-            TestDebugSettings.noDevTools().copyWith(enableDebugExtension: true),
+        debugSettings: TestDebugSettings.noDevToolsLaunch().copyWith(
+          enableDebugExtension: true,
+        ),
       );
     });
 
@@ -275,8 +280,9 @@ void main() async {
         ),
       );
       expect(result.body.contains('dartExtensionUri'), isTrue);
-      final extensionUri =
-          Uri.parse(uriPattern.firstMatch(result.body)!.group(1)!);
+      final extensionUri = Uri.parse(
+        uriPattern.firstMatch(result.body)!.group(1)!,
+      );
       expect(
         extensionUri.host,
         anyOf(
