@@ -2,13 +2,18 @@
 // for details. All rights reserved. Use of this source code is governed by a
 // BSD-style license that can be found in the LICENSE file.
 
+import 'dart:async';
+import 'dart:io';
 import 'dart:typed_data';
 
 import 'package:analyzer/file_system/file_system.dart';
-import 'package:analyzer/src/generated/source.dart';
+import 'package:analyzer/file_system/physical_file_system.dart';
+import 'package:analyzer/source/file_source.dart';
+import 'package:analyzer/source/source.dart';
 import 'package:path/path.dart' as path;
 import 'package:test/test.dart';
 import 'package:test_reflective_loader/test_reflective_loader.dart';
+import 'package:watcher/watcher.dart' show ChangeType;
 
 final isFile = TypeMatcher<File>();
 final isFileSystemException = TypeMatcher<FileSystemException>();
@@ -16,6 +21,11 @@ final isFolder = TypeMatcher<Folder>();
 
 final throwsFileSystemException = throwsA(isFileSystemException);
 
+typedef _WatcherChanges = ({
+  List<ChangeType> changes,
+  Future<void> Function() cancel,
+});
+
 abstract class FileSystemTestSupport {
   /// The content used for the file at the [defaultFilePath] if it is created
   /// and no other content is provided.
@@ -38,10 +48,6 @@ abstract class FileSystemTestSupport {
   /// to work.
   String get tempPath;
 
-  /// Create a link from [path] to [target].
-  /// The [target] does not have to exist, can be create later, or not at all.
-  void createLink({required String path, required String target});
-
   /// Return a file accessed through the resource provider. If [exists] is
   /// `true` then the returned file will exist, otherwise it won't. If [content]
   /// is provided then the file will have the given content, otherwise it will
@@ -56,15 +62,54 @@ abstract class FileSystemTestSupport {
   /// otherwise the folder will have the [defaultFolderPath].
   Folder getFolder({required bool exists, String? folderPath});
 
+  /// Return a link accessed through the resource provider. If [target] is
+  /// supplied then the returned link will exist and point to [target],
+  /// otherwise it won't.
+  Link getLink({required String linkPath, String? target});
+
   /// Return a file path composed of the provided parts as defined by the
   /// current path context.
-  String join(String part1,
-          [String? part2,
-          String? part3,
-          String? part4,
-          String? part5,
-          String? part6]) =>
-      provider.pathContext.join(part1, part2, part3, part4, part5, part6);
+  String join(
+    String part1, [
+    String? part2,
+    String? part3,
+    String? part4,
+    String? part5,
+    String? part6,
+  ]) => provider.pathContext.join(part1, part2, part3, part4, part5, part6);
+
+  /// Subscribes to [watcher], waits for it to become ready, and returns
+  /// a record containing a list of events received (which updates as events
+  /// arrive) and a function to cancel.
+  Future<_WatcherChanges> _subscribeToWatcher(ResourceWatcher watcher) async {
+    var changes = <ChangeType>[];
+    var subscription = watcher.changes.listen(
+      (event) => changes.add(event.type),
+    );
+
+    await watcher.ready;
+
+    return (changes: changes, cancel: subscription.cancel);
+  }
+
+  /// Waits up to [maxDuration] for [condition] to return `true`.
+  ///
+  /// Throws if condition is not `true` before the time expires.
+  Future<void> _waitFor(
+    FutureOr<bool> Function() condition, [
+    // Set the default max high enough to ensure no flakes on slow bots. We
+    // check periodically and will exit early if the condition is met.
+    Duration maxDuration = const Duration(seconds: 5),
+  ]) async {
+    var endTime = DateTime.now().add(maxDuration);
+    while (DateTime.now().isBefore(endTime)) {
+      if (await condition()) {
+        return;
+      }
+      await pumpEventQueue(times: 1000);
+    }
+    throw 'Condition was not true within $maxDuration';
+  }
 }
 
 /// Unlike most test mixins, this mixin defines some abstract test methods.
@@ -75,7 +120,7 @@ abstract class FileSystemTestSupport {
 mixin FileTestMixin implements FileSystemTestSupport {
   @failingTest
   test_changes() {
-    // TODO(brianwilkerson) Implement this.
+    // TODO(brianwilkerson): Implement this.
     fail('Not tested');
   }
 
@@ -100,7 +145,7 @@ mixin FileTestMixin implements FileSystemTestSupport {
   test_createSource() {
     File file = getFile(exists: true);
 
-    Source source = file.createSource();
+    Source source = FileSource(file);
     expect(source, isNotNull);
     expect(source.fullName, defaultFilePath);
     expect(source.uri, Uri.file(defaultFilePath));
@@ -153,7 +198,7 @@ mixin FileTestMixin implements FileSystemTestSupport {
     var a_path = join(tempPath, 'a.dart');
     var b_path = join(tempPath, 'b.dart');
 
-    createLink(path: b_path, target: a_path);
+    getLink(linkPath: b_path, target: a_path);
     getFile(exists: true, filePath: a_path);
 
     var a = provider.getFile(a_path);
@@ -169,7 +214,7 @@ mixin FileTestMixin implements FileSystemTestSupport {
     var a_path = join(tempPath, 'a.dart');
     var b_path = join(tempPath, 'b.dart');
 
-    createLink(path: b_path, target: a_path);
+    getLink(linkPath: b_path, target: a_path);
 
     var a = provider.getFile(a_path);
     var b = provider.getFile(b_path);
@@ -229,6 +274,77 @@ mixin FileTestMixin implements FileSystemTestSupport {
     expect(() => file.modificationStamp, throwsA(isFileSystemException));
   }
 
+  /// Test that we can reuse a [ResourceWatcher] to create a second subscription
+  /// and cancel it at a different time.
+  test_multipleWatchers_staggeredCancel() async {
+    var filePath = path.join(tempPath, 'foo');
+    var file = getFile(filePath: filePath, exists: true);
+
+    // On Windows, package:watcher may miss modification events for files that
+    // were created just before we started watching (see
+    // https://github.com/dart-lang/watcher/issues/159), so add an artificial
+    // delay there to ensure we don't miss events until that issue is resolved.
+    if (provider is PhysicalResourceProvider && Platform.isWindows) {
+      await Future<void>.delayed(const Duration(seconds: 1));
+    }
+
+    var resource = provider.getResource(filePath);
+    var watcher = resource.watch();
+
+    var watch1 = await _subscribeToWatcher(watcher);
+    var watch2 = await _subscribeToWatcher(watcher);
+    file.writeAsStringSync('first');
+    await _waitFor(
+      () => watch1.changes.isNotEmpty && watch2.changes.isNotEmpty,
+    );
+
+    // Cancel the second watcher before causing the second event.
+    await watch2.cancel();
+
+    file.writeAsStringSync('second');
+    await _waitFor(() => watch1.changes.length >= 2);
+
+    await watch1.cancel();
+
+    // Watcher 1 should have both events, and watcher 2 should have only the
+    // first one.
+    expect(watch1.changes.length, 2);
+    expect(watch2.changes.length, 1);
+  }
+
+  /// Test that we can reuse a [ResourceWatcher] to create a second subscription
+  /// at a different time.
+  test_multipleWatchers_staggeredSubscribe() async {
+    var filePath = path.join(tempPath, 'foo');
+    var file = getFile(filePath: filePath, exists: true);
+
+    // On Windows, package:watcher may miss modification events for files that
+    // were created just before we started watching (see
+    // https://github.com/dart-lang/watcher/issues/159), so add an artificial
+    // delay there to ensure we don't miss events until that issue is resolved.
+    if (provider is PhysicalResourceProvider && Platform.isWindows) {
+      await Future<void>.delayed(const Duration(seconds: 1));
+    }
+
+    var resource = provider.getResource(filePath);
+    var watcher = resource.watch();
+
+    var watch1 = await _subscribeToWatcher(watcher);
+    file.writeAsStringSync('first');
+    await _waitFor(() => watch1.changes.isNotEmpty);
+
+    var watch2 = await _subscribeToWatcher(watcher);
+    file.writeAsStringSync('second');
+    await _waitFor(() => watch2.changes.isNotEmpty);
+
+    await Future.wait([watch1.cancel(), watch2.cancel()]);
+
+    // Watcher 1 should have both events, and watcher 2 should have only the
+    // second.
+    expect(watch1.changes.length, 2);
+    expect(watch2.changes.length, 1);
+  }
+
   test_parent2() {
     File file = getFile(exists: true);
 
@@ -316,7 +432,7 @@ mixin FileTestMixin implements FileSystemTestSupport {
     var b_path = join(tempPath, 'bbb', 'b.dart');
 
     getFile(exists: true, filePath: a_path);
-    createLink(path: b_path, target: a_path);
+    getLink(linkPath: b_path, target: a_path);
 
     var resolved = provider.getFile(b_path).resolveSymbolicLinksSync();
     expect(resolved.path, a_path);
@@ -330,8 +446,8 @@ mixin FileTestMixin implements FileSystemTestSupport {
     var c = join(tempPath, 'ccc', 'c.dart');
 
     getFile(exists: true, filePath: a);
-    createLink(path: b, target: a);
-    createLink(path: c, target: b);
+    getLink(linkPath: b, target: a);
+    getLink(linkPath: c, target: b);
 
     var resolved = provider.getFile(c).resolveSymbolicLinksSync();
     expect(resolved.path, a);
@@ -343,7 +459,7 @@ mixin FileTestMixin implements FileSystemTestSupport {
     var a = join(tempPath, 'a.dart');
     var b = join(tempPath, 'b.dart');
 
-    createLink(path: b, target: a);
+    getLink(linkPath: b, target: a);
 
     expect(() {
       provider.getFile(b).resolveSymbolicLinksSync();
@@ -414,8 +530,10 @@ mixin FolderTestMixin implements FileSystemTestSupport {
     Folder folder = getFolder(exists: false);
     String path2 = join(tempPath, 'folder2');
 
-    expect(folder.canonicalizePath(join(path2, '.', 'baz')),
-        equals(join(path2, 'baz')));
+    expect(
+      folder.canonicalizePath(join(path2, '.', 'baz')),
+      equals(join(path2, 'baz')),
+    );
   }
 
   test_canonicalizePath_absolute_dotDot() {
@@ -424,21 +542,27 @@ mixin FolderTestMixin implements FileSystemTestSupport {
     String path3 = join(tempPath, 'folder3');
 
     expect(
-        folder.canonicalizePath(join(path2, '..', 'folder3')), equals(path3));
+      folder.canonicalizePath(join(path2, '..', 'folder3')),
+      equals(path3),
+    );
   }
 
   test_canonicalizePath_relative() {
     Folder folder = getFolder(exists: false);
 
     expect(
-        folder.canonicalizePath('baz'), equals(join(defaultFolderPath, 'baz')));
+      folder.canonicalizePath('baz'),
+      equals(join(defaultFolderPath, 'baz')),
+    );
   }
 
   test_canonicalizePath_relative_dot() {
     Folder folder = getFolder(exists: false);
 
-    expect(folder.canonicalizePath(join('.', 'baz')),
-        equals(join(defaultFolderPath, 'baz')));
+    expect(
+      folder.canonicalizePath(join('.', 'baz')),
+      equals(join(defaultFolderPath, 'baz')),
+    );
   }
 
   test_canonicalizePath_relative_dotDot() {
@@ -450,7 +574,7 @@ mixin FolderTestMixin implements FileSystemTestSupport {
 
   @failingTest
   test_changes() {
-    // TODO(brianwilkerson) Implement this.
+    // TODO(brianwilkerson): Implement this.
     fail('Not tested');
   }
 
@@ -479,22 +603,30 @@ mixin FolderTestMixin implements FileSystemTestSupport {
   }
 
   test_copyTo() {
-    Folder source =
-        getFolder(exists: true, folderPath: join(tempPath, 'source'));
+    Folder source = getFolder(
+      exists: true,
+      folderPath: join(tempPath, 'source'),
+    );
     String sourcePath = source.path;
-    Folder subdirectory =
-        getFolder(exists: true, folderPath: join(sourcePath, 'subdir'));
+    Folder subdirectory = getFolder(
+      exists: true,
+      folderPath: join(sourcePath, 'subdir'),
+    );
     String subdirectoryPath = subdirectory.path;
     getFile(
-        exists: true,
-        content: 'file1',
-        filePath: join(sourcePath, 'file1.txt'));
+      exists: true,
+      content: 'file1',
+      filePath: join(sourcePath, 'file1.txt'),
+    );
     getFile(
-        exists: true,
-        content: 'file2',
-        filePath: join(subdirectoryPath, 'file2.txt'));
-    Folder destination =
-        getFolder(exists: true, folderPath: join(tempPath, 'destination'));
+      exists: true,
+      content: 'file2',
+      filePath: join(subdirectoryPath, 'file2.txt'),
+    );
+    Folder destination = getFolder(
+      exists: true,
+      folderPath: join(tempPath, 'destination'),
+    );
 
     Folder copy = source.copyTo(destination);
     expect(copy.parent, destination);
@@ -510,8 +642,10 @@ mixin FolderTestMixin implements FileSystemTestSupport {
   }
 
   test_delete() {
-    File file =
-        getFile(exists: true, filePath: join(defaultFolderPath, 'myFile'));
+    File file = getFile(
+      exists: true,
+      filePath: join(defaultFolderPath, 'myFile'),
+    );
     var folder = file.parent;
     expect(folder.exists, isTrue);
     expect(file.exists, isTrue);
@@ -522,10 +656,14 @@ mixin FolderTestMixin implements FileSystemTestSupport {
   }
 
   test_equals_differentPaths() {
-    Folder folder1 =
-        getFolder(exists: true, folderPath: join(tempPath, 'folder1'));
-    Folder folder2 =
-        getFolder(exists: true, folderPath: join(tempPath, 'folder2'));
+    Folder folder1 = getFolder(
+      exists: true,
+      folderPath: join(tempPath, 'folder1'),
+    );
+    Folder folder2 = getFolder(
+      exists: true,
+      folderPath: join(tempPath, 'folder2'),
+    );
 
     expect(folder1 == folder2, isFalse);
   }
@@ -543,7 +681,7 @@ mixin FolderTestMixin implements FileSystemTestSupport {
     var foo_path = join(tempPath, 'foo');
     var bar_path = join(tempPath, 'bar');
 
-    createLink(path: bar_path, target: foo_path);
+    getLink(linkPath: bar_path, target: foo_path);
     getFolder(exists: true, folderPath: foo_path);
 
     var foo = provider.getFolder(foo_path);
@@ -559,7 +697,7 @@ mixin FolderTestMixin implements FileSystemTestSupport {
     var foo_path = join(tempPath, 'foo');
     var bar_path = join(tempPath, 'bar');
 
-    createLink(path: bar_path, target: foo_path);
+    getLink(linkPath: bar_path, target: foo_path);
 
     var foo = provider.getFolder(foo_path);
     var bar = provider.getFolder(bar_path);
@@ -684,15 +822,12 @@ mixin FolderTestMixin implements FileSystemTestSupport {
     var a_path = join(tempPath, 'a.dart');
     var b_path = join(tempPath, 'b.dart');
 
-    createLink(path: b_path, target: a_path);
+    getLink(linkPath: b_path, target: a_path);
     var a = getFile(exists: true, filePath: a_path);
 
     var children = provider.getFolder(tempPath).getChildren();
     expect(children, hasLength(2));
-    expect(
-      children.map((e) => e.path),
-      unorderedEquals([a_path, b_path]),
-    );
+    expect(children.map((e) => e.path), unorderedEquals([a_path, b_path]));
 
     var b = children.singleWhere((e) => e.path == b_path) as File;
     expect(b.resolveSymbolicLinksSync(), a);
@@ -705,14 +840,11 @@ mixin FolderTestMixin implements FileSystemTestSupport {
     var bar_path = join(tempPath, 'bar');
 
     var foo = getFolder(exists: true, folderPath: foo_path);
-    createLink(path: bar_path, target: foo_path);
+    getLink(linkPath: bar_path, target: foo_path);
 
     var children = provider.getFolder(tempPath).getChildren();
     expect(children, hasLength(2));
-    expect(
-      children.map((e) => e.path),
-      unorderedEquals([foo_path, bar_path]),
-    );
+    expect(children.map((e) => e.path), unorderedEquals([foo_path, bar_path]));
 
     var b = children.singleWhere((e) => e.path == bar_path) as Folder;
     expect(b.resolveSymbolicLinksSync(), foo);
@@ -730,7 +862,7 @@ mixin FolderTestMixin implements FileSystemTestSupport {
 
     var foo_a = getFile(exists: true, filePath: foo_a_path);
     var foo_b = getFolder(exists: true, folderPath: foo_b_path);
-    createLink(path: bar_path, target: foo_path);
+    getLink(linkPath: bar_path, target: foo_path);
 
     var children = provider.getFolder(bar_path).getChildren();
     expect(children, hasLength(2));
@@ -763,7 +895,9 @@ mixin FolderTestMixin implements FileSystemTestSupport {
     Folder folder = getFolder(exists: true);
 
     expect(
-        folder.isOrContains(join(defaultFolderPath, 'aaa', 'bbb.txt')), isTrue);
+      folder.isOrContains(join(defaultFolderPath, 'aaa', 'bbb.txt')),
+      isTrue,
+    );
   }
 
   test_isOrContains_notContained() {
@@ -778,6 +912,65 @@ mixin FolderTestMixin implements FileSystemTestSupport {
     expect(folder.isOrContains(defaultFolderPath), isTrue);
   }
 
+  /// Test that we can reuse a [ResourceWatcher] to create a second subscription
+  /// and cancel it at a different time.
+  test_multipleWatchers_staggeredCancel() async {
+    var folderPath = path.join(tempPath, 'foo');
+    var fileInFolder = getFile(
+      filePath: path.join(folderPath, 'file'),
+      exists: true,
+    );
+    var resource = provider.getResource(folderPath);
+    var watcher = resource.watch();
+
+    var watch1 = await _subscribeToWatcher(watcher);
+    var watch2 = await _subscribeToWatcher(watcher);
+    fileInFolder.writeAsStringSync('first');
+    await _waitFor(
+      () => watch1.changes.isNotEmpty && watch2.changes.isNotEmpty,
+    );
+
+    // Cancel the second watcher before causing the second event.
+    await watch2.cancel();
+
+    fileInFolder.writeAsStringSync('second');
+    await _waitFor(() => watch1.changes.length >= 2);
+
+    await watch1.cancel();
+
+    // Watcher 1 should have both events, and watcher 2 should have only the
+    // first one.
+    expect(watch1.changes.length, 2);
+    expect(watch2.changes.length, 1);
+  }
+
+  /// Test that we can reuse a [ResourceWatcher] to create a second subscription
+  /// at a different time.
+  test_multipleWatchers_staggeredSubscribe() async {
+    var folderPath = path.join(tempPath, 'foo');
+    var fileInFolder = getFile(
+      filePath: path.join(folderPath, 'file'),
+      exists: true,
+    );
+    var resource = provider.getResource(folderPath);
+    var watcher = resource.watch();
+
+    var watch1 = await _subscribeToWatcher(watcher);
+    fileInFolder.writeAsStringSync('first');
+    await _waitFor(() => watch1.changes.isNotEmpty);
+
+    var watch2 = await _subscribeToWatcher(watcher);
+    fileInFolder.writeAsStringSync('second');
+    await _waitFor(() => watch2.changes.isNotEmpty);
+
+    await Future.wait([watch1.cancel(), watch2.cancel()]);
+
+    // Watcher 1 should have both events, and watcher 2 should have only the
+    // second.
+    expect(watch1.changes.length, 2);
+    expect(watch2.changes.length, 1);
+  }
+
   test_parent() {
     Folder folder = getFolder(exists: true);
 
@@ -798,6 +991,67 @@ mixin FolderTestMixin implements FileSystemTestSupport {
     }
   }
 
+  test_relative_if_contains_immediateChild() {
+    Folder folder = getFolder(exists: false);
+    expect(
+      folder.relativeIfContains(join(defaultFolderPath, 'aaa.txt')),
+      'aaa.txt',
+    );
+  }
+
+  test_relative_if_contains_nestedChild() {
+    Folder folder = getFolder(exists: false);
+    expect(
+      folder.relativeIfContains(join(defaultFolderPath, 'aaa', 'bbb.txt')),
+      join('aaa', 'bbb.txt'),
+    );
+  }
+
+  test_relative_if_contains_os_specificic() {
+    Folder folder = getFolder(exists: false);
+    // On non-Windows path casing does matter.
+    String? expectOnCaseDifferenceImmediateChild;
+    String? expectOnCaseDifferenceNestedChild;
+    if (provider.pathContext.style.name == path.Style.windows.name) {
+      // On Windows path casing doesn't matter.
+      expectOnCaseDifferenceImmediateChild = 'aaa.txt';
+      expectOnCaseDifferenceNestedChild = join('aaa', 'bbb.txt');
+    }
+
+    var caseChangedFolder = defaultFolderPath.toUpperCase();
+
+    // Immediate child.
+    expect(
+      folder.relativeIfContains(join(caseChangedFolder, 'aaa.txt')),
+      expectOnCaseDifferenceImmediateChild,
+    );
+
+    // Nested child.
+    expect(
+      folder.relativeIfContains(join(caseChangedFolder, 'aaa', 'bbb.txt')),
+      expectOnCaseDifferenceNestedChild,
+    );
+
+    // Self (on Windows).
+    expect(folder.relativeIfContains(caseChangedFolder), isNull);
+
+    // Unrelated.
+    expect(
+      folder.relativeIfContains(join(tempPath.toUpperCase(), 'baz.txt')),
+      isNull,
+    );
+  }
+
+  test_relative_if_contains_self() {
+    Folder folder = getFolder(exists: false);
+    expect(folder.relativeIfContains(defaultFolderPath), isNull);
+  }
+
+  test_relative_if_contains_unrelated() {
+    Folder folder = getFolder(exists: false);
+    expect(folder.relativeIfContains(join(tempPath, 'baz.txt')), isNull);
+  }
+
   test_resolveSymbolicLinksSync_links_existing() {
     if (!hasSymbolicLinkSupport) return;
 
@@ -805,7 +1059,7 @@ mixin FolderTestMixin implements FileSystemTestSupport {
     var bar = join(tempPath, 'bar');
 
     getFolder(exists: true, folderPath: foo);
-    createLink(path: bar, target: foo);
+    getLink(linkPath: bar, target: foo);
 
     var resolved = provider.getFolder(bar).resolveSymbolicLinksSync();
     expect(resolved.path, foo);
@@ -817,7 +1071,7 @@ mixin FolderTestMixin implements FileSystemTestSupport {
     var foo = join(tempPath, 'foo');
     var bar = join(tempPath, 'bar');
 
-    createLink(path: bar, target: foo);
+    getLink(linkPath: bar, target: foo);
 
     expect(() {
       provider.getFolder(bar).resolveSymbolicLinksSync();
@@ -869,8 +1123,11 @@ mixin FolderTestMixin implements FileSystemTestSupport {
       if (copiedChild == null) {
         fail('Failed to copy file ${sourceChild.path}');
       }
-      expect(copiedChild.readAsStringSync(), sourceChild.readAsStringSync(),
-          reason: 'Incorrectly copied file ${sourceChild.path}');
+      expect(
+        copiedChild.readAsStringSync(),
+        sourceChild.readAsStringSync(),
+        reason: 'Incorrectly copied file ${sourceChild.path}',
+      );
     }
     for (String fileName in sourceFolders.keys) {
       var sourceChild = sourceFolders[fileName]!;
@@ -883,6 +1140,27 @@ mixin FolderTestMixin implements FileSystemTestSupport {
   }
 }
 
+mixin LinkTestMixin implements FileSystemTestSupport {
+  test_exists_created() {
+    var link = getLink(linkPath: join(tempPath, 'link.dart'))
+      ..create(join(tempPath, 'target.dart'));
+    expect(link.exists, isTrue);
+  }
+
+  test_exists_existing() {
+    var link = getLink(
+      linkPath: join(tempPath, 'link.dart'),
+      target: join(tempPath, 'target.dart'),
+    );
+    expect(link.exists, isTrue);
+  }
+
+  test_exists_notExisting() {
+    var link = getLink(linkPath: join(tempPath, 'link.dart'));
+    expect(link.exists, isFalse);
+  }
+}
+
 mixin ResourceProviderTestMixin implements FileSystemTestSupport {
   test_getFile_existing() {
     getFile(exists: true);
