@@ -16,7 +16,8 @@ main() {
 @reflectiveTest
 class ContinueLabelInvalidTest extends PubPackageResolutionTest {
   test_onBlock() async {
-    await assertErrorsInCode(r'''
+    await assertErrorsInCode(
+      r'''
 void f() {
   L:
   {
@@ -25,27 +26,31 @@ void f() {
     }
   }
 }
-''', [
-      error(HintCode.UNUSED_LOCAL_VARIABLE, 33, 1),
-      error(CompileTimeErrorCode.CONTINUE_LABEL_INVALID, 50, 11),
-    ]);
+''',
+      [
+        error(WarningCode.unusedLocalVariable, 33, 1),
+        error(CompileTimeErrorCode.continueLabelInvalid, 50, 11),
+      ],
+    );
   }
 
   test_onSwitchStatement() async {
-    await assertErrorsInCode(r'''
+    await assertErrorsInCode(
+      r'''
 void f(int x) {
   L: switch (x) {
     case 0:
       continue L;
   }
 }
-''', [
-      error(CompileTimeErrorCode.CONTINUE_LABEL_INVALID, 52, 11),
-    ]);
+''',
+      [error(CompileTimeErrorCode.continueLabelInvalid, 52, 11)],
+    );
   }
 
   test_onSwitchStatement_language219() async {
-    await assertErrorsInCode(r'''
+    await assertErrorsInCode(
+      r'''
 // @dart = 2.19
 void f(int x) {
   L: switch (x) {
@@ -53,8 +58,8 @@ void f(int x) {
       continue L;
   }
 }
-''', [
-      error(CompileTimeErrorCode.CONTINUE_LABEL_INVALID, 68, 11),
-    ]);
+''',
+      [error(CompileTimeErrorCode.continueLabelInvalid, 68, 11)],
+    );
   }
 }
