@@ -18,12 +18,18 @@ main() {
 class MixinSuperClassConstraintNonInterfaceTest
     extends PubPackageResolutionTest {
   test_dynamic() async {
-    await assertErrorsInCode(r'''
+    await assertErrorsInCode(
+      r'''
 mixin M on dynamic {}
-''', [
-      error(CompileTimeErrorCode.MIXIN_SUPER_CLASS_CONSTRAINT_NON_INTERFACE, 11,
-          7),
-    ]);
+''',
+      [
+        error(
+          CompileTimeErrorCode.mixinSuperClassConstraintNonInterface,
+          11,
+          7,
+        ),
+      ],
+    );
 
     var node = findNode.singleMixinOnClause;
     assertResolvedNodeText(node, r'''
@@ -32,20 +38,25 @@ MixinOnClause
   superclassConstraints
     NamedType
       name: dynamic
-      element: dynamic@-1
       element2: dynamic
       type: dynamic
 ''');
   }
 
   test_enum() async {
-    await assertErrorsInCode(r'''
+    await assertErrorsInCode(
+      r'''
 enum E { v }
 mixin M on E {}
-''', [
-      error(CompileTimeErrorCode.MIXIN_SUPER_CLASS_CONSTRAINT_NON_INTERFACE, 24,
-          1),
-    ]);
+''',
+      [
+        error(
+          CompileTimeErrorCode.mixinSuperClassConstraintNonInterface,
+          24,
+          1,
+        ),
+      ],
+    );
 
     var node = findNode.singleMixinOnClause;
     assertResolvedNodeText(node, r'''
@@ -54,20 +65,25 @@ MixinOnClause
   superclassConstraints
     NamedType
       name: E
-      element: <testLibraryFragment>::@enum::E
       element2: <testLibrary>::@enum::E
       type: E
 ''');
   }
 
   test_extensionType() async {
-    await assertErrorsInCode(r'''
+    await assertErrorsInCode(
+      r'''
 extension type A(int it) {}
 mixin M on A {}
-''', [
-      error(CompileTimeErrorCode.MIXIN_SUPER_CLASS_CONSTRAINT_NON_INTERFACE, 39,
-          1),
-    ]);
+''',
+      [
+        error(
+          CompileTimeErrorCode.mixinSuperClassConstraintNonInterface,
+          39,
+          1,
+        ),
+      ],
+    );
 
     var node = findNode.singleMixinOnClause;
     assertResolvedNodeText(node, r'''
@@ -76,19 +92,24 @@ MixinOnClause
   superclassConstraints
     NamedType
       name: A
-      element: <testLibraryFragment>::@extensionType::A
       element2: <testLibrary>::@extensionType::A
       type: A
 ''');
   }
 
   test_Never() async {
-    await assertErrorsInCode('''
+    await assertErrorsInCode(
+      '''
 mixin M on Never {}
-''', [
-      error(CompileTimeErrorCode.MIXIN_SUPER_CLASS_CONSTRAINT_NON_INTERFACE, 11,
-          5),
-    ]);
+''',
+      [
+        error(
+          CompileTimeErrorCode.mixinSuperClassConstraintNonInterface,
+          11,
+          5,
+        ),
+      ],
+    );
 
     var node = findNode.singleMixinOnClause;
     assertResolvedNodeText(node, r'''
@@ -97,20 +118,25 @@ MixinOnClause
   superclassConstraints
     NamedType
       name: Never
-      element: Never@-1
       element2: Never
       type: Never
 ''');
   }
 
   test_void() async {
-    await assertErrorsInCode(r'''
+    await assertErrorsInCode(
+      r'''
 mixin M on void {}
-''', [
-      error(ParserErrorCode.EXPECTED_TYPE_NAME, 11, 4),
-      error(CompileTimeErrorCode.MIXIN_SUPER_CLASS_CONSTRAINT_NON_INTERFACE, 11,
-          4),
-    ]);
+''',
+      [
+        error(ParserErrorCode.expectedTypeName, 11, 4),
+        error(
+          CompileTimeErrorCode.mixinSuperClassConstraintNonInterface,
+          11,
+          4,
+        ),
+      ],
+    );
 
     var node = findNode.singleMixinOnClause;
     assertResolvedNodeText(node, r'''
@@ -119,7 +145,6 @@ MixinOnClause
   superclassConstraints
     NamedType
       name: void
-      element: <null>
       element2: <null>
       type: void
 ''');
