@@ -17,20 +17,24 @@ main() {
 class UndefinedShownNameTest extends PubPackageResolutionTest {
   test_export() async {
     newFile('$testPackageLibPath/lib1.dart', '');
-    await assertErrorsInCode(r'''
+    await assertErrorsInCode(
+      r'''
 export 'lib1.dart' show a;
-''', [
-      error(WarningCode.UNDEFINED_SHOWN_NAME, 24, 1),
-    ]);
+''',
+      [error(WarningCode.undefinedShownName, 24, 1)],
+    );
   }
 
   test_import() async {
     newFile('$testPackageLibPath/lib1.dart', '');
-    await assertErrorsInCode(r'''
+    await assertErrorsInCode(
+      r'''
 import 'lib1.dart' show a;
-''', [
-      error(WarningCode.UNUSED_IMPORT, 7, 11),
-      error(WarningCode.UNDEFINED_SHOWN_NAME, 24, 1),
-    ]);
+''',
+      [
+        error(WarningCode.unusedImport, 7, 11),
+        error(WarningCode.undefinedShownName, 24, 1),
+      ],
+    );
   }
 }
